@@ -7,12 +7,6 @@
 /* Define if gdk-imlib is used */
 #undef GDK_IMLIB
 
-/* define if GNOME WM hints are enabled */
-#undef GNOME
-
-/* define if extended WM hints are enabled */
-#undef HAVE_EWMH
-
 /* Where to search for images. */
 #undef FVWM_IMAGEPATH
 
@@ -80,6 +74,10 @@
 /* Define if nl_langinfo is available */
 #undef HAVE_CODESET
 
+/* Define to 1 if translation of program messages to the user's native
+   language is requested. */
+#undef HAVE_NLS
+
 /* Define if you want the Shaped window extensions.
  * Shaped window extensions seem to increase the window managers RSS
  * by about 60 Kbytes. They provide for leaving a title-bar on the window
@@ -97,6 +95,9 @@
  * the currently running X server supports it. */
 #undef SHAPE
 
+/* Define if  MIT Shared Memory extension is used. */
+#undef HAVE_XSHM
+
 /* Define if fribidi library is used. */
 #undef HAVE_BIDI
 
