@@ -54,6 +54,7 @@
 #include "libs/FShape.h"
 #include "libs/FScreen.h"
 #include "libs/Picture.h"
+#include "libs/PictureUtils.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "cursor.h"
@@ -105,6 +106,23 @@ char NoResource[] = "NoResource"; /* Class if no res_name in class hints */
 
 /* ---------------------------- local functions ----------------------------- */
 
+static void delete_client_context(FvwmWindow *fw)
+{
+	FvwmWindow *cw;
+
+	/* We can not simply delete the context.  X might have reused the
+	 * window structure so we would delete the context that was established
+	 * by another FvwmWindow structure in the mean time. */
+	if (XFindContext(
+		    dpy, FW_W(fw), FvwmContext, (caddr_t *)&cw) !=
+	    XCNOENT && cw == fw)
+	{
+		XDeleteContext(dpy, FW_W(fw), FvwmContext);
+	}
+
+	return;
+}
+
 /***********************************************************************
  *
  *  Procedure:
@@ -705,6 +723,7 @@ void setup_icon_size_limits(FvwmWindow *fw, window_style *pstyle)
 		fw->min_icon_height = SGET_MIN_ICON_HEIGHT(*pstyle);
 		fw->max_icon_width = SGET_MAX_ICON_WIDTH(*pstyle);
 		fw->max_icon_height = SGET_MAX_ICON_HEIGHT(*pstyle);
+		fw->icon_resize_type = SGET_ICON_RESIZE_TYPE(*pstyle);
 	}
 	else
 	{
@@ -712,11 +731,49 @@ void setup_icon_size_limits(FvwmWindow *fw, window_style *pstyle)
 		fw->min_icon_height = MIN_ALLOWABLE_ICON_DIMENSION;
 		fw->max_icon_width = MAX_ALLOWABLE_ICON_DIMENSION;
 		fw->max_icon_height = MAX_ALLOWABLE_ICON_DIMENSION;
+		fw->icon_resize_type = ICON_RESIZE_TYPE_NONE;
 	}
 
 	return;
 }
 
+void setup_icon_background_parameters(FvwmWindow *fw, window_style *pstyle)
+{
+	if (SHAS_ICON_BACKGROUND_PADDING(&pstyle->flags))
+	{
+		fw->icon_background_padding =
+			SGET_ICON_BACKGROUND_PADDING(*pstyle);
+	}
+	else
+	{
+		fw->icon_background_padding = ICON_BACKGROUND_PADDING;
+	}
+	if (SHAS_ICON_BACKGROUND_RELIEF(&pstyle->flags))
+	{
+		fw->icon_background_relief =
+			SGET_ICON_BACKGROUND_RELIEF(*pstyle);
+	}
+	else
+	{
+		fw->icon_background_relief = ICON_RELIEF_WIDTH;
+	}
+	return;
+}
+
+void setup_icon_title_parameters(FvwmWindow *fw, window_style *pstyle)
+{
+	if (SHAS_ICON_TITLE_RELIEF(&pstyle->flags))
+	{
+		fw->icon_title_relief =
+			SGET_ICON_TITLE_RELIEF(*pstyle);
+	}
+	else
+	{
+		fw->icon_title_relief = ICON_RELIEF_WIDTH;
+	}
+	return;
+}
+
 static void setup_frame_window(
 	FvwmWindow *fw)
 {
@@ -727,7 +784,7 @@ static void setup_frame_window(
 	attributes.backing_store = NotUseful;
 	attributes.background_pixmap = None;
 	attributes.cursor = Scr.FvwmCursors[CRS_DEFAULT];
-	attributes.event_mask = XEVMASK_FRAMEW;
+	attributes.event_mask = XEVMASK_FRAMEW_CAPTURE;
 	attributes.save_under = False;
 	/* create the frame window, child of root, grandparent of client */
 	FW_W_FRAME(fw) = XCreateWindow(
@@ -1141,7 +1198,7 @@ static void destroy_auxiliary_windows(
 	{
 		XDeleteContext(dpy, FW_W_FRAME(fw), FvwmContext);
 		XDeleteContext(dpy, FW_W_PARENT(fw), FvwmContext);
-		XDeleteContext(dpy, FW_W(fw), FvwmContext);
+		delete_client_context(fw);
 		XDestroyWindow(dpy, FW_W_FRAME(fw));
 	}
 	if (HAS_TITLE(fw))
@@ -1260,6 +1317,20 @@ static void destroy_icon(FvwmWindow *fw)
 			XFreePixmap(dpy, fw->icon_alphaPixmap);
 			fw->icon_alphaPixmap = None;
 		}
+		if (fw->icon_alloc_pixels != NULL)
+		{
+			if (fw->icon_nalloc_pixels != 0)
+			{
+				PictureFreeColors(
+					dpy, Pcmap, fw->icon_alloc_pixels,
+					fw->icon_nalloc_pixels, 0,
+					fw->icon_no_limit);
+			}
+			free(fw->icon_alloc_pixels);
+			fw->icon_alloc_pixels = NULL;
+			fw->icon_nalloc_pixels = 0;
+			fw->icon_no_limit = 0;
+		}
 	}
 	if (FW_W_ICON_TITLE(fw))
 	{
@@ -1348,121 +1419,6 @@ static void setup_layer(FvwmWindow *fw, window_style *pstyle)
 	return;
 }
 
-static Bool setup_window_placement(
-	FvwmWindow *fw, window_style *pstyle, rectangle *attr_g,
-	initial_window_options_type *win_opts)
-{
-	int client_argc = 0;
-	char **client_argv = NULL;
-	XrmValue rm_value;
-	int tmpno1 = -1, tmpno2 = -1, tmpno3 = -1, spargs = 0;
-	/* Used to parse command line of clients for specific desk requests. */
-	/* Todo: check for multiple desks. */
-	XrmDatabase db = NULL;
-	static XrmOptionDescRec table [] = {
-		/* Want to accept "-workspace N" or -xrm "fvwm*desk:N" as
-		 * options to specify the desktop. I have to include dummy
-		 * options that are meaningless since Xrm seems to allow -w to
-		 * match -workspace if there would be no ambiguity. */
-		{"-workspacf", "*junk", XrmoptionSepArg, (caddr_t) NULL},
-		{"-workspace", "*desk", XrmoptionSepArg, (caddr_t) NULL},
-		{"-xrn", NULL, XrmoptionResArg, (caddr_t) NULL},
-		{"-xrm", NULL, XrmoptionResArg, (caddr_t) NULL},
-	};
-	Bool rc;
-	const exec_context_t *exc;
-	exec_context_changes_t ecc;
-
-	/* Find out if the client requested a specific desk on the command
-	 * line. */
-	/*  RBW - 11/20/1998 - allow a desk of -1 to work.  */
-
-	if (XGetCommand(dpy, FW_W(fw), &client_argv, &client_argc) &&
-	    client_argc > 0 && client_argv != NULL)
-	{
-		/* Get global X resources */
-		MergeXResources(dpy, &db, False);
-
-		/* command line takes precedence over all */
-		MergeCmdLineResources(
-			&db, table, 4, client_argv[0], &client_argc,
-			client_argv, True);
-
-		/* Now parse the database values: */
-		if (GetResourceString(db, "desk", client_argv[0], &rm_value) &&
-		    rm_value.size != 0)
-		{
-			SGET_START_DESK(*pstyle) = atoi(rm_value.addr);
-			/*  RBW - 11/20/1998  */
-			if (SGET_START_DESK(*pstyle) > -1)
-			{
-				SSET_START_DESK(
-					*pstyle, SGET_START_DESK(*pstyle) + 1);
-			}
-			pstyle->flags.use_start_on_desk = 1;
-		}
-		if (GetResourceString(
-			    db, "fvwmscreen", client_argv[0], &rm_value) &&
-		    rm_value.size != 0)
-		{
-			SSET_START_SCREEN(
-				*pstyle, FScreenGetScreenArgument(
-					rm_value.addr, 'c'));
-			pstyle->flags.use_start_on_screen = 1;
-		}
-		if (GetResourceString(db, "page", client_argv[0], &rm_value) &&
-		    rm_value.size != 0)
-		{
-			spargs = sscanf(
-				rm_value.addr, "%d %d %d", &tmpno1, &tmpno2,
-				&tmpno3);
-			switch (spargs)
-			{
-			case 1:
-				pstyle->flags.use_start_on_desk = 1;
-				SSET_START_DESK(*pstyle, (tmpno1 > -1) ?
-						tmpno1 + 1 : tmpno1);
-				break;
-			case 2:
-				pstyle->flags.use_start_on_desk = 1;
-				SSET_START_PAGE_X(*pstyle, (tmpno1 > -1) ?
-						  tmpno1 + 1 : tmpno1);
-				SSET_START_PAGE_Y(*pstyle, (tmpno2 > -1) ?
-						  tmpno2 + 1 : tmpno2);
-				break;
-			case 3:
-				pstyle->flags.use_start_on_desk = 1;
-				SSET_START_DESK(*pstyle, (tmpno1 > -1) ?
-						tmpno1 + 1 : tmpno1);
-				SSET_START_PAGE_X(*pstyle, (tmpno2 > -1) ?
-						  tmpno2 + 1 : tmpno2);
-				SSET_START_PAGE_Y(*pstyle, (tmpno3 > -1) ?
-						  tmpno3 + 1 : tmpno3);
-				break;
-			default:
-				break;
-			}
-		}
-
-		XFreeStringList(client_argv);
-		XrmDestroyDatabase(db);
-	}
-	if (pstyle->flags.do_start_iconic)
-	{
-		win_opts->initial_state = IconicState;
-	}
-	ecc.type = EXCT_NULL;
-	ecc.w.fw = fw;
-	exc = exc_create_context(&ecc, ECC_TYPE | ECC_FW);
-	rc = PlaceWindow(
-		exc, &pstyle->flags, attr_g, SGET_START_DESK(*pstyle),
-		SGET_START_PAGE_X(*pstyle), SGET_START_PAGE_Y(*pstyle),
-		SGET_START_SCREEN(*pstyle), PLACE_INITIAL, win_opts);
-	exc_destroy_context(exc);
-
-	return rc;
-}
-
 static void destroy_mini_icon(FvwmWindow *fw)
 {
 	if (fw->mini_icon)
@@ -1655,9 +1611,8 @@ void setup_window_font(
 void setup_icon_font(
 	FvwmWindow *fw, window_style *pstyle, Bool do_destroy)
 {
-	int height;
+	int height = 0;
 
-	height = (IS_ICON_FONT_LOADED(fw)) ? fw->icon_font->height : 0;
 	if (IS_ICON_SUPPRESSED(fw) || HAS_NO_ICON_TITLE(fw))
 	{
 		if (IS_ICON_FONT_LOADED(fw))
@@ -1693,12 +1648,13 @@ void setup_icon_font(
 		SET_ICON_FONT_LOADED(fw, 1);
 	}
 	/* adjust y position of existing icons */
+	height = (IS_ICON_FONT_LOADED(fw)) ? fw->icon_font->height : 0;
 	if (height)
 	{
 		resize_icon_title_height(fw, height - fw->icon_font->height);
 		/* this repositions the icon even if the window is not
 		 * iconified */
-		DrawIconWindow(fw, True, True, False, NULL);
+		DrawIconWindow(fw, True, True, False, False, NULL);
 	}
 
 	return;
@@ -1779,6 +1735,15 @@ void setup_style_and_decor(
 	update_window_color_style(fw, pstyle);
 	update_window_color_hi_style(fw, pstyle);
 
+	/***** icons colorsets *****/
+	update_icon_title_cs_style(fw, pstyle);
+	update_icon_title_cs_hi_style(fw, pstyle);
+	update_icon_background_cs_style(fw, pstyle);
+
+	/***** icons title/background parameters ****/
+	setup_icon_background_parameters(fw, pstyle);
+	setup_icon_title_parameters(fw, pstyle);
+
 	/****** window shading ******/
 	fw->shade_anim_steps = pstyle->shade_anim_steps;
 
@@ -1980,9 +1945,125 @@ void setup_focus_policy(FvwmWindow *fw)
 	return;
 }
 
+Bool setup_window_placement(
+	FvwmWindow *fw, window_style *pstyle, rectangle *attr_g,
+	initial_window_options_type *win_opts)
+{
+	int client_argc = 0;
+	char **client_argv = NULL;
+	XrmValue rm_value;
+	int tmpno1 = -1, tmpno2 = -1, tmpno3 = -1, spargs = 0;
+	/* Used to parse command line of clients for specific desk requests. */
+	/* Todo: check for multiple desks. */
+	XrmDatabase db = NULL;
+	static XrmOptionDescRec table [] = {
+		/* Want to accept "-workspace N" or -xrm "fvwm*desk:N" as
+		 * options to specify the desktop. I have to include dummy
+		 * options that are meaningless since Xrm seems to allow -w to
+		 * match -workspace if there would be no ambiguity. */
+		{"-workspacf", "*junk", XrmoptionSepArg, (caddr_t) NULL},
+		{"-workspace", "*desk", XrmoptionSepArg, (caddr_t) NULL},
+		{"-xrn", NULL, XrmoptionResArg, (caddr_t) NULL},
+		{"-xrm", NULL, XrmoptionResArg, (caddr_t) NULL},
+	};
+	Bool rc;
+	const exec_context_t *exc;
+	exec_context_changes_t ecc;
+
+	/* Find out if the client requested a specific desk on the command
+	 * line. */
+	/*  RBW - 11/20/1998 - allow a desk of -1 to work.  */
+
+	if (XGetCommand(dpy, FW_W(fw), &client_argv, &client_argc) &&
+	    client_argc > 0 && client_argv != NULL)
+	{
+		/* Get global X resources */
+		MergeXResources(dpy, &db, False);
+
+		/* command line takes precedence over all */
+		MergeCmdLineResources(
+			&db, table, 4, client_argv[0], &client_argc,
+			client_argv, True);
+
+		/* Now parse the database values: */
+		if (GetResourceString(db, "desk", client_argv[0], &rm_value) &&
+		    rm_value.size != 0)
+		{
+			SGET_START_DESK(*pstyle) = atoi(rm_value.addr);
+			/*  RBW - 11/20/1998  */
+			if (SGET_START_DESK(*pstyle) > -1)
+			{
+				SSET_START_DESK(
+					*pstyle, SGET_START_DESK(*pstyle) + 1);
+			}
+			pstyle->flags.use_start_on_desk = 1;
+		}
+		if (GetResourceString(
+			    db, "fvwmscreen", client_argv[0], &rm_value) &&
+		    rm_value.size != 0)
+		{
+			SSET_START_SCREEN(
+				*pstyle, FScreenGetScreenArgument(
+					rm_value.addr, 'c'));
+			pstyle->flags.use_start_on_screen = 1;
+		}
+		if (GetResourceString(db, "page", client_argv[0], &rm_value) &&
+		    rm_value.size != 0)
+		{
+			spargs = sscanf(
+				rm_value.addr, "%d %d %d", &tmpno1, &tmpno2,
+				&tmpno3);
+			switch (spargs)
+			{
+			case 1:
+				pstyle->flags.use_start_on_desk = 1;
+				SSET_START_DESK(*pstyle, (tmpno1 > -1) ?
+						tmpno1 + 1 : tmpno1);
+				break;
+			case 2:
+				pstyle->flags.use_start_on_desk = 1;
+				SSET_START_PAGE_X(*pstyle, (tmpno1 > -1) ?
+						  tmpno1 + 1 : tmpno1);
+				SSET_START_PAGE_Y(*pstyle, (tmpno2 > -1) ?
+						  tmpno2 + 1 : tmpno2);
+				break;
+			case 3:
+				pstyle->flags.use_start_on_desk = 1;
+				SSET_START_DESK(*pstyle, (tmpno1 > -1) ?
+						tmpno1 + 1 : tmpno1);
+				SSET_START_PAGE_X(*pstyle, (tmpno2 > -1) ?
+						  tmpno2 + 1 : tmpno2);
+				SSET_START_PAGE_Y(*pstyle, (tmpno3 > -1) ?
+						  tmpno3 + 1 : tmpno3);
+				break;
+			default:
+				break;
+			}
+		}
+
+		XFreeStringList(client_argv);
+		XrmDestroyDatabase(db);
+	}
+	if (pstyle->flags.do_start_iconic)
+	{
+		win_opts->initial_state = IconicState;
+	}
+	ecc.type = EXCT_NULL;
+	ecc.w.fw = fw;
+	exc = exc_create_context(&ecc, ECC_TYPE | ECC_FW);
+	rc = PlaceWindow(
+		exc, &pstyle->flags, attr_g, SGET_START_DESK(*pstyle),
+		SGET_START_PAGE_X(*pstyle), SGET_START_PAGE_Y(*pstyle),
+		SGET_START_SCREEN(*pstyle), PLACE_INITIAL, win_opts);
+	exc_destroy_context(exc);
+
+	return rc;
+}
+
 Bool validate_transientfor(FvwmWindow *fw)
 {
 	XWindowAttributes wa;
+	FvwmWindow *cw;
 	Window w;
 
 	w = FW_W_TRANSIENTFOR(fw);
@@ -1991,6 +2072,15 @@ Bool validate_transientfor(FvwmWindow *fw)
 		FW_W_TRANSIENTFOR(fw) = Scr.Root;
 		return False;
 	}
+	else if (XFindContext(dpy, w, FvwmContext, (caddr_t *)&cw) != XCNOENT)
+	{
+		if (cw == fw)
+		{
+			/* It's a transient of itself, ignore the hint */
+			FW_W_TRANSIENTFOR(fw) = Scr.Root;
+			return False;
+		}
+	}
 	else if (!XGetWindowAttributes(dpy, w, &wa) ||
 		 wa.map_state != IsViewable)
 	{
@@ -2222,7 +2312,6 @@ FvwmWindow *AddWindow(
 		fw->frame_g.height = wattr.height + b.total_size.height;
 		gravity_constrain_size(
 			fw->hints.win_gravity, fw, &fw->frame_g, 0);
-
 		update_absolute_geometry(fw);
 	}
 
@@ -2318,23 +2407,32 @@ FvwmWindow *AddWindow(
 		      (unsigned long)fw,fw->class.res_name);
 
 	/****** stick window ******/
-	if (IS_STICKY(fw) && (!(fw->hints.flags & USPosition) || used_sm))
+	if (!(fw->hints.flags & USPosition) || used_sm)
 	{
-		/* If it's sticky and the user didn't ask for an explicit
-		 * position, force it on screen now.  Don't do that with
-		 * USPosition because we have to assume the user knows what
-		 * (s)he is doing.  This is necessary e.g. if we want a sticky
-		 * 'panel' in FvwmButtons but don't want to see when it's
-		 * mapped in the void. */
-		if (!IsRectangleOnThisPage(&fw->frame_g, Scr.CurrentDesk))
+		int stick_page;
+		int stick_desk;
+
+		stick_page = is_window_sticky_across_pages(fw);
+		stick_desk = is_window_sticky_across_pages(fw);
+		if ((stick_page &&
+		     !IsRectangleOnThisPage(&fw->frame_g, Scr.CurrentDesk)) ||
+		    (stick_desk && fw->Desk != Scr.CurrentDesk))
 		{
+			/* If it's sticky and the user didn't ask for an
+			 * explicit position, force it on screen now.  Don't do
+			 * that with USPosition because we have to assume the
+			 * user knows what (s)he is doing.  This is necessary
+			 * e.g. if we want a sticky 'panel' in FvwmButtons but
+			 * don't want to see when it's mapped in the void. */
 			ecc.w.fw = fw;
 			ecc.w.w = FW_W_FRAME(fw);
 			ecc.w.wcontext = C_FRAME;
 			exc2 = exc_clone_context(
 				exc, &ecc, ECC_FW | ECC_W | ECC_WCONTEXT);
-			SET_STICKY(fw, 0);
-			handle_stick(NULL, exc2, "", 1, 1, 0);
+			SET_STICKY_ACROSS_PAGES(fw, 0);
+			SET_STICKY_ACROSS_DESKS(fw, 0);
+			handle_stick(
+				NULL, exc2, "", stick_page, stick_desk, 1, 0);
 			exc_destroy_context(exc2);
 		}
 	}
@@ -2689,6 +2787,28 @@ void GetWindowSizeHints(FvwmWindow *tmp)
 		tmp->hints.win_gravity = NorthWestGravity;
 	}
 
+
+	if ((tmp->hints.flags & PMaxSize) &&
+	    ((tmp->hints.flags & PMinSize) || (tmp->hints.flags & PBaseSize)))
+	{
+		if (tmp->hints.max_width < tmp->hints.base_width)
+		{
+			tmp->hints.max_width = DEFAULT_MAX_MAX_WINDOW_WIDTH;
+			if (!*broken_cause)
+			{
+				broken_cause = "max_width";
+			}
+		}
+		if (tmp->hints.max_height < tmp->hints.base_height)
+		{
+			tmp->hints.max_height = DEFAULT_MAX_MAX_WINDOW_HEIGHT;
+			if (!*broken_cause)
+			{
+				broken_cause = "max_height";
+			}
+		}
+	}
+
 	if (tmp->hints.flags & PAspect)
 	{
 		/*
@@ -2732,8 +2852,16 @@ void GetWindowSizeHints(FvwmWindow *tmp)
 			}
 			tmp->hints.flags &= ~PAspect;
 			fvwm_msg(
-				WARN, "GetWindowSizeHints", "%s window %#lx"
-				" has broken aspect ratio: %d/%d - %d/%d\n",
+				WARN, "GetWindowSizeHints",
+				"The applicaton window \"%s\"\n"
+				"(window id %#lx)"
+				" has broken aspect ratio: %d/%d - %d/%d\n"
+				"Fvwm is ignoring the aspect ratio.  "
+				"If you are having a problem\n"
+				"with the application, send this message to"
+				" the application owner.\n"
+				"There is no need to notify "
+				"fvwm-workers@fvwm.org.\n",
 				tmp->name.name, FW_W(tmp), minAspectX,
 				minAspectY, maxAspectX, maxAspectY);
 		}
@@ -2778,10 +2906,14 @@ void GetWindowSizeHints(FvwmWindow *tmp)
 	if (*broken_cause != 0)
 	{
 		fvwm_msg(WARN, "GetWindowSizeHints",
-			 "%s window %#lx has broken (%s) size hints\n"
-			 "Please send a bug report to the application owner,\n"
-			 "\tyou may use fvwm-workers@fvwm.org as a reference.\n"
-			 "hint override = %d\n"
+			 "The application window \"%s\"\n(window id %#lx) "
+			 "has broken size hints (%s).\n"
+			 "Fvwm is ignoring those hints.  "
+			 "If you are having a problem\n"
+			 "with the application, send this message to"
+			 " the application owner.\n"
+			 "There is no need to notify fvwm-workers@fvwm.org.\n"
+			 "hint override = %d "
 			 "flags = %lx\n"
 			 "min_width = %d, min_height = %d, "
 			 "max_width = %d, max_height = %d\n"
@@ -2816,62 +2948,50 @@ void free_window_names(FvwmWindow *fw, Bool nukename, Bool nukeicon)
 		return;
 	}
 
-	if (nukename && fw->visible_name &&
-	    fw->visible_name != fw->name.name &&
-	    fw->visible_name != NoName)
+	if (nukename)
 	{
-		free(fw->visible_name);
-		fw->visible_name = NULL;
+		if (fw->visible_name && fw->visible_name != fw->name.name &&
+		    fw->visible_name != NoName)
+		{
+			free(fw->visible_name);
+		}
+		fw->visible_name = NoName;
+		if (fw->name.name)
+		{
+			if (fw->icon_name.name == fw->name.name)
+			{
+				fw->icon_name.name = NoName;
+			}
+			if (fw->visible_icon_name == fw->name.name)
+			{
+				fw->visible_icon_name = fw->icon_name.name;
+			}
+			if (fw->name.name != NoName)
+			{
+				FlocaleFreeNameProperty(&(fw->name));
+				fw->visible_name = NULL;
+			}
+		}
 	}
-	if (nukeicon && fw->visible_icon_name &&
-	    fw->visible_icon_name != fw->name.name &&
-	    fw->visible_icon_name != fw->icon_name.name &&
-	    fw->visible_icon_name != NoName)
+	if (nukeicon)
 	{
-		free(fw->visible_icon_name);
-		fw->visible_icon_name = NULL;
-	}
-	if (nukename && fw->name.name)
-	{
-#ifdef CODE_WITH_LEAK_I_THINK
-		if (fw->name.name != fw->icon_name.name &&
-		    fw->name.name != NoName)
+		if (fw->visible_icon_name &&
+		    fw->visible_icon_name != fw->name.name &&
+		    fw->visible_icon_name != fw->icon_name.name &&
+		    fw->visible_icon_name != NoName)
 		{
-			FlocaleFreeNameProperty(&(fw->name));
+			free(fw->visible_icon_name);
 		}
-#else
-		if (fw->icon_name.name == fw->name.name)
+		fw->visible_icon_name = NoName;
+		if (fw->icon_name.name)
 		{
-			fw->icon_name.name = NoName;
+			if ((fw->icon_name.name != fw->name.name) &&
+			    fw->icon_name.name != NoName)
+			{
+				FlocaleFreeNameProperty(&(fw->icon_name));
+				fw->visible_icon_name = NULL;
+			}
 		}
-		if (fw->visible_icon_name == fw->name.name)
-		{
-			fw->visible_icon_name = fw->icon_name.name;
-		}
-		if (fw->name.name != NoName)
-		{
-			FlocaleFreeNameProperty(&(fw->name));
-			fw->visible_name = NULL;
-		}
-#endif
-	}
-	if (nukeicon && fw->icon_name.name)
-	{
-#ifdef CODE_WITH_LEAK_I_THINK
-		if ((fw->name.name != fw->icon_name.name || nukename) &&
-		    fw->icon_name.name != NoName)
-		{
-			FlocaleFreeNameProperty(&(fw->icon_name));
-			fw->visible_icon_name = NULL;
-		}
-#else
-		if ((fw->name.name != fw->icon_name.name) &&
-		    fw->icon_name.name != NoName)
-		{
-			FlocaleFreeNameProperty(&(fw->icon_name));
-			fw->visible_icon_name = NULL;
-		}
-#endif
 	}
 
 	return;
@@ -2895,25 +3015,31 @@ void destroy_window(FvwmWindow *fw)
 	}
 
 	/****** remove from window list ******/
-
-	/* first of all, remove the window from the list of all windows! */
-	if (fw->prev != NULL)
+	/* if the window is sheduled fro destroy the window has been already
+	 * removed from list */
+	if (!IS_SCHEDULED_FOR_DESTROY(fw))
 	{
-		fw->prev->next = fw->next;
-	}
-	if (fw->next != NULL)
-	{
-		fw->next->prev = fw->prev;
-	}
+		/* first, remove the window from the list of all windows! */
+		if (fw->prev != NULL)
+		{
+			fw->prev->next = fw->next;
+		}
+		if (fw->next != NULL)
+		{
+			fw->next->prev = fw->prev;
+		}
+		fw->next = NULL;
+		fw->prev = NULL;
 
-	/****** also remove it from the stack ring ******/
+		/****** also remove it from the stack ring ******/
 
-	/*
-	 * RBW - 11/13/1998 - new: have to unhook the stacking order chain also.
-	 * There's always a prev and next, since this is a ring anchored on
-	 * Scr.FvwmRoot
-	 */
-	remove_window_from_stack_ring(fw);
+		/*
+		 * RBW - 11/13/1998 - new: have to unhook the stacking order
+		 chain also. There's always a prev and next, since this is a
+		 ring anchored on Scr.FvwmRoot
+		*/
+		remove_window_from_stack_ring(fw);
+	}
 
 	/****** check if we have to delay window destruction ******/
 
@@ -2921,13 +3047,17 @@ void destroy_window(FvwmWindow *fw)
 	     Scr.flags.is_executing_menu_function) &&
 	    !DO_REUSE_DESTROYED(fw))
 	{
+		if (IS_SCHEDULED_FOR_DESTROY(fw))
+		{
+			return;
+		}
 		/* mark window for destruction */
 		SET_SCHEDULED_FOR_DESTROY(fw, 1);
 		Scr.flags.is_window_scheduled_for_destroy = 1;
 		/* this is necessary in case the application destroys the
 		 * client window and a new window is created with the same
 		 * window id */
-		XDeleteContext(dpy, FW_W(fw), FvwmContext);
+		delete_client_context(fw);
 		XFlush(dpy);
 		/* unmap the the window to fake that it was already removed */
 		if (IS_ICONIFIED(fw))
@@ -2951,6 +3081,8 @@ void destroy_window(FvwmWindow *fw)
 			(unsigned long)fw);
 		EWMH_DestroyWindow(fw);
 		focus_grab_buttons_on_layer(fw->layer);
+		Scr.FWScheduledForDestroy = flist_append_obj(
+			Scr.FWScheduledForDestroy, fw);
 		return;
 	}
 
@@ -3064,6 +3196,13 @@ void RestoreWithdrawnLocation(
 		return;
 	}
 
+	if (HAS_NEW_WM_NORMAL_HINTS(fw))
+	{
+		/* get the latest size hints */
+		XSync(dpy, 0);
+		GetWindowSizeHints(fw);
+		SET_HAS_NEW_WM_NORMAL_HINTS(fw, 0);
+	}
 	get_unshaded_geometry(fw, &unshaded_g);
 	gravity_get_naked_geometry(
 		fw->hints.win_gravity, fw, &naked_g, &unshaded_g);
