@@ -6,12 +6,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifndef ADD_WINDOW_H
@@ -35,6 +35,14 @@ void setup_visible_name(FvwmWindow *fw, Bool is_icon);
 void setup_wm_hints(FvwmWindow *fw);
 void setup_placement_penalty(FvwmWindow *fw, window_style *pstyle);
 void setup_focus_policy(FvwmWindow *fw);
+Bool setup_transientfor(FvwmWindow *fw);
+void setup_icon_size_limits(FvwmWindow *fw, window_style *pstyle);
+void setup_icon_background_parameters(FvwmWindow *fw, window_style *pstyle);
+void setup_icon_title_parameters(FvwmWindow *fw, window_style *pstyle);
+Bool setup_window_placement(
+	FvwmWindow *fw, window_style *pstyle, rectangle *attr_g,
+	initial_window_options_type *win_opts);
+Bool validate_transientfor(FvwmWindow *fw);
 void setup_title_geometry(
 	FvwmWindow *fw, window_style *pstyle);
 void setup_window_font(
@@ -43,16 +51,10 @@ void setup_icon_font(
 	FvwmWindow *fw, window_style *pstyle, Bool do_destroy);
 void setup_style_and_decor(
 	FvwmWindow *fw, window_style *pstyle, short *buttons);
-void setup_auxiliary_windows(
-	FvwmWindow *fw, Bool setup_frame_and_parent, short buttons);
 void setup_frame_attributes(
 	FvwmWindow *fw, window_style *pstyle);
-void destroy_auxiliary_windows(
-	FvwmWindow *fw, Bool destroy_frame_and_parent);
 void change_auxiliary_windows(
 	FvwmWindow *fw, short buttons);
-void setup_key_and_button_grabs(
-	FvwmWindow *fw);
 void setup_frame_geometry(
 	FvwmWindow *fw);
 void setup_frame_size_limits(
@@ -68,7 +70,8 @@ void change_icon_boxes(
 void FetchWmProtocols(
 	FvwmWindow *);
 FvwmWindow *AddWindow(
-	Window w, FvwmWindow *ReuseWin, initial_window_options_type * win_opts);
+	const exec_context_t *exc, FvwmWindow *ReuseWin,
+	initial_window_options_type * win_opts);
 void GetWindowSizeHints(
 	FvwmWindow *);
 void free_window_names(
@@ -78,5 +81,6 @@ void destroy_window(
 void RestoreWithdrawnLocation(
 	FvwmWindow *tmp, Bool is_restart_or_recapture, Window parent);
 void Reborder(void);
+void CaptureAllWindows(const exec_context_t *exc, Bool is_recapture);
 
 #endif /* ADD_WINDOW_H */
