@@ -106,13 +106,6 @@ static int activate_binding(Binding *binding, binding_t type, Bool do_grab)
 	{
 		return rc;
 	}
-	if (BIND_IS_KEY_RELEASE(type))
-	{
-		/* Release a passive grab on the key if any.  Actually this may
-		 * release the grab for the wrong key, but it will prevent the
-		 * keyboard from staying frozen forever. */
-		MyXUngrabKey(dpy);
-	}
 	if (BIND_IS_PKEY_BINDING(type) || binding->Context == C_ALL)
 	{
 		/* necessary for key bindings that work over unfocused windows
@@ -195,6 +188,7 @@ static int bind_get_bound_button_contexts(
 			continue;
 		}
 		if ((b->Context & (C_WINDOW | C_EWMH_DESKTOP)) &&
+		    !(BIND_IS_STROKE_BINDING(b->type) && b->Button_Key == 0) &&
 		    buttons_grabbed != NULL)
 		{
 			if (b->Button_Key == 0)
@@ -261,12 +255,6 @@ static int ParseBinding(
 	{
 		if (BIND_IS_KEY_BINDING(type))
 		{
-			if (token[0] == '-')
-			{
-				/* it's a key release binding */
-				type++;
-				token++;
-			}
 			/* see len of key_string above */
 			n1 = sscanf(token,"%200s", key_string);
 		}
@@ -345,9 +333,9 @@ static int ParseBinding(
 						WARN, "ParseBinding",
 						"Got mouse button %d when the"
 						" maximum is %d.\n  You can't"
-						" bind complex function to"
+						" bind complex functions to"
 						" this button.  To suppress"
-						" the warning, use:\n"
+						" this warning, use:\n"
 						"  Silent Mouse %s", button,
 						NUMBER_OF_MOUSE_BUTTONS, tline);
 				}
@@ -486,7 +474,8 @@ static int ParseBinding(
 			" ignored.");
 		modifier = AnyModifier;
 	}
-	if ((BIND_IS_MOUSE_BINDING(type) || BIND_IS_STROKE_BINDING(type)) &&
+	if ((BIND_IS_MOUSE_BINDING(type) ||
+	     (BIND_IS_STROKE_BINDING(type) && button != 0)) &&
 	    (context & (C_WINDOW | C_EWMH_DESKTOP)) && buttons_grabbed != NULL)
 	{
 		if (button == 0)
