@@ -28,6 +28,9 @@
 
 #include <stdio.h>
 #include <unistd.h>                     /* for STDIN_FILENO */
+#include <sys/types.h>		/* for open */
+#include <sys/stat.h>		/* for open */
+#include <fcntl.h>		/* for open */
 #include <errno.h>
 #include <X11/keysym.h>
 
@@ -65,8 +68,6 @@
 
 /* ---------------------------- local definitions --------------------------- */
 
-#define ENV_LIST_INC 10
-
 /* ---------------------------- local macros -------------------------------- */
 
 /* ---------------------------- imports ------------------------------------- */
@@ -79,12 +80,6 @@ extern int cmsDelayDefault;
 
 /* ---------------------------- local types --------------------------------- */
 
-typedef struct
-{
-	char *var;
-	char *env;
-} env_list_item;
-
 /* ---------------------------- forward declarations ------------------------ */
 
 /* ---------------------------- local variables ----------------------------- */
@@ -126,53 +121,6 @@ int moduleTimeout = DEFAULT_MODULE_TIMEOUT;
 
 /* ---------------------------- local functions ----------------------------- */
 
-/* add_to_env_list
- *   This function keeps a list of all strings that were set in the environment
- *   via SetEnv or UnsetEnv. If a variable is written again, the old memory is
- *   freed. */
-static void add_to_env_list(char *var, char *env)
-{
-	static env_list_item *env_list = NULL;
-	static unsigned int env_len = 0;
-	unsigned int i;
-
-	/* find string in list */
-	if (env_list && env_len)
-	{
-		for (i = 0; i < env_len; i++)
-		{
-			if (strcmp(var, env_list[i].var) == 0)
-			{
-				/* found it - replace old string */
-				free(env_list[i].var);
-				free(env_list[i].env);
-				env_list[i].var = var;
-				env_list[i].env = env;
-				return;
-			}
-		}
-		/* not found, add to list */
-		if (env_len % ENV_LIST_INC == 0)
-		{
-			/* need more memory */
-			env_list = (env_list_item *)saferealloc(
-				(void *)env_list, (env_len + ENV_LIST_INC) *
-				sizeof(env_list_item));
-		}
-	}
-	else if (env_list == NULL)
-	{
-		/* list is still empty */
-		env_list = (env_list_item *)safecalloc(
-			sizeof(env_list_item), ENV_LIST_INC);
-	}
-	env_list[env_len].var = var;
-	env_list[env_len].env = env;
-	env_len++;
-
-	return;
-}
-
 /** Prepend rather than replace the image path.
     Used for obsolete PixmapPath and IconPath **/
 static void obsolete_imagepaths( const char* pre_path )
@@ -764,7 +712,6 @@ static char *ReadMultiPixmapDecor(char *s, DecorFace *df)
 			}
 			acs[TBMP_BUTTONS].cs = -1;
 			df->u.mp.solid_flags &= ~(1 << TBMP_BUTTONS);
-			
 		}
 		s = SkipSpaces(s, NULL, 0);
 		s = GetNextTokenIndex(s, pm_names, 0, &pm_id);
@@ -793,7 +740,7 @@ static char *ReadMultiPixmapDecor(char *s, DecorFace *df)
 			{
 				PictureFreeColors(
 					dpy, Pcmap, &df->u.mp.pixels[i], 1, 0,
-					False); 
+					False);
 			}
 		}
 		free(pm);
@@ -1199,7 +1146,7 @@ int update_decorface_colorset(DecorFace *df, int cset)
 			}
 		}
 }
-	
+
 	return has_changed;
 }
 
@@ -1879,16 +1826,6 @@ Bool ReadDecorFace(char *s, DecorFace *df, int button, int verbose)
 		{
 			memset(&df->style, 0, sizeof(df->style));
 			DFS_FACE_TYPE(df->style) = MiniIconButton;
-#if 0
-			/* Have to remove this again. This is all so badly
-			 * written there is no chance to prevent a coredump
-			 * and a memory leak the same time without a rewrite of
-			 * large parts of the code. */
-			if (df->u.p)
-			{
-				PDestroyFvwmPicture(dpy, df->u.p);
-			}
-#endif
 			/* pixmap read in when the window is created */
 			df->u.p = NULL;
 		}
@@ -1904,7 +1841,7 @@ Bool ReadDecorFace(char *s, DecorFace *df, int button, int verbose)
 			memset(&df->style, 0, sizeof(df->style));
 			if (n > 0 && val[0] >= 0)
 			{
-				
+
 				df->u.acs.cs = val[0];
 				alloc_colorset(val[0]);
 				DFS_FACE_TYPE(df->style) = ColorsetButton;
@@ -2366,14 +2303,11 @@ void CMD_Destroy(F_CMD_ARGS)
 		return;
 	}
 	if (XGetGeometry(dpy, FW_W(fw), &JunkRoot, &JunkX, &JunkY,
-			 &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) == 0)
-	{
-		destroy_window(fw);
-	}
-	else
+			 &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) != 0)
 	{
 		XKillClient(dpy, FW_W(fw));
 	}
+	destroy_window(fw);
 	XFlush(dpy);
 
 	return;
@@ -2399,16 +2333,14 @@ void CMD_Close(F_CMD_ARGS)
 			dpy, FW_W(fw), _XA_WM_DELETE_WINDOW, CurrentTime);
 		return;
 	}
-	else if (XGetGeometry(
+	if (XGetGeometry(
 			 dpy, FW_W(fw), &JunkRoot, &JunkX, &JunkY,
-			 &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) == 0)
-	{
-		destroy_window(fw);
-	}
-	else
+			 &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) != 0)
 	{
 		XKillClient(dpy, FW_W(fw));
 	}
+
+	destroy_window(fw);
 	XFlush(dpy);
 
 	return;
@@ -2486,9 +2418,10 @@ void CMD_Exec(F_CMD_ARGS)
 
 	if (!(fork())) /* child process */
 	{
-		/* close stdin so the exec'd process knows its not
-		   interactive */
-	  	close(STDIN_FILENO);
+		/* This is for fixing a problem with rox filer */
+		int fd;
+		fd = open("/dev/null", O_RDONLY, 0);
+		dup2(fd,STDIN_FILENO);
 		if (fvwm_setpgrp() == -1)
 		{
 			fvwm_msg(ERR, "exec_function", "setpgrp failed (%s)",
@@ -2688,7 +2621,7 @@ void CMD_Echo(F_CMD_ARGS)
 void CMD_PrintInfo(F_CMD_ARGS)
 {
 	int verbose;
-	char *rest, *subject;
+	char *rest, *subject = NULL;
 
 	rest = GetNextToken(action, &subject);
 	if (!rest || GetIntegerArguments(rest, NULL, &verbose, 1) != 1)
@@ -2707,12 +2640,19 @@ void CMD_PrintInfo(F_CMD_ARGS)
 	{
 		FGettextPrintLocalePath(verbose);
 	}
+	else if (StrEquals(subject, "style"))
+	{
+		print_styles(verbose);
+	}
 	else
 	{
 		fvwm_msg(ERR, "PrintInfo",
 			 "Unknown subject '%s'", action);
 	}
-
+	if (subject)
+	{
+		free(subject);
+	}
 	return;
 }
 
@@ -3027,6 +2967,7 @@ void CMD_DefaultFont(F_CMD_ARGS)
 {
 	char *font;
 	FlocaleFont *new_font;
+	FvwmWindow *t;
 
 	font = PeekToken(action, &action);
 	if (!font)
@@ -3046,6 +2987,19 @@ void CMD_DefaultFont(F_CMD_ARGS)
 	}
 	FlocaleUnloadFont(dpy, Scr.DefaultFont);
 	Scr.DefaultFont = new_font;
+	/* we should do that here because a redraw can happen before
+	   flush_window_updates is called ... */
+	for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
+	{
+		if (USING_DEFAULT_ICON_FONT(t))
+		{
+			t->icon_font = Scr.DefaultFont;
+		}
+		if (USING_DEFAULT_WINDOW_FONT(t))
+		{
+			t->title_font = Scr.DefaultFont;
+		}
+	}
 	/* set flags to indicate that the font has changed */
 	Scr.flags.do_need_window_update = 1;
 	Scr.flags.has_default_font_changed = 1;
@@ -3363,24 +3317,23 @@ void CMD_SetEnv(F_CMD_ARGS)
 	char *szValue = NULL;
 	char *szPutenv = NULL;
 
-	action = GetNextToken(action,&szVar);
+	action = GetNextToken(action, &szVar);
 	if (!szVar)
 	{
 		return;
 	}
-	action = GetNextToken(action,&szValue);
+	action = GetNextToken(action, &szValue);
 	if (!szValue)
 	{
-		/* no value, treat as unset */
-		CMD_UnsetEnv(F_PASS_ARGS);
+		/* no value, ignore */
 		free(szVar);
 		return;
 	}
-	szPutenv = safemalloc(strlen(szVar)+strlen(szValue)+2);
-	sprintf(szPutenv,"%s=%s",szVar,szValue);
-	putenv(szPutenv);
-	add_to_env_list(szVar, szPutenv);
-	/* szVar is stored in the env list. do not free it */
+	szPutenv = safemalloc(strlen(szVar) + strlen(szValue) + 2);
+	sprintf(szPutenv,"%s=%s", szVar, szValue);
+	flib_putenv(szVar, szPutenv);
+	free(szVar);
+	free(szPutenv);
 	free(szValue);
 
 	return;
@@ -3391,16 +3344,16 @@ void CMD_UnsetEnv(F_CMD_ARGS)
 	char *szVar = NULL;
 	char *szPutenv = NULL;
 
-	action = GetNextToken(action,&szVar);
+	action = GetNextToken(action, &szVar);
 	if (!szVar)
 	{
 		return;
 	}
 	szPutenv = (char *)safemalloc(strlen(szVar) + 2);
 	sprintf(szPutenv, "%s=", szVar);
-	putenv(szPutenv);
-	add_to_env_list(szVar, szPutenv);
-	/* szVar is stored in the env list. do not free it */
+	flib_putenv(szVar, szPutenv);
+	free(szVar);
+	free(szPutenv);
 
 	return;
 }
@@ -4049,7 +4002,7 @@ void CMD_StrokeFunc(F_CMD_ARGS)
 
 	/* Force auto repeat off and grab the Keyboard to get proper
 	 * KeyRelease events if we need it.
-	 * Some computers do not support keyRelease events, can we
+	 * Some computers do not support KeyRelease events, can we
 	 * check this here ? No ? */
 	if (start_event_type == KeyPress && finish_on_release)
 	{
