@@ -171,17 +171,22 @@ Pixmap get_root_pixmap(Atom prop)
 	Atom type;
 	int format;
 	unsigned long length, after;
-	unsigned char *data;
+	unsigned char *reteval = NULL;
 	int ret;
+	Pixmap pix = None;
 
 	ret = XGetWindowProperty(dpy, Scr.Root, prop, 0L, 1L, False, XA_PIXMAP,
-			   &type, &format, &length, &after, &data);
+			   &type, &format, &length, &after, &reteval);
 	if (ret == Success && type == XA_PIXMAP && format == 32 && length == 1 &&
 	    after == 0)
 	{
-		return *((Pixmap *)data);
+		pix = ((Pixmap *)reteval)[0];
 	}
-	return None;
+	if (reteval)
+	{
+		XFree(reteval);
+	}
+	return pix;
 }
 
 void update_root_pixmap(Atom prop)
@@ -1086,9 +1091,12 @@ void parse_colorset(int n, char *line)
 				{
 					average_pix = None;
 				}
-				if (w != cs->width || h != cs->height)
+				else
 				{
-					average_pix = None;
+					if (w != cs->width || h != cs->height)
+					{
+						average_pix = None;
+					}
 				}
 				if (average_pix == None)
 				{
@@ -1511,6 +1519,7 @@ void parse_colorset(int n, char *line)
 		FvwmRenderAttributes fra;
 		Pixmap temp, mask, alpha;
 
+		memset(&fra, 0, sizeof(fra));
 		temp = XCreatePixmap(dpy, win, cs->width, cs->height, Pdepth);
 		if (cs->picture != NULL)
 		{
@@ -1532,7 +1541,7 @@ void parse_colorset(int n, char *line)
 		fra.tint_percent = cs->tint_percent;
 		PGraphicsRenderPixmaps(
 			dpy, win, cs->pixmap, mask, alpha, Pdepth, &fra,
-			temp, gc, Scr.MonoGC, None,
+			temp, gc, Scr.MonoGC, Scr.AlphaGC,
 			0, 0, cs->width, cs->height,
 			0, 0, cs->width, cs->height, False);
 		if (cs->pixmap != root_pic.pixmap)
