@@ -28,6 +28,7 @@
 
 #include <stdio.h>
 #include <math.h>
+//#include <sys/stat.h>
 
 #include "libs/fvwmlib.h"
 #include "libs/FScreen.h"
@@ -117,6 +118,7 @@ static FvwmWindow *Circulate(
 		fw = NULL;
 		if (Direction == 0)
 		{
+			FreeConditionMask(&mask);
 			return NULL;
 		}
 	}
@@ -243,6 +245,51 @@ static void select_cmd(F_CMD_ARGS)
 	return;
 }
 
+static Bool cond_check_access(char *file, int type, Bool im)
+{
+	char *full_file;
+	char *path = NULL;
+
+	if (!file || *file == 0)
+	{
+		return False;
+	}
+	if (file[0] == '/')
+	{
+		if (access(file, type) == 0)
+		{
+			return True;
+		}
+		else
+		{
+			return False;
+		}
+	}
+	if (type != X_OK && !im)
+	{
+		return False;
+	}
+	if (!im)
+	{
+		path = getenv("PATH");
+	}
+	else
+	{
+		path = PictureGetImagePath();
+	}
+	if (path == NULL || *path == 0)
+	{
+		return False;
+	}
+	full_file = searchPath(path, file, NULL, type);
+	if (full_file)
+	{
+		free(full_file);
+		return True;
+	}
+	return False;
+}
+
 /* ---------------------------- interface functions ------------------------- */
 
 /**********************************************************************
@@ -444,7 +491,7 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 			   by checking allowed function */
 		        SET_SIZE_FIXED(mask, on);
 			SETM_SIZE_FIXED(mask, 1);
-		}		
+		}
 		else if (StrEquals(cond,"HasHandles"))
 		{
 		        SET_HAS_HANDLES(mask,on);
@@ -530,6 +577,7 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 					CLEAR_USER_STATES(mask, state);
 				}
 				SETM_USER_STATES(mask, state);
+				free(condition);
 				tmp = GetNextToken(tmp, &condition);
 			}
 		}
@@ -541,6 +589,7 @@ void CreateConditionMask(char *flags, WindowConditionMask *mask)
 			}
 			else if (sscanf(tmp, "%d", &mask->layer))
 			{
+				free(condition);
 				tmp = GetNextToken (tmp, &condition);
 				if (mask->layer < 0)
 				{
@@ -600,32 +649,32 @@ Bool MatchesConditionMask(FvwmWindow *fw, WindowConditionMask *mask)
 	Bool fMatchesResource;
 	Bool fMatches;
 	FvwmWindow *sf = get_focus_window();
-	
+
 	/* match FixedSize conditional */
 	/* special treatment for FixedSize, because more than just
 	   the is_size_fixed flag makes a window unresizable (width and height
 	   hints etc.) */
-	if(IS_SIZE_FIXED(mask) && 
-	   mask->flag_mask.common.s.is_size_fixed && 
+	if (IS_SIZE_FIXED(mask) &&
+	   mask->flag_mask.common.s.is_size_fixed &&
 	   is_function_allowed(F_RESIZE,NULL,fw,True,False))
 	{
 	        return False;
 	}
-	if(!IS_SIZE_FIXED(mask) &&
+	if (!IS_SIZE_FIXED(mask) &&
            mask->flag_mask.common.s.is_size_fixed &&
 	   !is_function_allowed(F_RESIZE,NULL,fw,True,False))
 	{
 	        return False;
         }
         SETM_SIZE_FIXED(mask, 0);
-	
-	if(IS_UNICONIFIABLE(mask) &&
+
+	if (IS_UNICONIFIABLE(mask) &&
 	   mask->flag_mask.common.s.is_uniconifiable &&
 	   is_function_allowed(F_ICONIFY,NULL,fw,True,False))
 	{
 	        return False;
 	}
-	if(!IS_UNICONIFIABLE(mask) &&
+	if (!IS_UNICONIFIABLE(mask) &&
 	   mask->flag_mask.common.s.is_uniconifiable &&
 	   !is_function_allowed(F_ICONIFY,NULL,fw,True,False))
 	{
@@ -633,13 +682,13 @@ Bool MatchesConditionMask(FvwmWindow *fw, WindowConditionMask *mask)
 	}
 	SETM_IS_UNICONIFIABLE(mask, 0);
 
-	if(IS_UNMAXIMIZABLE(mask) &&
+	if (IS_UNMAXIMIZABLE(mask) &&
 	   mask->flag_mask.common.s.is_unmaximizable &&
 	   is_function_allowed(F_MAXIMIZE,NULL,fw,True,False))
 	{
 	        return False;
 	}
-	if(!IS_UNMAXIMIZABLE(mask) &&
+	if (!IS_UNMAXIMIZABLE(mask) &&
 	   mask->flag_mask.common.s.is_unmaximizable &&
 	   !is_function_allowed(F_MAXIMIZE,NULL,fw,True,False))
 	{
@@ -647,7 +696,7 @@ Bool MatchesConditionMask(FvwmWindow *fw, WindowConditionMask *mask)
 	}
 	SETM_IS_UNMAXIMIZABLE(mask, 0);
 
-	if(IS_UNCLOSABLE(mask) &&
+	if (IS_UNCLOSABLE(mask) &&
 	   mask->flag_mask.common.s.is_unclosable &&
 	   (is_function_allowed(F_CLOSE,NULL,fw,True,False) ||
 	    is_function_allowed(F_DELETE,NULL,fw,True,False) ||
@@ -655,7 +704,7 @@ Bool MatchesConditionMask(FvwmWindow *fw, WindowConditionMask *mask)
 	{
 	        return False;
 	}
-	if(!IS_UNCLOSABLE(mask) &&
+	if (!IS_UNCLOSABLE(mask) &&
 	   mask->flag_mask.common.s.is_unclosable &&
 	   (!is_function_allowed(F_CLOSE,NULL,fw,True,False) &&
 	    !is_function_allowed(F_DELETE,NULL,fw,True,False) &&
@@ -670,7 +719,7 @@ Bool MatchesConditionMask(FvwmWindow *fw, WindowConditionMask *mask)
 	{
 		return False;
 	}
-	
+
 	if (!mask->my_flags.use_circulate_hit && DO_SKIP_CIRCULATE(fw))
 	{
 		return False;
@@ -937,17 +986,17 @@ static void direction_cmd(F_CMD_ARGS,Bool is_scan)
 	int my_cy;
 	int his_cx;
 	int his_cy;
-	int cross=0;
+	int cross = 0;
 	int offset = 0;
 	int distance = 0;
-	int cycle=False;
-	int forward=False;
+	int cycle = False;
+	int forward = False;
 	int score;
-	int best_cross=0;
+	int best_cross = 0;
 	int best_score;
-	int worst_score= -1;
-	FvwmWindow *window;
-	FvwmWindow *best_window;
+	int worst_score = -1;
+	FvwmWindow *tfw;
+	FvwmWindow *fw_best;
 	int dir;
 	int dir2;
 	Bool right_handed=False;
@@ -982,9 +1031,9 @@ static void direction_cmd(F_CMD_ARGS,Bool is_scan)
 		}
 		return;
 	}
-	if(is_scan)
+	if (is_scan)
 	{
-		cycle=True;
+		cycle = True;
 		tmp = PeekToken(action, &action);
 		dir2 = gravity_parse_dir_argument(tmp, NULL, -1);
 		/* if enum direction_type changes, this is trashed. */
@@ -999,7 +1048,7 @@ static void direction_cmd(F_CMD_ARGS,Bool is_scan)
 			}
 			return;
 		}
-		else if(dir2-dir==1 || dir2-dir== -3)
+		else if (dir2-dir==1 || dir2-dir== -3)
 		{
 			right_handed=True;
 		}
@@ -1052,20 +1101,20 @@ static void direction_cmd(F_CMD_ARGS,Bool is_scan)
 
 	/* Next we iterate through all windows and choose the closest one in
 	 * the wanted direction. */
-	best_window = NULL;
+	fw_best = NULL;
 	best_score = -1;
-	for (window = Scr.FvwmRoot.next; window; window = window->next)
+	for (tfw = Scr.FvwmRoot.next; tfw != NULL; tfw = tfw->next)
 	{
 		/* Skip every window that does not match conditionals.  Also
 		 * skip the currently focused window.  That would be too
 		 * close. :) */
-		if (window == fw || !MatchesConditionMask(window, &mask))
+		if (tfw == fw || !MatchesConditionMask(tfw, &mask))
 		{
 			continue;
 		}
 
 		/* Calculate relative location of the window. */
-		get_visible_window_or_icon_geometry(window, &his_g);
+		get_visible_window_or_icon_geometry(tfw, &his_g);
 		his_g.x -= my_cx;
 		his_g.y -= my_cy;
 		his_cx = his_g.x + his_g.width / 2;
@@ -1089,21 +1138,23 @@ static void direction_cmd(F_CMD_ARGS,Bool is_scan)
 		{
 		case DIR_S:
 		case DIR_SW:
-			forward=True;
+			forward = True;
 		case DIR_N:
 		case DIR_NE:
 			cross = -his_cx;
 			offset = (his_cx < 0) ? -his_cx : his_cx;
-			distance = (dir == DIR_N || dir == DIR_NE) ? -his_cy : his_cy;
+			distance = (dir == DIR_N || dir == DIR_NE) ?
+				-his_cy : his_cy;
 			break;
 		case DIR_E: /* E */
 		case DIR_SE: /* SE */
-			forward=True;
+			forward = True;
 		case DIR_W: /* W */
 		case DIR_NW: /* NW */
 			cross = his_cy;
 			offset = (his_cy < 0) ? -his_cy : his_cy;
-			distance = (dir == DIR_W || dir == DIR_NW) ? -his_cx : his_cx;
+			distance = (dir == DIR_W || dir == DIR_NW) ?
+				-his_cx : his_cx;
 			break;
 		case DIR_C:
 			offset = 0;
@@ -1113,67 +1164,77 @@ static void direction_cmd(F_CMD_ARGS,Bool is_scan)
 			break;
 		}
 
-		if(cycle)
+		if (cycle)
+		{
 			offset=0;
-		else if (distance <= 0)	/* Target must be in given direction. */
+		}
+		else if (distance < 0)	/* Target must be in given direction. */
+		{
 			continue;
+		}
+		else if (distance == 0 && dir != DIR_C)
+		{
+			continue;
+		}
 
 		/* Calculate score for this window.  The smaller the better. */
 		score = distance + offset;
-
-		if(!right_handed)
-			cross= -cross;
-
-		if(cycle)
+		if (!right_handed)
 		{
-			int ordered=(forward == (cross<best_cross));
+			cross= -cross;
+		}
+		if (cycle)
+		{
+			int ordered = (forward == (cross < best_cross));
 
-			if (distance<0 && best_score == -1 &&
+			if (distance < 0 && best_score == -1 &&
 				(score < worst_score ||
-				(score==worst_score && ordered)))
+				(score == worst_score && ordered)))
 			{
-				best_window = window;
+				fw_best = tfw;
 				worst_score = score;
 				best_cross = cross;
 			}
-
-			if(score==0 && forward==(cross<0))
-				continue;
-
-			if (distance>=0 &&
-				(best_score == -1 || score < best_score ||
-				(score==best_score && ordered)))
+			if (score == 0 && forward == (cross < 0) &&
+			    dir != DIR_C)
 			{
-				best_window = window;
+				continue;
+			}
+			if (distance >= 0 &&
+				(best_score == -1 || score < best_score ||
+				 (score == best_score && ordered)))
+			{
+				fw_best = tfw;
 				best_score = score;
 				best_cross = cross;
 			}
 		}
 		else
 		{
-			/* windows more than 45 degrees off the direction are heavily
-			 * penalized and will only be chosen if nothing else within a
-			 * million pixels */
+			/* windows more than 45 degrees off the direction are
+			 * heavily penalized and will only be chosen if nothing
+			 * else within a million pixels */
 			if (offset > distance)
 			{
 				score += 1000000;
 			}
-			if (best_score == -1 || score < best_score)
+			if (best_score == -1 || score < best_score ||
+			    (score == best_score && dir == DIR_C))
 			{
-				best_window = window;
+				fw_best = tfw;
 				best_score = score;
 			}
 		}
 	} /* for */
 
-	if (best_window)
+	if (fw_best)
 	{
 		if (cond_rc != NULL)
 		{
 			*cond_rc = COND_RC_OK;
 		}
 		execute_function_override_window(
-			NULL, exc, restofline, 0, best_window);
+			NULL, exc, restofline, 0, fw_best);
 	}
 	else if (cond_rc != NULL)
 	{
@@ -1357,8 +1418,10 @@ void CMD_WindowId(F_CMD_ARGS)
 void CMD_Cond(F_CMD_ARGS)
 {
 	fvwm_cond_func_rc match_rc;
+	char *orig_flags;
 	char *flags;
 	char *restofline;
+	int is_not_reversed = 1;
 
 	if (cond_rc == NULL)
 	{
@@ -1366,36 +1429,45 @@ void CMD_Cond(F_CMD_ARGS)
 		return;
 	}
 	/* Create window mask */
-	flags = CreateFlagString(action, &restofline);
+	orig_flags = CreateFlagString(action, &restofline);
+	flags = orig_flags;
 	if (flags == NULL)
 	{
 		match_rc = COND_RC_NO_MATCH;
 	}
-	else if (StrEquals(flags, "1") || StrEquals(flags, "match"))
-	{
-		match_rc = COND_RC_OK;
-	}
-	else if (StrEquals(flags, "0") || StrEquals(flags, "nomatch"))
-	{
-		match_rc = COND_RC_NO_MATCH;
-	}
-	else if (StrEquals(flags, "-1") || StrEquals(flags, "error"))
-	{
-		match_rc = COND_RC_ERROR;
-	}
 	else
 	{
-		match_rc = COND_RC_NO_MATCH;
+		if (*flags == '!')
+		{
+			is_not_reversed = 0;
+			flags++;
+		}
+		if (StrEquals(flags, "1") || StrEquals(flags, "match"))
+		{
+			match_rc = COND_RC_OK;
+		}
+		else if (StrEquals(flags, "0") || StrEquals(flags, "nomatch"))
+		{
+			match_rc = COND_RC_NO_MATCH;
+		}
+		else if (StrEquals(flags, "-1") || StrEquals(flags, "error"))
+		{
+			match_rc = COND_RC_ERROR;
+		}
+		else
+		{
+			match_rc = COND_RC_NO_MATCH;
+		}
 	}
-	if (*cond_rc == match_rc && restofline != NULL)
+	if ((*cond_rc == match_rc) == is_not_reversed && restofline != NULL)
 	{
 		/* execute the command in root window context; overwrite the
 		 * return code with the return code of the command */
 		execute_function(cond_rc, exc, restofline, 0);
 	}
-	if (flags != NULL)
+	if (orig_flags != NULL)
 	{
-		free(flags);
+		free(orig_flags);
 	}
 
 	return;
@@ -1502,16 +1574,62 @@ void CMD_On(F_CMD_ARGS)
 		{
 			match = exc->type == EXCT_TORESTART;
 		}
+		else if (StrEquals(cond, "x") || StrEquals(cond, "r") ||
+			 StrEquals(cond, "w") || StrEquals(cond, "f") ||
+			 StrEquals(cond, "i"))
+		{
+			char *pattern;
+			int type = X_OK;
+			Bool im = False;
+
+			switch(cond[0])
+			{
+			case 'X':
+			case 'x':
+				type = X_OK;
+				break;
+			case 'R':
+			case 'r':
+				type = R_OK;
+				break;
+			case 'W':
+			case 'w':
+				type = W_OK;
+				break;
+			case 'f':
+			case 'F':
+				type = F_OK;
+				break;
+			case 'i':
+			case 'I':
+				im = True;
+				type = R_OK;
+				break;
+			default:
+				/* cannot happen */
+				break;
+			}
+			tmp = GetNextSimpleOption(tmp, &pattern);
+			if (pattern)
+			{
+				match = cond_check_access(pattern, type, im);
+				free(pattern);
+			}
+			else
+			{
+				error = True;
+			}
+		}
 
 		if (!on)
 		{
 			match = !match;
 		}
+		free(condition);
 		if (error || !match)
 		{
 			break;
 		}
-		free(condition);
 		tmp = GetNextSimpleOption(tmp, &condition);
 	}
 	if (flags != NULL)
