@@ -705,7 +705,7 @@ static void __handle_bpress_on_managed(const exec_context_t *exc)
 
 void HandleButtonPress(const evh_args_t *ea)
 {
-	DBUG("HandleButtonPress","Routine Entered");
+	DBUG("HandleButtonPress", "Routine Entered");
 
 	GrabEm(CRS_NONE, GRAB_PASSIVE);
 	if (__is_bpress_window_handled(ea->exc) == False)
@@ -732,7 +732,7 @@ void HandleButtonRelease(const evh_args_t *ea)
 	int real_modifier;
 	const XEvent *te = ea->exc->x.etrigger;
 
-	DBUG("HandleButtonRelease","Routine Entered");
+	DBUG("HandleButtonRelease", "Routine Entered");
 
 	send_motion = False;
 	stroke_trans (sequence);
@@ -771,7 +771,7 @@ void HandleClientMessage(const evh_args_t *ea)
 	const XEvent *te = ea->exc->x.etrigger;
 	FvwmWindow * const fw = ea->exc->w.fw;
 
-	DBUG("HandleClientMessage","Routine Entered");
+	DBUG("HandleClientMessage", "Routine Entered");
 
 	/* Process GNOME and EWMH Messages */
 	if (GNOME_ProcessClientMessage(ea->exc))
@@ -862,7 +862,7 @@ void HandleConfigureRequest(const evh_args_t *ea)
 	XConfigureRequestEvent cre;
 	FvwmWindow *fw = ea->exc->w.fw;
 
-	DBUG("HandleConfigureRequest","Routine Entered");
+	DBUG("HandleConfigureRequest", "Routine Entered");
 
 	cre = te->xconfigurerequest;
 	/* te->xany.window is te->.xconfigurerequest.parent, so the context
@@ -1223,6 +1223,39 @@ void HandleConfigureRequest(const evh_args_t *ea)
 			GetWindowSizeHints(fw);
 			SET_HAS_NEW_WM_NORMAL_HINTS(fw, 0);
 		}
+		if (!HAS_OVERRIDE_SIZE_HINTS(fw) && (fw->hints.flags & PMaxSize))
+		{
+			/* Java workaround */
+			if (cre.height > fw->hints.max_height &&
+			    fw->hints.max_height <= BROKEN_MAXSIZE_LIMIT)
+			{
+				fw->hints.max_height =
+					DEFAULT_MAX_MAX_WINDOW_HEIGHT;
+				cre.value_mask |= CWHeight;
+			}
+			if (cre.width > fw->hints.max_width &&
+			    fw->hints.max_width <= BROKEN_MAXSIZE_LIMIT)
+			{
+				fw->hints.max_width =
+					DEFAULT_MAX_MAX_WINDOW_WIDTH;
+				cre.value_mask |= CWWidth;
+			}
+		}
+		if (!HAS_OVERRIDE_SIZE_HINTS(fw) && (fw->hints.flags & PMinSize))
+		{
+			if (cre.height < fw->hints.min_height &&
+			    fw->hints.min_height >= BROKEN_MINSIZE_LIMIT)
+			{
+				fw->hints.min_height = 1;
+				cre.value_mask |= CWHeight;
+			}
+			if (cre.width < fw->hints.max_width &&
+			    fw->hints.max_width >= BROKEN_MINSIZE_LIMIT)
+			{
+				fw->hints.min_width = 1;
+				cre.value_mask |= CWWidth;
+			}
+		}
 		if (IS_SHADED(fw) ||
 		    !is_function_allowed(F_MOVE, NULL, fw, False, False))
 		{
@@ -1237,8 +1270,6 @@ void HandleConfigureRequest(const evh_args_t *ea)
 			cre.value_mask &= ~(CWWidth | CWHeight);
 			/* resend the old geometry */
 			do_send_event = True;
-			dw = fw->max_g_defect.width;
-			dh = fw->max_g_defect.width;
 			dw = 0;
 			dh = 0;
 		}
@@ -1410,7 +1441,7 @@ void HandleConfigureRequest(const evh_args_t *ea)
 
 void HandleDestroyNotify(const evh_args_t *ea)
 {
-	DBUG("HandleDestroyNotify","Routine Entered");
+	DBUG("HandleDestroyNotify", "Routine Entered");
 
 	destroy_window(ea->exc->w.fw);
 	EWMH_ManageKdeSysTray(
@@ -1439,7 +1470,7 @@ void HandleEnterNotify(const evh_args_t *ea)
 	const XEvent *te = ea->exc->x.etrigger;
 	FvwmWindow * const fw = ea->exc->w.fw;
 
-	DBUG("HandleEnterNotify","Routine Entered");
+	DBUG("HandleEnterNotify", "Routine Entered");
 	ewp = &te->xcrossing;
 ENTER_DBG((stderr, "++++++++ en (%d): fw 0x%08x w 0x%08x sw 0x%08xmode 0x%x detail 0x%x '%s'\n", ++ecount, (int)fw, (int)ewp->window, (int)ewp->subwindow, ewp->mode, ewp->detail, fw?fw->visible_name:"(none)"));
 
@@ -1809,7 +1840,7 @@ void HandleFocusIn(const evh_args_t *ea)
 	static Bool was_nothing_ever_focused = True;
 	FvwmWindow *fw = ea->exc->w.fw;
 
-	DBUG("HandleFocusIn","Routine Entered");
+	DBUG("HandleFocusIn", "Routine Entered");
 
 	Scr.focus_in_pending_window = NULL;
 	/* This is a hack to make the PointerKey command work */
@@ -1946,7 +1977,7 @@ void HandleFocusOut(const evh_args_t *ea)
 	return;
 }
 
-void __handle_key_event(const evh_args_t *ea, Bool is_release)
+void HandleKeyPress(const evh_args_t *ea)
 {
 	char *action;
 	FvwmWindow *sf;
@@ -1976,24 +2007,8 @@ void __handle_key_event(const evh_args_t *ea, Bool is_release)
 	{
 		context2 = ea->exc->w.wcontext;
 	}
-	if (is_release == False)
-	{
-		if (CheckTwoBindings(
-			    &is_second_binding, Scr.AllBindings, STROKE_ARG(0)
-			    kc, te->xkey.state, GetUnusedModifiers(),
-			    ea->exc->w.wcontext, BIND_KEYRELEASE, context2,
-			    BIND_PKEYRELEASE) != NULL)
-		{
-			MyXGrabKey(dpy);
-		}
-		type1 = BIND_KEYPRESS;
-		type2 = BIND_PKEYPRESS;
-	}
-	else
-	{
-		type1 = BIND_KEYRELEASE;
-		type2 = BIND_PKEYRELEASE;
-	}
+	type1 = BIND_KEYPRESS;
+	type2 = BIND_PKEYPRESS;
 	action = CheckTwoBindings(
 		&is_second_binding, Scr.AllBindings, STROKE_ARG(0) kc,
 		te->xkey.state, GetUnusedModifiers(), ea->exc->w.wcontext,
@@ -2016,10 +2031,6 @@ void __handle_key_event(const evh_args_t *ea, Bool is_release)
 		{
 			exc_destroy_context(exc);
 		}
-		if (is_release == True)
-		{
-			MyXUngrabKey(dpy);
-		}
 		XAllowEvents(dpy, AsyncKeyboard, CurrentTime);
 		return;
 	}
@@ -2033,10 +2044,7 @@ void __handle_key_event(const evh_args_t *ea, Bool is_release)
 
 		e = *te;
 		e.xkey.window = FW_W(sf);
-		FSendEvent(
-			dpy, e.xkey.window, False,
-			(is_release == True) ? KeyReleaseMask : KeyPressMask,
-			&e);
+		FSendEvent(dpy, e.xkey.window, False, KeyPressMask, &e);
 	}
 	else if (fw && te->xkey.window != FW_W(fw))
 	{
@@ -2044,36 +2052,19 @@ void __handle_key_event(const evh_args_t *ea, Bool is_release)
 
 		e = *te;
 		e.xkey.window = FW_W(fw);
-		FSendEvent(
-			dpy, e.xkey.window, False,
-			(is_release == True) ? KeyReleaseMask : KeyPressMask,
-			&e);
+		FSendEvent(dpy, e.xkey.window, False, KeyPressMask, &e);
 	}
 	XAllowEvents(dpy, AsyncKeyboard, CurrentTime);
 
 	return;
 }
 
-void HandleKeyPress(const evh_args_t *ea)
-{
-	__handle_key_event(ea, False);
-
-	return;
-}
-
-void HandleKeyRelease(const evh_args_t *ea)
-{
-	__handle_key_event(ea, True);
-
-	return;
-}
-
 void HandleLeaveNotify(const evh_args_t *ea)
 {
 	const XEvent *te = ea->exc->x.etrigger;
 	FvwmWindow * const fw = ea->exc->w.fw;
 
-	DBUG("HandleLeaveNotify","Routine Entered");
+	DBUG("HandleLeaveNotify", "Routine Entered");
 
 ENTER_DBG((stderr, "-------- ln (%d): fw 0x%08x w 0x%08x sw 0x%08x mode 0x%x detail 0x%x '%s'\n", ++ecount, (int)fw, (int)te->xcrossing.window, (int)te->xcrossing.subwindow, te->xcrossing.mode, te->xcrossing.detail, fw?fw->visible_name:"(none)"));
 	/* Ignore LeaveNotify events while a window is resized or moved as a
@@ -2173,7 +2164,7 @@ void HandleMapNotify(const evh_args_t *ea)
 	const XEvent *te = ea->exc->x.etrigger;
 	FvwmWindow * const fw = ea->exc->w.fw;
 
-	DBUG("HandleMapNotify","Routine Entered");
+	DBUG("HandleMapNotify", "Routine Entered");
 
 	if (!fw)
 	{
@@ -2277,7 +2268,7 @@ void HandleMappingNotify(const evh_args_t *ea)
 
 void HandleMapRequest(const evh_args_t *ea)
 {
-	DBUG("HandleMapRequest","Routine Entered");
+	DBUG("HandleMapRequest", "Routine Entered");
 
 	if (fFvwmInStartup)
 	{
@@ -2512,7 +2503,7 @@ void HandleMapRequestKeepRaised(
 #ifdef HAVE_STROKE
 void HandleMotionNotify(const evh_args_t *ea)
 {
-	DBUG("HandleMotionNotify","Routine Entered");
+	DBUG("HandleMotionNotify", "Routine Entered");
 
 	if (send_motion == True)
 	{
@@ -2537,7 +2528,7 @@ void HandlePropertyNotify(const evh_args_t *ea)
 	char *urgency_action = NULL;
 	FvwmWindow * const fw = ea->exc->w.fw;
 
-	DBUG("HandlePropertyNotify","Routine Entered");
+	DBUG("HandlePropertyNotify", "Routine Entered");
 
 	if (te->xproperty.window == Scr.Root &&
 	    te->xproperty.state == PropertyNewValue &&
@@ -2590,7 +2581,8 @@ void HandlePropertyNotify(const evh_args_t *ea)
 				}
 			}
 			if (t->icon_alphaPixmap != None ||
-			    (cs >= 0 && Colorset[cs].icon_alpha_percent < 100) ||
+			    (cs >= 0 &&
+			     Colorset[cs].icon_alpha_percent < 100) ||
 			    CSET_IS_TRANSPARENT_PR(b_cs) ||
 			    (!IS_ICON_SHAPED(t) &&
 			     t->icon_background_padding > 0))
@@ -2653,15 +2645,23 @@ void HandlePropertyNotify(const evh_args_t *ea)
 		FlocaleGetNameProperty(XGetWMName, dpy, FW_W(fw), &new_name);
 		if (new_name.name == NULL)
 		{
+			FlocaleFreeNameProperty(&new_name);
 			return;
 		}
-		free_window_names (fw, True, False);
-		fw->name = new_name;
-		if (fw->name.name &&
-		    strlen(fw->name.name) > MAX_WINDOW_NAME_LEN)
+		if (strlen(new_name.name) > MAX_WINDOW_NAME_LEN)
 		{
-			(fw->name.name)[MAX_WINDOW_NAME_LEN] = 0;
+			/* limit to prevent hanging X server */
+			(new_name.name)[MAX_WINDOW_NAME_LEN] = 0;
 		}
+		if (fw->name.name && strcmp(new_name.name, fw->name.name) == 0)
+		{
+			/* migo: some apps update their names every second */
+			FlocaleFreeNameProperty(&new_name);
+			return;
+		}
+
+		free_window_names(fw, True, False);
+		fw->name = new_name;
 		SET_NAME_CHANGED(fw, 1);
 		if (fw->name.name == NULL)
 		{
@@ -2669,6 +2669,7 @@ void HandlePropertyNotify(const evh_args_t *ea)
 		}
 		setup_visible_name(fw, False);
 		BroadcastWindowIconNames(fw, True, False);
+
 		/* fix the name in the title bar */
 		if (!IS_ICONIFIED(fw))
 		{
@@ -2700,20 +2701,29 @@ void HandlePropertyNotify(const evh_args_t *ea)
 			XGetWMIconName, dpy, FW_W(fw), &new_name);
 		if (new_name.name == NULL)
 		{
+			FlocaleFreeNameProperty(&new_name);
 			return;
 		}
-		free_window_names(fw, False, True);
-		fw->icon_name = new_name;
-		if (fw->icon_name.name && strlen(fw->icon_name.name) >
-		    MAX_ICON_NAME_LEN)
+		if (new_name.name && strlen(new_name.name) > MAX_ICON_NAME_LEN)
 		{
 			/* limit to prevent hanging X server */
-			(fw->icon_name.name)[MAX_ICON_NAME_LEN] = 0;
+			(new_name.name)[MAX_ICON_NAME_LEN] = 0;
 		}
+		if (fw->icon_name.name &&
+			strcmp(new_name.name, fw->icon_name.name) == 0)
+		{
+			/* migo: some apps update their names every second */
+			FlocaleFreeNameProperty(&new_name);
+			return;
+		}
+
+		free_window_names(fw, False, True);
+		fw->icon_name = new_name;
 		SET_WAS_ICON_NAME_PROVIDED(fw, 1);
 		if (fw->icon_name.name == NULL)
 		{
-			fw->icon_name .name= fw->name.name;
+			/* currently never happens */
+			fw->icon_name.name = fw->name.name;
 			SET_WAS_ICON_NAME_PROVIDED(fw, 0);
 		}
 		setup_visible_name(fw, True);
@@ -2725,7 +2735,8 @@ void HandlePropertyNotify(const evh_args_t *ea)
 	case XA_WM_HINTS:
 		flush_property_notify(XA_WM_HINTS, FW_W(fw));
 		/* clasen@mathematik.uni-freiburg.de - 02/01/1998 - new -
-		   the urgency flag is an ICCCM 2.0 addition to the WM_HINTS. */
+		 * the urgency flag is an ICCCM 2.0 addition to the WM_HINTS.
+		 */
 		old_wmhints_flags = 0;
 		if (fw->wmhints)
 		{
@@ -2745,13 +2756,13 @@ void HandlePropertyNotify(const evh_args_t *ea)
 		if ((fw->wmhints->flags & IconPixmapHint) ||
 		    (old_wmhints_flags & IconPixmapHint))
 		{
-ICON_DBG((stderr,"hpn: iph changed (%d) '%s'\n", !!(int)(fw->wmhints->flags & IconPixmapHint), fw->name));
+ICON_DBG((stderr, "hpn: iph changed (%d) '%s'\n", !!(int)(fw->wmhints->flags & IconPixmapHint), fw->name));
 			has_icon_pixmap_hint_changed = True;
 		}
 		if ((fw->wmhints->flags & IconWindowHint) ||
 		    (old_wmhints_flags & IconWindowHint))
 		{
-ICON_DBG((stderr,"hpn: iwh changed (%d) '%s'\n", !!(int)(fw->wmhints->flags & IconWindowHint), fw->name));
+ICON_DBG((stderr, "hpn: iwh changed (%d) '%s'\n", !!(int)(fw->wmhints->flags & IconWindowHint), fw->name));
 			has_icon_window_hint_changed = True;
 			SET_USE_EWMH_ICON(fw, False);
 		}
@@ -2761,7 +2772,7 @@ ICON_DBG((stderr,"hpn: iwh changed (%d) '%s'\n", !!(int)(fw->wmhints->flags & Ic
 		{
 			if (ICON_OVERRIDE_MODE(fw) == ICON_OVERRIDE)
 			{
-ICON_DBG((stderr,"hpn: icon override '%s'\n", fw->name));
+ICON_DBG((stderr, "hpn: icon override '%s'\n", fw->name));
 				has_icon_changed = False;
 			}
 			else if (ICON_OVERRIDE_MODE(fw) ==
@@ -2772,7 +2783,7 @@ ICON_DBG((stderr,"hpn: icon override '%s'\n", fw->name));
 					if (WAS_ICON_HINT_PROVIDED(fw) ==
 					    ICON_HINT_MULTIPLE)
 					{
-ICON_DBG((stderr,"hpn: using further iph '%s'\n", fw->name));
+ICON_DBG((stderr, "hpn: using further iph '%s'\n", fw->name));
 						has_icon_changed = True;
 					}
 					else  if (fw->icon_bitmap_file ==
@@ -2780,7 +2791,7 @@ ICON_DBG((stderr,"hpn: using further iph '%s'\n", fw->name));
 						  fw->icon_bitmap_file ==
 						  Scr.DefaultIcon)
 					{
-ICON_DBG((stderr,"hpn: using first iph '%s'\n", fw->name));
+ICON_DBG((stderr, "hpn: using first iph '%s'\n", fw->name));
 						has_icon_changed = True;
 					}
 					else
@@ -2789,24 +2800,24 @@ ICON_DBG((stderr,"hpn: using first iph '%s'\n", fw->name));
 						 * hint if the application did
 						 * not provide it from the
 						 * start */
-ICON_DBG((stderr,"hpn: first iph ignored '%s'\n", fw->name));
+ICON_DBG((stderr, "hpn: first iph ignored '%s'\n", fw->name));
 						has_icon_changed = False;
 					}
 				}
 				else if (has_icon_window_hint_changed)
 				{
-ICON_DBG((stderr,"hpn: using iwh '%s'\n", fw->name));
+ICON_DBG((stderr, "hpn: using iwh '%s'\n", fw->name));
 					has_icon_changed = True;
 				}
 				else
 				{
-ICON_DBG((stderr,"hpn: iwh not changed, hint ignored '%s'\n", fw->name));
+ICON_DBG((stderr, "hpn: iwh not changed, hint ignored '%s'\n", fw->name));
 					has_icon_changed = False;
 				}
 			}
 			else /* NO_ICON_OVERRIDE */
 			{
-ICON_DBG((stderr,"hpn: using hint '%s'\n", fw->name));
+ICON_DBG((stderr, "hpn: using hint '%s'\n", fw->name));
 				has_icon_changed = True;
 			}
 
@@ -2817,7 +2828,7 @@ ICON_DBG((stderr,"hpn: using hint '%s'\n", fw->name));
 
 			if (has_icon_changed)
 			{
-ICON_DBG((stderr,"hpn: icon changed '%s'\n", fw->name));
+ICON_DBG((stderr, "hpn: icon changed '%s'\n", fw->name));
 				/* Okay, the icon hint has changed and style
 				 * options tell us to honour this change.  Now
 				 * let's see if we have to use the application
@@ -2959,7 +2970,7 @@ void HandleShapeNotify(const evh_args_t *ea)
 {
 	FvwmWindow * const fw = ea->exc->w.fw;
 
-	DBUG("HandleShapeNotify","Routine Entered");
+	DBUG("HandleShapeNotify", "Routine Entered");
 
 	if (FShapesSupported)
 	{
@@ -2992,7 +3003,7 @@ void HandleUnmapNotify(const evh_args_t *ea)
 	Bool must_return = False;
 	FvwmWindow * const fw = ea->exc->w.fw;
 
-	DBUG("HandleUnmapNotify","Routine Entered");
+	DBUG("HandleUnmapNotify", "Routine Entered");
 
 	/* Don't ignore events as described below. */
 	if (te->xunmap.event != te->xunmap.window &&
@@ -3127,7 +3138,7 @@ void HandleVisibilityNotify(const evh_args_t *ea)
 {
 	FvwmWindow * const fw = ea->exc->w.fw;
 
-	DBUG("HandleVisibilityNotify","Routine Entered");
+	DBUG("HandleVisibilityNotify", "Routine Entered");
 
 	if (fw && ea->exc->x.etrigger->xvisibility.window == FW_W_FRAME(fw))
 	{
@@ -3181,7 +3192,6 @@ void InitEventHandlerJumpTable(void)
 	EventHandlerJumpTable[ClientMessage] =    HandleClientMessage;
 	EventHandlerJumpTable[PropertyNotify] =   HandlePropertyNotify;
 	EventHandlerJumpTable[KeyPress] =         HandleKeyPress;
-	EventHandlerJumpTable[KeyRelease] =       HandleKeyRelease;
 	EventHandlerJumpTable[VisibilityNotify] = HandleVisibilityNotify;
 	EventHandlerJumpTable[ColormapNotify] =   HandleColormapNotify;
 	if (FShapesSupported)
@@ -3210,7 +3220,7 @@ void dispatch_event(XEvent *e)
 	Window w = e->xany.window;
 	FvwmWindow *fw;
 
-	DBUG("dispatch_event","Routine Entered");
+	DBUG("dispatch_event", "Routine Entered");
 
 	XFlush(dpy);
 	if (w == Scr.Root)
@@ -3260,7 +3270,7 @@ void dispatch_event(XEvent *e)
 	 */
 	alloca(0);
 #endif
-	DBUG("dispatch_event","Leaving Routine");
+	DBUG("dispatch_event", "Leaving Routine");
 
 	return;
 }
@@ -3269,7 +3279,7 @@ void HandleEvents(void)
 {
 	XEvent ev;
 
-	DBUG("HandleEvents","Routine Entered");
+	DBUG("HandleEvents", "Routine Entered");
 	STROKE_CODE(send_motion = False);
 	while (!isTerminated)
 	{
@@ -3313,7 +3323,7 @@ int My_XNextEvent(Display *dpy, XEvent *event)
 	static struct timeval timeout;
 	static struct timeval *timeoutP = &timeout;
 
-	DBUG("My_XNextEvent","Routine Entered");
+	DBUG("My_XNextEvent", "Routine Entered");
 
 	/* include this next bit if HandleModuleInput() gets called anywhere
 	 * else with queueing turned on.  Because this routine is the only
@@ -3333,8 +3343,9 @@ int My_XNextEvent(Display *dpy, XEvent *event)
 	 * there are events in the queue */
 	if (FPending(dpy))
 	{
-		DBUG("My_XNextEvent","taking care of queued up events"
-		     " & returning (1)");
+		DBUG(
+			"My_XNextEvent", "taking care of queued up events"
+			" & returning (1)");
 		FNextEvent(dpy, event);
 		return 1;
 	}
@@ -3343,7 +3354,7 @@ int My_XNextEvent(Display *dpy, XEvent *event)
 	 * dies, and the SIGCHLD handler now reaps them automatically. We
 	 * should therefore never see a zombie */
 #if 0
-	DBUG("My_XNextEvent","no X events waiting - about to reap children");
+	DBUG("My_XNextEvent", "no X events waiting - about to reap children");
 	/* Zap all those zombies! */
 	/* If we get to here, then there are no X events waiting to be
 	 * processed. Just take a moment to check for dead children. */
@@ -3437,7 +3448,7 @@ int My_XNextEvent(Display *dpy, XEvent *event)
 			}
 		}
 
-		DBUG("My_XNextEvent","waiting for module input/output");
+		DBUG("My_XNextEvent", "waiting for module input/output");
 		num_fd = fvwmSelect(
 			fd_width, &in_fdset, &out_fdset, 0, timeoutP);
 		if (is_waiting_for_scheduled_command)
@@ -3527,7 +3538,7 @@ int My_XNextEvent(Display *dpy, XEvent *event)
 		return 1;
 	}
 
-	DBUG("My_XNextEvent","leaving My_XNextEvent");
+	DBUG("My_XNextEvent", "leaving My_XNextEvent");
 	return 0;
 }
 
