@@ -16,17 +16,39 @@
  */
 
 /* ************************************************************************
- * An implementation of the Extended Window Manager Hints specification
- * version 1.0, 1.1 and 1.2
- *
+ * An partial implementation of the Extended Window Manager Hints specification
  * http://www.freedesktop.org/standards/wm-spec.html
  *
+ * Not Implemented (draft 1.3 - 2003-01-03):
+ *
+ * _NET_DESKTOP_LAYOUT
+ *
+ * _NET_SHOWING_DESKTOP
+ *
+ * _NET_MOVERESIZE_WINDOW
+ *
+ * Some _NET_WINDOW_TYPE:
+ *         _NET_WM_WINDOW_TYPE_SPLASH
+ *         _NET_WM_WINDOW_TYPE_UTILITIES
+ *
+ * One _NET_WINDOW_STATE:
+ *         _NET_WM_STATE_FULLSCREEN
+ *
+ * One _NET_WM_ALLOWED_ACTIONS: _NET_WM_ACTION_FULLSCREEN
+ *
+ * The kill huge process protocol: _NET_WM_PID and _NET_WM_PING
+ *
+ * _NET_WM_HANDLED_ICONS (what to do? Nothing?)
+ *
+ * Problems:
+ * - _NET_WM_WINDOW_TYPE_TOOLBAR is interpreted in a different way
+ * in GNOME (the spec) and in KDE 2/3.0 (~ simple dock?).
+ * - What is a window of TYPE MENU ?
+ *
  * ************************************************************************/
 
 #include "config.h"
 
-#ifdef HAVE_EWMH
-
 #include <stdio.h>
 
 #include "libs/fvwmlib.h"
@@ -72,6 +94,8 @@ ewmhInfo ewmhc =
 #define ENTRY(name, type, func) \
  {name, None, type, func}
 
+/* WARNING: lists must be in "name" alphabetic order! */
+
 /* EWMH_ATOM_LIST_CLIENT_ROOT
  * net atoms that can be send (Client Message) by a client and do not
  * need a window to operate */
@@ -104,7 +128,10 @@ ewmh_atom ewmh_atom_client_win[] =
  * too */
 ewmh_atom ewmh_atom_wm_state[] =
 {
-  ENTRY("_NET_WM_STATE_FULLSCREEN",      XA_ATOM,   ewmh_WMStateFullScreen),
+  ENTRY("_NET_WM_STATE_ABOVE",           XA_ATOM,   ewmh_WMStateStaysOnTop),
+  ENTRY("_NET_WM_STATE_BELOW",           XA_ATOM,   ewmh_WMStateStaysOnBottom),
+  /* not yet implemented */
+  /*ENTRY("_NET_WM_STATE_FULLSCREEN",      XA_ATOM,   ewmh_WMStateFullScreen),*/
   ENTRY("_NET_WM_STATE_HIDDEN",          XA_ATOM,   ewmh_WMStateHidden),
   ENTRY("_NET_WM_STATE_MAXIMIZED_HORIZ", XA_ATOM,   ewmh_WMStateMaxHoriz),
   ENTRY("_NET_WM_STATE_MAXIMIZED_HORZ",  XA_ATOM,   ewmh_WMStateMaxHoriz),
@@ -126,6 +153,7 @@ ewmh_atom ewmh_atom_allowed_actions[] =
   ENTRY("_NET_WM_ACTION_CLOSE",          XA_ATOM, ewmh_AllowsClose),
   ENTRY("_NET_WM_ACTION_MAXIMIZE_HORZ",  XA_ATOM, ewmh_AllowsMaximize),
   ENTRY("_NET_WM_ACTION_MAXIMIZE_VERT",  XA_ATOM, ewmh_AllowsMaximize),
+  ENTRY("_NET_WM_ACTION_MINIMIZE",       XA_ATOM, ewmh_AllowsMinimize),
   ENTRY("_NET_WM_ACTION_MOVE",           XA_ATOM, ewmh_AllowsMove),
   ENTRY("_NET_WM_ACTION_RESIZE",         XA_ATOM, ewmh_AllowsResize),
   ENTRY("_NET_WM_ACTION_SHADE",          XA_ATOM, ewmh_AllowsYes),
@@ -363,7 +391,7 @@ int check_desk(void)
 
   for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
   {
-    if (!IS_STICKY_ON_DESK(t))
+    if (!IS_STICKY_ACROSS_DESKS(t))
       d = max(d,t->Desk);
   }
   return d;
@@ -430,7 +458,7 @@ void EWMH_SetWMDesktop(FvwmWindow *fwin)
 {
   CARD32 desk = fwin->Desk;
 
-  if (IS_STICKY_ON_DESK(fwin))
+  if (IS_STICKY_ACROSS_DESKS(fwin))
   {
     desk = 0xFFFFFFFE;
   }
@@ -729,7 +757,7 @@ void ewmh_ComputeAndSetWorkArea(void)
 
   for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
   {
-    if (DO_EWMH_IGNORE_STRUT_HINTS(t) || !IS_STICKY_ON_PAGE(t))
+    if (DO_EWMH_IGNORE_STRUT_HINTS(t) || !IS_STICKY_ACROSS_PAGES(t))
       continue;
     left = max(left, t->strut.left);
     right = max(right, t->strut.right);
@@ -767,7 +795,7 @@ void ewmh_HandleDynamicWorkArea(void)
 
   for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
   {
-    if (DO_EWMH_IGNORE_STRUT_HINTS(t) || !IS_STICKY_ON_PAGE(t))
+    if (DO_EWMH_IGNORE_STRUT_HINTS(t) || !IS_STICKY_ACROSS_PAGES(t))
       continue;
     dyn_left = max(dyn_left, t->dyn_strut.left);
     dyn_right = max(dyn_right, t->dyn_strut.right);
@@ -936,7 +964,12 @@ Bool ewmh_AllowsYes(EWMH_CMD_ARGS)
 
 Bool ewmh_AllowsClose(EWMH_CMD_ARGS)
 {
-  return is_function_allowed(F_CLOSE, NULL, fwin, False, False);
+  return is_function_allowed(F_CLOSE, NULL, fwin, True, False);
+}
+
+Bool ewmh_AllowsMinimize(EWMH_CMD_ARGS)
+{
+  return is_function_allowed(F_ICONIFY, NULL, fwin, True, False);
 }
 
 Bool ewmh_AllowsMaximize(EWMH_CMD_ARGS)
@@ -996,13 +1029,14 @@ int ewmh_HandleDesktop(EWMH_CMD_ARGS)
   SSET_LAYER(*style, 0);
   style->flags.use_layer = 1;
   style->flag_mask.use_layer = 1;
+  style->change_mask.use_layer = 1;
 
-  S_SET_IS_STICKY_ON_PAGE(SCF(*style), 1);
-  S_SET_IS_STICKY_ON_PAGE(SCM(*style), 1);
-  S_SET_IS_STICKY_ON_PAGE(SCC(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCF(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCM(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
 
   S_SET_IS_FIXED(SCF(*style), 1);
   S_SET_IS_FIXED(SCM(*style), 1);
@@ -1016,6 +1050,14 @@ int ewmh_HandleDesktop(EWMH_CMD_ARGS)
   S_SET_DO_CIRCULATE_SKIP(SCM(*style), 1);
   S_SET_DO_CIRCULATE_SKIP(SCC(*style), 1);
 
+  S_SET_IS_UNICONIFIABLE(SCF(*style), 1);
+  S_SET_IS_UNICONIFIABLE(SCM(*style), 1);
+  S_SET_IS_UNICONIFIABLE(SCC(*style), 1);
+
+  S_SET_IS_UNMAXIMIZABLE(SCF(*style), 1);
+  S_SET_IS_UNMAXIMIZABLE(SCM(*style), 1);
+  S_SET_IS_UNMAXIMIZABLE(SCC(*style), 1);
+
   /* No border */
   SSET_BORDER_WIDTH(*style, 0);
   style->flags.has_border_width = 1;
@@ -1075,12 +1117,12 @@ int ewmh_HandleDock(EWMH_CMD_ARGS)
 {
   fwin->ewmh_window_type = EWMH_WINDOW_TYPE_DOCK_ID;
 
-  S_SET_IS_STICKY_ON_PAGE(SCF(*style), 1);
-  S_SET_IS_STICKY_ON_PAGE(SCM(*style), 1);
-  S_SET_IS_STICKY_ON_PAGE(SCC(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCF(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCM(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
 
   S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
   S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
@@ -1090,6 +1132,32 @@ int ewmh_HandleDock(EWMH_CMD_ARGS)
   S_SET_DO_CIRCULATE_SKIP(SCM(*style), 1);
   S_SET_DO_CIRCULATE_SKIP(SCC(*style), 1);
 
+  S_SET_IS_UNICONIFIABLE(SCF(*style), 1);
+  S_SET_IS_UNICONIFIABLE(SCM(*style), 1);
+  S_SET_IS_UNICONIFIABLE(SCC(*style), 1);
+
+  S_SET_IS_UNMAXIMIZABLE(SCF(*style), 1);
+  S_SET_IS_UNMAXIMIZABLE(SCM(*style), 1);
+  S_SET_IS_UNMAXIMIZABLE(SCC(*style), 1);
+
+  if (fwin->ewmh_hint_layer == -1)
+  {
+	  fwin->ewmh_hint_layer = Scr.TopLayer;
+	  if (DO_EWMH_USE_STACKING_HINTS(style))
+	  {
+		  SSET_LAYER(*style, Scr.TopLayer);
+		  style->flags.use_layer = 1;
+		  style->flag_mask.use_layer = 1;
+		  style->change_mask.use_layer = 1;
+	  }
+	  else if (!style->change_mask.use_layer)
+	  {
+		  SSET_LAYER(*style, Scr.DefaultLayer);
+		  style->flags.use_layer = 1;
+		  style->flag_mask.use_layer = 1;
+		  style->change_mask.use_layer = 1;
+	  }
+  }
   /* no title ? MWM hints should be used by the app but ... */
 
   return 1;
@@ -1099,12 +1167,14 @@ int ewmh_HandleMenu(EWMH_CMD_ARGS)
 {
   fwin->ewmh_window_type = EWMH_WINDOW_TYPE_MENU_ID;
 
-  S_SET_IS_STICKY_ON_PAGE(SCF(*style), 1);
-  S_SET_IS_STICKY_ON_PAGE(SCM(*style), 1);
-  S_SET_IS_STICKY_ON_PAGE(SCC(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCF(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCM(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCC(*style), 1);
+  /* ???? */
+
+  S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
 
   S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
   S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
@@ -1142,12 +1212,14 @@ int ewmh_HandleToolBar(EWMH_CMD_ARGS)
 {
   fwin->ewmh_window_type = EWMH_WINDOW_TYPE_TOOLBAR_ID;
 
-  S_SET_IS_STICKY_ON_PAGE(SCF(*style), 1);
-  S_SET_IS_STICKY_ON_PAGE(SCM(*style), 1);
-  S_SET_IS_STICKY_ON_PAGE(SCC(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCF(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCM(*style), 1);
-  S_SET_IS_STICKY_ON_DESK(SCC(*style), 1);
+  /* this ok for KDE 2 (and 3??) but I do not think that a toolbar
+     should be sticky */
+  S_SET_IS_STICKY_ACROSS_PAGES(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_PAGES(SCC(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCF(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCM(*style), 1);
+  S_SET_IS_STICKY_ACROSS_DESKS(SCC(*style), 1);
 
   S_SET_DO_WINDOW_LIST_SKIP(SCF(*style), 1);
   S_SET_DO_WINDOW_LIST_SKIP(SCM(*style), 1);
@@ -1432,4 +1504,3 @@ void EWMH_DLOG(char *msg, ...)
 }
 #endif
 
-#endif /* HAVE_EWMH */
