@@ -8,17 +8,16 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "config.h"
 
-#ifdef HAVE_EWMH
 #include <stdio.h>
 #include <stdlib.h>
 #include <X11/Xlib.h>
@@ -67,7 +66,7 @@ void EWMH_SetVisibleName(FvwmWindow *fwin, Bool is_icon_name)
 					    EWMH_ATOM_LIST_FVWM_WIN);
 			return;
 		}
-		if (fwin->icon_font != NULL)
+		if (IS_ICON_FONT_LOADED(fwin) && fwin->icon_font != NULL)
 		{
 			fc = fwin->icon_font->str_fc;
 		}
@@ -83,7 +82,7 @@ void EWMH_SetVisibleName(FvwmWindow *fwin, Bool is_icon_name)
 					    EWMH_ATOM_LIST_FVWM_WIN);
 			return;
 		}
-		if (fwin->title_font != NULL)
+		if (IS_WINDOW_FONT_LOADED(fwin) && fwin->title_font != NULL)
 		{
 			fc = fwin->title_font->str_fc;
 		}
@@ -127,25 +126,36 @@ int EWMH_WMIconName(EWMH_CMD_ARGS)
 	if (!FiconvSupport)
 		return 0;
 
-	val = ewmh_AtomGetByName(FW_W(fwin), "_NET_WM_ICON_NAME",
-				 EWMH_ATOM_LIST_PROPERTY_NOTIFY, &size);
+	val = ewmh_AtomGetByName(
+		FW_W(fwin), "_NET_WM_ICON_NAME",
+		EWMH_ATOM_LIST_PROPERTY_NOTIFY, &size);
 
 	if (val == NULL)
 	{
 		SET_HAS_EWMH_WM_ICON_NAME(fwin,0);
 		return 0;
 	}
-	if (fwin->icon_font != NULL)
+	if (IS_ICON_FONT_LOADED(fwin) && fwin->icon_font != NULL)
 	{
 		fc = fwin->icon_font->str_fc;
 	}
 
 	tmp_str = (char *)FiconvUtf8ToCharset(
-					dpy, fc, (const char *) val, size);
+		dpy, fc, (const char *) val, size);
 	free(val);
 	if (tmp_str == NULL)
 	{
-		SET_HAS_EWMH_WM_ICON_NAME(fwin,0);
+		SET_HAS_EWMH_WM_ICON_NAME(fwin, 0);
+		return 0;
+	}
+	if (strlen(tmp_str) > MAX_ICON_NAME_LEN)
+	{
+		tmp_str[MAX_ICON_NAME_LEN] = 0;
+	}
+	if (fwin->icon_name.name && strcmp(tmp_str, fwin->icon_name.name) == 0)
+	{
+		/* migo: some apps update their names every second */  
+		free(tmp_str);
 		return 0;
 	}
 
@@ -166,12 +176,6 @@ int EWMH_WMIconName(EWMH_CMD_ARGS)
 		return 1;
 	}
 
-	if (fwin->icon_name.name &&
-	    strlen(fwin->icon_name.name) > MAX_ICON_NAME_LEN)
-	{
-		(fwin->icon_name.name)[MAX_ICON_NAME_LEN] = 0;
-	}
-
 	setup_visible_name(fwin, True);
 	EWMH_SetVisibleName(fwin, True);
 	BroadcastWindowIconNames(fwin, False, True);
@@ -189,30 +193,44 @@ int EWMH_WMName(EWMH_CMD_ARGS)
 	if (!FiconvSupport)
 		return 0;
 
-	val = ewmh_AtomGetByName(FW_W(fwin), "_NET_WM_NAME",
-				 EWMH_ATOM_LIST_PROPERTY_NOTIFY, &size);
+	val = ewmh_AtomGetByName(
+		FW_W(fwin), "_NET_WM_NAME",
+		EWMH_ATOM_LIST_PROPERTY_NOTIFY, &size);
 
 	if (val == NULL)
 	{
 		SET_HAS_EWMH_WM_NAME(fwin,0);
 		return 0;
 	}
-	if (fwin->title_font != NULL)
+	if (IS_WINDOW_FONT_LOADED(fwin) && fwin->title_font != NULL)
 	{
 		fc = fwin->title_font->str_fc;
 	}
 
 	tmp_str = (char *)FiconvUtf8ToCharset(
-					dpy, fc, (const char *) val, size);
+		dpy, fc, (const char *) val, size);
 	free(val);
 	if (tmp_str == NULL)
 	{
 		SET_HAS_EWMH_WM_NAME(fwin,0);
 		return 0;
 	}
+	if (strlen(tmp_str) > MAX_WINDOW_NAME_LEN)
+	{
+		tmp_str[MAX_WINDOW_NAME_LEN] = 0;
+	}
+	if (fwin->name.name && strcmp(tmp_str, fwin->name.name) == 0)
+	{
+		/* migo: some apps update their names every second */  
+		free(tmp_str);
+		return 0;
+	}
 
 	if (ev != NULL)
+	{
+		/* client message */
 		free_window_names(fwin, True, False);
+	}
 
 	fwin->name.name = tmp_str;
 	SET_HAS_EWMH_WM_NAME(fwin, 1);
@@ -222,22 +240,17 @@ int EWMH_WMName(EWMH_CMD_ARGS)
 		return 1;
 	}
 
-	if (fwin->name.name && strlen(fwin->name.name) > MAX_WINDOW_NAME_LEN)
-	{
-		(fwin->name.name[MAX_WINDOW_NAME_LEN]) = 0;
-	}
-
 	setup_visible_name(fwin, False);
 	SET_NAME_CHANGED(fwin, 1);
 	EWMH_SetVisibleName(fwin, False);
 	BroadcastWindowIconNames(fwin, True, False);
 
 	/* fix the name in the title bar */
-	if(!IS_ICONIFIED(fwin))
+	if (!IS_ICONIFIED(fwin))
 	{
 		border_draw_decorations(
-		  fwin, PART_TITLE, (Scr.Hilite == fwin),
-		  True, CLEAR_ALL, NULL, NULL);
+			fwin, PART_TITLE, (Scr.Hilite == fwin),
+			True, CLEAR_ALL, NULL, NULL);
 	}
 
 	if (!WAS_ICON_NAME_PROVIDED(fwin))
@@ -266,45 +279,55 @@ void EWMH_SetDesktopNames(void)
 	unsigned char *val;
 
 	if (!FiconvSupport)
+	{
 		return;
+	}
 
 	d = Scr.Desktops->next;
 	/* skip negative desk */
 	while (d != NULL && d->desk < 0)
+	{
 		d = d->next;
+	}
 	s = d;
 	while (d != NULL && d->name != NULL && d->desk == nbr)
 	{
 		nbr++;
-		len += strlen(d->name) + 1;
 		d = d->next;
 	}
 	if (nbr == 0)
+	{
 		return;
-
-	val = (unsigned char *)safemalloc(len);
+	}
 	names = (void *)safemalloc(sizeof(*names)*nbr);
 	for (i = 0; i < nbr; i++)
 	{
-		names[i] =
-			(unsigned char *)FiconvCharsetToUtf8(dpy, NULL,
-							     s->name,
-							     strlen(s->name));
+		names[i] = (unsigned char *)FiconvCharsetToUtf8(
+			dpy, NULL, s->name, strlen(s->name));
+		if (names[i])
+		{
+			len += strlen(names[i]) + 1;
+		}
+		else
+		{
+			len++;
+		}
 		s = s->next;
 	}
+	val = (unsigned char *)safemalloc(len);
 	for (i = 0; i < nbr; i++)
 	{
 		if (names[i] != NULL)
 		{
-			memcpy(&val[j], names[i], strlen(names[i])+1);
-			j += strlen(names[i]) + 1;
+			memcpy(&val[j], names[i], strlen(names[i]));
+			j += strlen(names[i]);
 			free(names[i]);
 		}
+		val[j++] = '\0';
 	}
+	ewmh_ChangeProperty(
+		Scr.Root, "_NET_DESKTOP_NAMES", EWMH_ATOM_LIST_CLIENT_ROOT,
+		(unsigned char *)val, len);
 	free(names);
-	ewmh_ChangeProperty(Scr.Root, "_NET_DESKTOP_NAMES",
-			    EWMH_ATOM_LIST_CLIENT_ROOT,
-			    (unsigned char *)val, len);
 	free(val);
 }
-#endif /* HAVE_EWMH */
