@@ -60,14 +60,22 @@ static char *function_vars[] =
 	"fgsh.cs",
 	"gt.",
 	"desk.name",
+	"desk.n",
 	"desk.width",
 	"desk.height",
+	"desk.pagesx",
+	"desk.pagesy",
 	"vp.x",
 	"vp.y",
 	"vp.width",
 	"vp.height",
 	"page.nx",
 	"page.ny",
+	"w.id",
+	"w.name",
+	"w.iconname",
+	"w.class",
+	"w.resource",
 	"w.x",
 	"w.y",
 	"w.width",
@@ -98,6 +106,9 @@ static char *function_vars[] =
 	"pointer.wy",
 	"pointer.cx",
 	"pointer.cy",
+	"version.num",
+	"version.info",
+	"version.line",
 	NULL
 };
 
@@ -110,14 +121,22 @@ enum
 	VAR_FGSH_CS,
 	VAR_GT,
 	VAR_DESK_NAME,
+	VAR_DESK_N,
 	VAR_DESK_WIDTH,
 	VAR_DESK_HEIGHT,
+	VAR_DESK_PAGESX,
+	VAR_DESK_PAGESY,
 	VAR_VP_X,
 	VAR_VP_Y,
 	VAR_VP_WIDTH,
 	VAR_VP_HEIGHT,
 	VAR_PAGE_NX,
 	VAR_PAGE_NY,
+	VAR_W_ID,
+	VAR_W_NAME,
+	VAR_W_ICONNAME,
+	VAR_W_CLASS,
+	VAR_W_RESOURCE,
 	VAR_W_X,
 	VAR_W_Y,
 	VAR_W_WIDTH,
@@ -148,13 +167,16 @@ enum
 	VAR_POINTER_WY,
 	VAR_POINTER_CX,
 	VAR_POINTER_CY,
+	VAR_VERSION_NUM,
+	VAR_VERSION_INFO,
+	VAR_VERSION_LINE,
 } extended_vars;
 
 /* ---------------------------- exported variables (globals) ---------------- */
 
 /* ---------------------------- local functions ----------------------------- */
 
-static int expand_vars_extended(
+static signed int expand_vars_extended(
 	char *var_name, char *output, FvwmWindow *fw,
 	fvwm_cond_func_rc *cond_rc)
 {
@@ -170,6 +192,7 @@ static int expand_vars_extended(
 	int y;
 	Pixel pixel = 0;
 	int val = -12345678;
+	const char *string = NULL;
 	Bool is_numeric = False;
 	Bool is_x;
 	Window context_w = Scr.Root;
@@ -185,20 +208,20 @@ static int expand_vars_extended(
 		if (!isdigit(*rest) || (*rest == '0' && *(rest + 1) != 0))
 		{
 			/* not a non-negative integer without leading zeros */
-			return 0;
+			return -1;
 		}
 		if (sscanf(rest, "%d%n", &cs, &n) < 1)
 		{
-			return 0;
+			return -1;
 		}
 		if (*(rest + n) != 0)
 		{
 			/* trailing characters */
-			return 0;
+			return -1;
 		}
 		if (cs < 0)
 		{
-			return 0;
+			return -1;
 		}
 		alloc_colorset(cs);
 		switch (i)
@@ -222,32 +245,28 @@ static int expand_vars_extended(
 		return pixel_to_color_string(dpy, Pcmap, pixel, target, False);
 	case VAR_GT:
 	{
-		const char *gt;
-
 		if (rest == NULL)
 		{
-			return 0;
-		}
-		gt = _(rest);
-		if (gt == NULL)
-		{
-			return 0;
+			return -1;
 		}
+		string = _(rest);
+		l = strlen(string);
 		if (output)
 		{
-			strcpy(output, gt);
+			strcpy(output, string);
 		}
-		return strlen(gt);
+		return l;
+		break;
 	}
 	case VAR_DESK_NAME:
 		if (sscanf(rest, "%d%n", &cs, &n) < 1)
 		{
-			return 0;
+			return -1;
 		}
 		if (*(rest + n) != 0)
 		{
 			/* trailing characters */
-			return 0;
+			return -1;
 		}
 		s = GetDesktopName(cs);
 		if (s == NULL)
@@ -267,7 +286,7 @@ static int expand_vars_extended(
 			l = strlen(s);
 			if (output)
 			{
-				strcpy(output,s);
+				strcpy(output, s);
 			}
 		}
 		return l;
@@ -278,6 +297,10 @@ static int expand_vars_extended(
 	/* only exact matches for all other variables */
 	switch ((i = GetTokenIndex(var_name, function_vars, 0, &rest)))
 	{
+	case VAR_DESK_N:
+		is_numeric = True;
+		val = Scr.CurrentDesk;
+		break;
 	case VAR_DESK_WIDTH:
 		is_numeric = True;
 		val = Scr.VxMax + Scr.MyDisplayWidth;
@@ -286,6 +309,14 @@ static int expand_vars_extended(
 		is_numeric = True;
 		val = Scr.VyMax + Scr.MyDisplayHeight;
 		break;
+	case VAR_DESK_PAGESX:
+		is_numeric = True;
+		val = (int)(Scr.VxMax / Scr.MyDisplayWidth) + 1;
+		break;
+	case VAR_DESK_PAGESY:
+		is_numeric = True;
+		val = (int)(Scr.VyMax / Scr.MyDisplayHeight) + 1;
+		break;
 	case VAR_VP_X:
 		is_numeric = True;
 		val = Scr.Vx;
@@ -310,13 +341,44 @@ static int expand_vars_extended(
 		is_numeric = True;
 		val = (int)(Scr.Vy / Scr.MyDisplayHeight);
 		break;
+	case VAR_W_ID:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			sprintf(target, "0x%x", (unsigned int)FW_W(fw));
+			string = target;
+		}
+		break;
+	case VAR_W_NAME:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			string = fw->name.name;
+		}
+		break;
+	case VAR_W_ICONNAME:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			string = fw->icon_name.name;
+		}
+		break;
+	case VAR_W_CLASS:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			string = fw->class.res_class;
+		}
+		break;
+	case VAR_W_RESOURCE:
+		if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
+		{
+			string = fw->class.res_name;
+		}
+		break;
 	case VAR_W_X:
 	case VAR_W_Y:
 	case VAR_W_WIDTH:
 	case VAR_W_HEIGHT:
 		if (!fw || IS_ICONIFIED(fw) || IS_EWMH_DESKTOP(FW_W(fw)))
 		{
-			return 0;
+			return -1;
 		}
 		else
 		{
@@ -339,7 +401,7 @@ static int expand_vars_extended(
 				val = g.height;
 				break;
 			default:
-				return 0;
+				return -1;
 			}
 		}
 		break;
@@ -349,7 +411,7 @@ static int expand_vars_extended(
 	case VAR_CW_HEIGHT:
 		if (!fw || IS_ICONIFIED(fw) || IS_EWMH_DESKTOP(FW_W(fw)))
 		{
-			return 0;
+			return -1;
 		}
 		else
 		{
@@ -372,7 +434,7 @@ static int expand_vars_extended(
 				val = g.height;
 				break;
 			default:
-				return 0;
+				return -1;
 			}
 		}
 		break;
@@ -382,7 +444,7 @@ static int expand_vars_extended(
 	case VAR_IT_HEIGHT:
 		if (!fw || IS_EWMH_DESKTOP(FW_W(fw)))
 		{
-			return 0;
+			return -1;
 		}
 		else
 		{
@@ -390,7 +452,7 @@ static int expand_vars_extended(
 
 			if (get_visible_icon_title_geometry(fw, &g) == False)
 			{
-				return 0;
+				return -1;
 			}
 			is_numeric = True;
 			switch (i)
@@ -408,7 +470,7 @@ static int expand_vars_extended(
 				val = g.height;
 				break;
 			default:
-				return 0;
+				return -1;
 			}
 		}
 		break;
@@ -418,7 +480,7 @@ static int expand_vars_extended(
 	case VAR_IP_HEIGHT:
 		if (!fw || IS_EWMH_DESKTOP(FW_W(fw)))
 		{
-			return 0;
+			return -1;
 		}
 		else
 		{
@@ -426,7 +488,7 @@ static int expand_vars_extended(
 
 			if (get_visible_icon_picture_geometry(fw, &g) == False)
 			{
-				return 0;
+				return -1;
 			}
 			is_numeric = True;
 			switch (i)
@@ -444,7 +506,7 @@ static int expand_vars_extended(
 				val = g.height;
 				break;
 			default:
-				return 0;
+				return -1;
 			}
 		}
 		break;
@@ -454,7 +516,7 @@ static int expand_vars_extended(
 	case VAR_I_HEIGHT:
 		if (!fw || IS_EWMH_DESKTOP(FW_W(fw)))
 		{
-			return 0;
+			return -1;
 		}
 		else
 		{
@@ -462,7 +524,7 @@ static int expand_vars_extended(
 
 			if (get_visible_icon_geometry(fw, &g) == False)
 			{
-				return 0;
+				return -1;
 			}
 			is_numeric = True;
 			switch (i)
@@ -480,7 +542,7 @@ static int expand_vars_extended(
 				val = g.height;
 				break;
 			default:
-				return 0;
+				return -1;
 			}
 		}
 		break;
@@ -499,7 +561,7 @@ static int expand_vars_extended(
 	case VAR_COND_RC:
 		if (cond_rc == NULL)
 		{
-			return 0;
+			return -1;
 		}
 		switch (*cond_rc)
 		{
@@ -509,7 +571,7 @@ static int expand_vars_extended(
 			val = (int)(*cond_rc);
 			break;
 		default:
-			return 0;
+			return -1;
 		}
 		is_numeric = True;
 		break;
@@ -528,7 +590,7 @@ static int expand_vars_extended(
 			if (!fw || IS_ICONIFIED(fw)
 			    || IS_EWMH_DESKTOP(FW_W(fw)))
 			{
-				return 0;
+				return -1;
 			}
 			is_numeric = True;
 			context_w = FW_W_FRAME(fw);
@@ -541,7 +603,7 @@ static int expand_vars_extended(
 			if (!fw || IS_ICONIFIED(fw) || IS_SHADED(fw)
 			    || IS_EWMH_DESKTOP(FW_W(fw)))
 			{
-				return 0;
+				return -1;
 			}
 			is_numeric = True;
 			context_w = FW_W(fw);
@@ -558,33 +620,36 @@ static int expand_vars_extended(
 				  &JunkX, &JunkY, &x, &y, &JunkMask) == False)
 		{
 			/* pointer is on a different screen, don't expand */
-			return 0;
+			return -1;
 		}
 		val = (is_x) ? x : y;
 		break;
+	case VAR_VERSION_NUM:
+		string = VERSION;
+		break;
+	case VAR_VERSION_INFO:
+		string = VERSIONINFO;
+		break;
+	case VAR_VERSION_LINE:
+		string = Fvwm_VersionInfo;
+		break;
 	default:
 		/* unknown variable - try to find it in the environment */
-		s = getenv(var_name);
-		if (s)
-		{
-			if (output)
-			{
-				strcpy(output, s);
-			}
-			return strlen(s);
-		}
-		else
-		{
-			return 0;
-		}
+		string = getenv(var_name);
 	}
 	if (is_numeric)
 	{
 		sprintf(target, "%d", val);
 		return strlen(target);
 	}
-
-	return 0;
+	else
+	{
+		if (output && string)
+		{
+			strcpy(output, string);
+		}
+		return string ? strlen(string) : -1;
+	}
 }
 
 /* ---------------------------- interface functions ------------------------- */
@@ -593,7 +658,7 @@ char *expand_vars(
 	char *input, char *arguments[], FvwmWindow *fw, Bool addto, Bool ismod,
 	fvwm_cond_func_rc *cond_rc)
 {
-	int l,i,l2,n,k,j,m;
+	int l, i, l2, n, k, j, m;
 	int xlen;
 	char *out;
 	char *var;
@@ -609,8 +674,8 @@ char *expand_vars(
 	}
 
 	/* Calculate best guess at length of expanded string */
-	i=0;
-	while (i<l)
+	i = 0;
+	while (i < l)
 	{
 		if (input[i] == '$' && (!ismod || !isalpha(input[i+1])))
 		{
@@ -638,7 +703,7 @@ char *expand_vars(
 					{
 						xlen = expand_vars_extended(
 							var, NULL, fw, cond_rc);
-						if (xlen > 0)
+						if (xlen >= 0)
 						{
 							l2 += xlen - (k + 2);
 						}
@@ -771,7 +836,7 @@ char *expand_vars(
 					xlen = expand_vars_extended(
 						var, &out[j], fw, cond_rc);
 					input[m] = ']';
-					if (xlen > 0)
+					if (xlen >= 0)
 					{
 						j += xlen;
 						i += k + 2;
@@ -844,6 +909,10 @@ char *expand_vars(
 			case 'w':
 				if (fw && !IS_EWMH_DESKTOP(FW_W(fw)))
 				{
+#if 0
+					fvwm_msg(OLD, "expand_vars",
+						"Use $[w.id] instead of $w");
+#endif
 					sprintf(&out[j], "0x%x",
 						(unsigned int)FW_W(fw));
 				}
@@ -855,16 +924,28 @@ char *expand_vars(
 				i++;
 				break;
 			case 'd':
+#if 0
+				fvwm_msg(OLD, "expand_vars",
+					"Use $[desk.n] instead of $d");
+#endif
 				sprintf(&out[j], "%d", Scr.CurrentDesk);
 				j += strlen(&out[j]);
 				i++;
 				break;
 			case 'x':
+#if 0
+				fvwm_msg(OLD, "expand_vars",
+					"Use $[vp.x] instead of $x");
+#endif
 				sprintf(&out[j], "%d", Scr.Vx);
 				j += strlen(&out[j]);
 				i++;
 				break;
 			case 'y':
+#if 0
+				fvwm_msg(OLD, "expand_vars",
+					"Use $[vp.y] instead of $y");
+#endif
 				sprintf(&out[j], "%d", Scr.Vy);
 				j += strlen(&out[j]);
 				i++;
@@ -878,6 +959,11 @@ char *expand_vars(
 					switch(input[i+1])
 					{
 					case 'c':
+#if 0
+						fvwm_msg(OLD, "expand_vars",
+							"Use $[w.class] "
+							"instead of $c");
+#endif
 						if (fw->class.res_class &&
 						    fw->class.res_class[0])
 						{
@@ -886,6 +972,11 @@ char *expand_vars(
 						}
 						break;
 					case 'r':
+#if 0
+						fvwm_msg(OLD, "expand_vars",
+							"Use $[w.resource] "
+							"instead of $r");
+#endif
 						if (fw->class.res_name &&
 						    fw->class.res_name[0])
 						{
@@ -894,6 +985,11 @@ char *expand_vars(
 						}
 						break;
 					case 'n':
+#if 0
+						fvwm_msg(OLD, "expand_vars",
+							"Use $[w.name] "
+							"instead of $n");
+#endif
 						if (fw->name.name &&
 						    fw->name.name[0])
 						{
@@ -905,6 +1001,8 @@ char *expand_vars(
 				is_string = True;
 				break;
 			case 'v':
+				fvwm_msg(OLD, "expand_vars",
+					"Use $[version.line] instead of $v");
 				sprintf(&out[j], "%s", (Fvwm_VersionInfo) ?
 					Fvwm_VersionInfo : "");
 				j += strlen(&out[j]);
