@@ -170,22 +170,19 @@ static void __update_windowlist(
 	int is_focus_by_flip_focus_cmd)
 {
 	lastFocusType = (is_focus_by_flip_focus_cmd) ? True : False;
-	if (fw == NULL || focus_is_focused(fw) || fw == &Scr.FvwmRoot)
+	if (fw == NULL || focus_is_focused(fw) || fw == &Scr.FvwmRoot ||
+	    IS_SCHEDULED_FOR_DESTROY(fw))
 	{
 		return;
 	}
-	/* ClickToFocus focus queue manipulation - only performed for
-	 * Focus-by-mouse type focus events */
 	/* Watch out: fw may not be on the windowlist and the windowlist may be
 	 * empty */
-
-	/* pluck window from list and deposit at top */
-
-	if (FP_DO_SORT_WINDOWLIST_BY(FW_FOCUS_POLICY(fw)) ==
-	    FPOL_SORT_WL_BY_OPEN && !is_focus_by_flip_focus_cmd)
+	if (!is_focus_by_flip_focus_cmd &&
+	    (FP_DO_SORT_WINDOWLIST_BY(FW_FOCUS_POLICY(fw)) ==
+	     FPOL_SORT_WL_BY_OPEN ||
+	     set_by == FOCUS_SET_BY_FUNCTION))
 	{
-		/* move the windowlist around so that fw is at the top
-		 */
+		/* move the windowlist around so that fw is at the top */
 		FvwmWindow *fw2;
 
 		/* find the window on the windowlist */
@@ -197,10 +194,8 @@ static void __update_windowlist(
 
 		if (fw2)
 		{
-			/* the window is on the (non-zero length)
-			 * windowlist */
-			/* make fw2 point to the last window on the
-			 * list */
+			/* the window is on the (non-zero length) windowlist */
+			/* make fw2 point to the last window on the list */
 			while (fw2->next)
 			{
 				fw2 = fw2->next;
@@ -219,6 +214,7 @@ static void __update_windowlist(
 	}
 	else
 	{
+		/* pluck window from list and deposit at top */
 		/* remove fw from list */
 		if (fw->prev)
 		{
@@ -228,7 +224,6 @@ static void __update_windowlist(
 		{
 			fw->next->prev = fw->prev;
 		}
-
 		/* insert fw at start */
 		fw->next = Scr.FvwmRoot.next;
 		if (Scr.FvwmRoot.next)
@@ -386,13 +381,13 @@ static void set_focus_to_fwin(
 	/* Make sure the button grabs on the new and the old focused windows
 	 * are up to date. */
         if (args->client_entered)
-                {
-                        focus_grab_buttons_client_entered(fw);
-                }
-                else
-                {
-                        focus_grab_buttons(fw);
-                }
+	{
+		focus_grab_buttons_client_entered(fw);
+	}
+	else
+	{
+		focus_grab_buttons(fw);
+	}
         /* RBW -- don't call this twice for the same window!  */
         if (fw != get_focus_window())
         {
@@ -549,10 +544,16 @@ static Bool focus_query_grab_buttons(FvwmWindow *fw, Bool client_entered)
 	if (is_focused)
 	{
 		flag = FP_DO_RAISE_FOCUSED_CLIENT_CLICK(FW_FOCUS_POLICY(fw));
+#if 0
+fprintf(stderr,"fqgb: 0x%08x f %d '%s'\n", (int)fw, flag, fw->visible_name);
+#endif
 	}
 	else
 	{
 		flag = FP_DO_RAISE_UNFOCUSED_CLIENT_CLICK(FW_FOCUS_POLICY(fw));
+#if 0
+fprintf(stderr,"fqgb: 0x%08x u %d '%s'\n", (int)fw, flag, fw->visible_name);
+#endif
 	}
 
 	return (flag) ? True : False;
@@ -581,7 +582,8 @@ static FvwmWindow *__restore_focus_after_unmap(
 			if (!FP_DO_OVERRIDE_RELEASE_FOCUS(
 				    FW_FOCUS_POLICY(t)) &&
 			    t->Desk == fw->Desk && !DO_SKIP_CIRCULATE(t) &&
-			    !(DO_SKIP_ICON_CIRCULATE(t) && IS_ICONIFIED(t)) &&
+			    !(IS_ICONIFIED(t) && (DO_SKIP_ICON_CIRCULATE(t) ||
+			      IS_ICON_SUPPRESSED(t))) &&
 			    (!do_skip_marked_transients ||
 			     !IS_IN_TRANSIENT_SUBTREE(t)))
 			{
@@ -845,7 +847,7 @@ static void __focus_grab_buttons(FvwmWindow *fw, Bool client_entered)
 
 	if (fw == NULL || IS_SCHEDULED_FOR_DESTROY(fw) || !IS_MAPPED(fw))
 	{
-		/* It is pointless to grab buttons on dying windows.  Buttons
+		/* It is pointless to grab buttons on dieing windows.  Buttons
 		 * can not be grabbed when the window is unmapped. */
 		return;
 	}
@@ -854,6 +856,9 @@ static void __focus_grab_buttons(FvwmWindow *fw, Bool client_entered)
 	if (do_grab_window == True)
 	{
 		grab_buttons |= FP_USE_MOUSE_BUTTONS(FW_FOCUS_POLICY(fw));
+#if 0
+fprintf(stderr,"gb: 0x%x\n", grab_buttons);
+#endif
 	}
 	if (grab_buttons != fw->grabbed_buttons)
 	{
