@@ -106,6 +106,21 @@ static void execute_complex_function(
 
 /* ---------------------------- local functions ----------------------------- */
 
+static int __context_has_window(
+	const exec_context_t *exc, execute_flags_t flags)
+{
+	if (exc->w.fw != NULL)
+	{
+		return 1;
+	}
+	else if ((flags & FUNC_ALLOW_UNMANAGED) && exc->w.w != None)
+	{
+		return 1;
+	}
+
+	return 0;
+}
+
 /***********************************************************************
  *
  *  Procedure:
@@ -114,28 +129,28 @@ static void execute_complex_function(
  *
  *  Inputs:
  *      cursor  - the cursor to display while waiting
- *      finishEvent - ButtonRelease or ButtonPress; tells what kind of event to
- *                    terminate on.
  *
  ***********************************************************************/
 static Bool DeferExecution(
 	exec_context_changes_t *ret_ecc, exec_context_change_mask_t *ret_mask,
-	cursor_t cursor, int trigger_evtype, int FinishEvent,
-	int do_allow_unmanaged)
+	cursor_t cursor, int trigger_evtype, int do_allow_unmanaged)
 {
 	int done;
 	int finished = 0;
+	int just_waiting_for_finish = 0;
 	Window dummy;
 	Window original_w;
 	static XEvent e;
 	Window w;
 	int wcontext;
 	FvwmWindow *fw;
+	int FinishEvent;
 
 	fw = ret_ecc->w.fw;
 	w = ret_ecc->w.w;
 	original_w = w;
 	wcontext = ret_ecc->w.wcontext;
+	FinishEvent = ((fw != NULL) ? ButtonRelease : ButtonPress);
 	if (wcontext == C_UNMANAGED && do_allow_unmanaged)
 	{
 		return False;
@@ -154,6 +169,7 @@ static Bool DeferExecution(
 			/* We are only waiting until the user releases the
 			 * button. Do not change the cursor. */
 			cursor = CRS_NONE;
+			just_waiting_for_finish = 1;
 		}
 	}
 	if (Scr.flags.silent_functions)
@@ -216,7 +232,10 @@ static Bool DeferExecution(
 	}
 	MyXUngrabKeyboard(dpy);
 	UngrabEm(GRAB_NORMAL);
-
+	if (just_waiting_for_finish)
+	{
+		return False;
+	}
 	w = e.xany.window;
 	ret_ecc->x.etrigger = &e;
 	*ret_mask |= ECC_ETRIGGER | ECC_W | ECC_WCONTEXT;
@@ -392,6 +411,16 @@ static void __execute_function(
 	}
 
 	func_depth++;
+	if (func_depth > MAX_FUNCTION_DEPTH)
+	{
+		fvwm_msg(
+			ERR, "__execute_function",
+			"Function '%s' called with a depth of %i, "
+			"stopping function execution!",
+			action, func_depth);
+		func_depth--;
+		return;
+	}
 	if (args)
 	{
 		for (j = 0; j < 11; j++)
@@ -420,12 +449,24 @@ static void __execute_function(
 	}
 	else
 	{
+		FvwmWindow *tw;
+
 		w = GetSubwindowFromEvent(dpy, exc->x.elast);
 		if (w == None)
 		{
 			w = exc->x.elast->xany.window;
 		}
-		if (w == None)
+		tw = NULL;
+		if (w != None)
+		{
+			if (XFindContext(
+				 dpy, w, FvwmContext, (caddr_t *)&tw) ==
+			    XCNOENT)
+			{
+				tw = NULL;
+			}
+		}
+		if (w == None || tw != exc->w.fw)
 		{
 			w = FW_W(exc->w.fw);
 		}
@@ -577,9 +618,18 @@ static void __execute_function(
 			{
 				rc = DeferExecution(
 					&ecc, &mask, bif->cursor,
-					exc->x.elast->type, bif->evtype,
+					exc->x.elast->type,
 					(bif->flags & FUNC_ALLOW_UNMANAGED));
 			}
+			else if ((bif->flags & FUNC_NEEDS_WINDOW) &&
+				 !__context_has_window(
+					 exc,
+					 bif->flags & FUNC_ALLOW_UNMANAGED))
+			{
+				/* no context window and not allowed to defer,
+				 * skip command */
+				rc = True;
+			}
 			if (rc == False)
 			{
 				exc2 = exc_clone_context(exc, &ecc, mask);
@@ -758,7 +808,8 @@ static void __run_complex_function_items(
 	char c;
 	FunctionItem *fi;
 
-	for (fi = func->first_item; fi != NULL && *cond_func_rc != COND_RC_BREAK; )
+	for (fi = func->first_item;
+	     fi != NULL && *cond_func_rc != COND_RC_BREAK; )
 	{
 		/* make lower case */
 		c = fi->condition;
@@ -827,6 +878,7 @@ static void execute_complex_function(
 	XEvent *te;
 
 	mask = 0;
+	d.type = 0;
 	ecc.w.fw = exc->w.fw;
 	ecc.w.w = exc->w.w;
 	ecc.w.wcontext = exc->w.wcontext;
@@ -912,7 +964,7 @@ static void execute_complex_function(
 	{
 		if (DeferExecution(
 			    &ecc, &mask, CRS_SELECT, trigger_evtype,
-			    ButtonPress, do_allow_unmanaged_immediate))
+			    do_allow_unmanaged_immediate))
 		{
 			func->use_depth--;
 			cf_cleanup(&depth, arguments);
@@ -977,7 +1029,7 @@ static void execute_complex_function(
 	{
 		if (DeferExecution(
 			    &ecc, &mask, CRS_SELECT, trigger_evtype,
-			    ButtonPress, do_allow_unmanaged))
+			    do_allow_unmanaged))
 		{
 			func->use_depth--;
 			cf_cleanup(&depth, arguments);
