@@ -1376,7 +1376,7 @@ static void SetRCDefaults(void)
 		},
 		{
 			"+ \"&3. ",
-			_("Setup 95 Script"), 
+			_("Setup 95 Script"),
 			"\" Module FvwmScript FvwmScript-Setup95"
 		},
 		{
@@ -1394,7 +1394,7 @@ static void SetRCDefaults(void)
 			_("Exit FVWM"),
 			"\" Quit"
 		},
-		{ "Mouse 0 R N Menu MenuFvwmRoot", "", "" },
+		{ "Mouse 1 R A Menu MenuFvwmRoot", "", "" },
 		{ "Read "FVWM_DATADIR"/ConfigFvwmDefaults", "", "" },
 		{ NULL, NULL, NULL }
 	};
@@ -1483,7 +1483,7 @@ void StartupStuff(void)
 
 	ecc.type = Restarting ? EXCT_RESTART : EXCT_INIT;
 	ecc.w.wcontext = C_ROOT;
-	exc = exc_create_context(&ecc, ECC_TYPE | ECC_W);
+	exc = exc_create_context(&ecc, ECC_TYPE | ECC_WCONTEXT);
 	CaptureAllWindows(exc, False);
 	/* Turn off the SM stuff after the initial capture so that new windows
 	 * will not be matched by accident. */
@@ -1601,6 +1601,7 @@ void ResetAllButtons(FvwmDecor *decor)
 	int i;
 	int j;
 
+	DestroyAllButtons(decor);
 	for (tbp = decor->buttons, i = 0; i < NUMBER_OF_BUTTONS; i++, tbp++)
 	{
 		memset(&TB_FLAGS(*tbp), 0, sizeof(TB_FLAGS(*tbp)));
@@ -1709,7 +1710,7 @@ int main(int argc, char **argv)
 	setVersionInfo();
 	/* Put the default module directory into the environment so it can be
 	 * used later by the config file, etc.  */
-	putenv("FVWM_MODULEDIR=" FVWM_MODULEDIR);
+	flib_putenv("FVWM_MODULEDIR", "FVWM_MODULEDIR=" FVWM_MODULEDIR);
 
 	/* Figure out user's home directory */
 	home_dir = getenv("HOME");
@@ -1732,10 +1733,14 @@ int main(int argc, char **argv)
 	fvwm_userdir = getenv("FVWM_USERDIR");
 	if (fvwm_userdir == NULL)
 	{
+		char *s;
+
 		fvwm_userdir = safestrdup(CatString2(home_dir, "/.fvwm"));
 		/* Put the user directory into the environment so it can be used
 		 * later everywhere. */
-		putenv(safestrdup(CatString2("FVWM_USERDIR=", fvwm_userdir)));
+		s = safestrdup(CatString2("FVWM_USERDIR=", fvwm_userdir));
+		flib_putenv("FVWM_USERDIR", s);
+		free(s);
 	}
 
 	/* Create FVWM_USERDIR directory if needed */
@@ -2058,13 +2063,11 @@ int main(int argc, char **argv)
 	len = strlen(XDisplayString(dpy));
 	display_string = safemalloc(len+10);
 	sprintf(display_string, "DISPLAY=%s",XDisplayString(dpy));
-	putenv(display_string);
+	flib_putenv("DISPLAY", display_string);
 	/* Add a HOSTDISPLAY environment variable, which is the same as
 	 * DISPLAY, unless display = :0.0 or unix:0.0, in which case the full
 	 * host name will be used for ease in networking.
-	 *
-	 * Note: Can't free the rdisplay_string after putenv, because it
-	 * becomes part of the environment! */
+	 */
 	if (strncmp(display_string, "DISPLAY=:",9)==0)
 	{
 		char client[MAXHOSTNAME], *rdisplay_string;
@@ -2072,24 +2075,28 @@ int main(int argc, char **argv)
 		rdisplay_string = safemalloc(len+14 + strlen(client));
 		sprintf(rdisplay_string, "HOSTDISPLAY=%s:%s", client,
 			&display_string[9]);
-		putenv(rdisplay_string);
+		flib_putenv("HOSTDISPLAY", rdisplay_string);
+		free(rdisplay_string);
 	}
 	else if (strncmp(display_string, "DISPLAY=unix:",13)==0)
 	{
 		char client[MAXHOSTNAME], *rdisplay_string;
 		gethostname(client,MAXHOSTNAME);
 		rdisplay_string = safemalloc(len+14 + strlen(client));
-		sprintf(rdisplay_string, "HOSTDISPLAY=%s:%s",client,
+		sprintf(rdisplay_string, "HOSTDISPLAY=%s:%s", client,
 			&display_string[13]);
-		putenv(rdisplay_string);
+		flib_putenv("HOSTDISPLAY", rdisplay_string);
+		free(rdisplay_string);
 	}
 	else
 	{
 		char *rdisplay_string;
 		rdisplay_string = safemalloc(len+14);
 		sprintf(rdisplay_string, "HOSTDISPLAY=%s",XDisplayString(dpy));
-		putenv(rdisplay_string);
+		flib_putenv("HOSTDISPLAY", rdisplay_string);
+		free(rdisplay_string);
 	}
+	free(display_string);
 
 	Scr.Root = RootWindow(dpy, Scr.screen);
 	if (Scr.Root == None)
