@@ -233,11 +233,11 @@ void get_title_font_size_and_offset(
 	int font_size;
 	int min_offset;
 	Bool is_rotated_cw, is_rotated;
+	rotation_type draw_rotation;
 
 	/* adjust font offset according to height specified in title style */
 	decor_size = fw->decor->title_height;
 	font_size = fw->title_font->height + EXTRA_TITLE_FONT_HEIGHT;
-	min_offset = fw->title_font->ascent;
 	switch (title_dir)
 	{
 	case DIR_W:
@@ -247,8 +247,6 @@ void get_title_font_size_and_offset(
 		if (is_rotated_cw)
 		{
 			fw->title_text_rotation = ROTATION_90;
-			min_offset = fw->title_font->height -
-				fw->title_font->ascent;
 		}
 		else
 		{
@@ -263,8 +261,6 @@ void get_title_font_size_and_offset(
 		if (is_rotated)
 		{
 			fw->title_text_rotation = ROTATION_180;
-			min_offset = fw->title_font->height -
-				fw->title_font->ascent;
 		}
 		else
 		{
@@ -272,8 +268,23 @@ void get_title_font_size_and_offset(
 		}
 		break;
 	}
+	if (USE_TITLE_DECOR_ROTATION(fw))
+	{
+		draw_rotation = ROTATION_0;
+	}
+	else
+	{
+		draw_rotation = fw->title_text_rotation;
+	}
+	min_offset =  FlocaleGetMinOffset(
+		fw->title_font, draw_rotation);
 	extra_size = (decor_size > 0) ? decor_size - font_size : 0;
 	*offset = min_offset;
+	if (fw->decor->min_title_height > 0 &&
+	    font_size + extra_size < fw->decor->min_title_height)
+	{
+		extra_size = fw->decor->min_title_height - font_size;
+	}
 	if (extra_size > 0)
 	{
 		*offset += extra_size / 2;
@@ -1033,9 +1044,10 @@ Bool get_visible_icon_geometry(
 }
 
 /* returns the icon geometry (unexpanded title plus pixmap) if it exists */
-Bool get_icon_geometry(
+void get_icon_geometry(
 	FvwmWindow *fw, rectangle *ret_g)
 {
+	/* valid geometry? */
 	if (fw->icon_g.picture_w_g.width > 0)
 	{
 		*ret_g = fw->icon_g.picture_w_g;
@@ -1044,17 +1056,25 @@ Bool get_icon_geometry(
 			ret_g->height += fw->icon_g.title_w_g.height;
 		}
 	}
-	else if (!HAS_NO_ICON_TITLE(fw))
+	else if (fw->icon_g.title_w_g.width > 0)
+	{
+		*ret_g = fw->icon_g.title_w_g;
+	}
+	/* valid position? */
+	else if (fw->icon_g.picture_w_g.x != 0 || fw->icon_g.picture_w_g.y != 0)
+	{
+		*ret_g = fw->icon_g.picture_w_g;
+	}
+	else if (fw->icon_g.title_w_g.x != 0 || fw->icon_g.title_w_g.y != 0)
 	{
 		*ret_g = fw->icon_g.title_w_g;
 	}
 	else
 	{
 		memset(ret_g, 0, sizeof(*ret_g));
-		return False;
 	}
 
-	return True;
+	return;
 }
 
 /* Returns the visible geometry of a window or icon.  This can be used to test
@@ -1074,6 +1094,9 @@ Bool get_visible_window_or_icon_geometry(
 void move_icon_to_position(
 	FvwmWindow *fw)
 {
+	Bool draw_picture_w = False;
+	Bool draw_title_w = False;
+
 	if (fw->icon_g.picture_w_g.width > 0)
 	{
 		int cs;
@@ -1091,17 +1114,43 @@ void move_icon_to_position(
 			fw->icon_g.picture_w_g.x,
 			fw->icon_g.picture_w_g.y);
 		if (fw->icon_alphaPixmap ||
-		    (cs >= 0 && Colorset[cs].icon_alpha_percent < 100))
+		    (cs >= 0 && Colorset[cs].icon_alpha_percent < 100) ||
+		    CSET_IS_TRANSPARENT(fw->icon_background_cs) ||
+		    (!IS_ICON_SHAPED(fw) && fw->icon_background_padding > 0))
 		{
-			DrawIconWindow(fw, False, True, False, NULL);
+			draw_picture_w = True;
 		}
 	}
 	if (!HAS_NO_ICON_TITLE(fw))
 	{
+		int cs;
+		rectangle dummy;
+
+		if (Scr.Hilite == fw)
+		{
+			cs = fw->icon_title_cs_hi;
+		}
+		else
+		{
+			cs = fw->icon_title_cs;
+		}
 		XMoveWindow(
 			dpy, FW_W_ICON_TITLE(fw),
 			fw->icon_g.title_w_g.x,
 			fw->icon_g.title_w_g.y);
+		if (CSET_IS_TRANSPARENT(cs) &&
+		    !get_visible_icon_picture_geometry(fw, &dummy) &&
+		    get_visible_icon_title_geometry(fw, &dummy))
+		{
+			draw_title_w = True;
+		}
+	}
+
+	if (draw_title_w || draw_picture_w)
+	{
+		DrawIconWindow(
+			fw, draw_title_w, draw_picture_w, False, draw_picture_w,
+			NULL);
 	}
 
 	return;
@@ -1128,8 +1177,10 @@ void broadcast_icon_geometry(
 void modify_icon_position(
 	FvwmWindow *fw, int dx, int dy)
 {
-	if (fw->icon_g.picture_w_g.width > 0)
+	if (fw->icon_g.picture_w_g.width > 0 || HAS_NO_ICON_TITLE(fw))
 	{
+		/* picture position is also valid if there is neither a picture
+		 * nor a title */
 		fw->icon_g.picture_w_g.x += dx;
 		fw->icon_g.picture_w_g.y += dy;
 	}
@@ -1176,6 +1227,13 @@ void set_icon_position(
 		fw->icon_g.title_w_g.y +=
 			fw->icon_g.picture_w_g.height;
 	}
+	else if (fw->icon_g.picture_w_g.width <= 0 && HAS_NO_ICON_TITLE(fw))
+	{
+		/* In case there is no icon, fake the icon position so the
+		 * modules know where its window was iconified. */
+		fw->icon_g.picture_w_g.x = x;
+		fw->icon_g.picture_w_g.y = y;
+	}
 
 	return;
 }
