@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifndef ICCCM2_h
@@ -18,7 +18,7 @@
 
 extern void SetupICCCM2(Bool replace_wm);
 extern void CloseICCCM2(void);
-extern void HandleSelectionRequest(void);
-extern void HandleSelectionClear(void);
+extern void icccm2_handle_selection_request(const XEvent *e);
+extern void icccm2_handle_selection_clear(void);
 
 #endif /* ICCCM2_H */
