@@ -69,14 +69,28 @@ static void GetIconFromFile(FvwmWindow *fw);
 static void GetIconWindow(FvwmWindow *fw);
 static void GetIconBitmap(FvwmWindow *fw);
 
-/* erase all traces of the last used icon in the window structure */
-void clear_icon(FvwmWindow *fw)
+static void clear_icon_dimensions(FvwmWindow *fw)
 {
 	int px;
 	int py;
 	int tx;
 	int ty;
 
+	px = fw->icon_g.picture_w_g.x;
+	py = fw->icon_g.picture_w_g.y;
+	tx = fw->icon_g.title_w_g.x;
+	ty = fw->icon_g.title_w_g.y;
+	memset(&fw->icon_g, 0, sizeof(fw->icon_g));
+	fw->icon_g.picture_w_g.x = px;
+	fw->icon_g.picture_w_g.y = py;
+	fw->icon_g.title_w_g.x = tx;
+	fw->icon_g.title_w_g.y = ty;
+
+	return;
+}
+/* erase all traces of the last used icon in the window structure */
+void clear_icon(FvwmWindow *fw)
+{
 	FW_W_ICON_PIXMAP(fw) = None;
 	fw->iconPixmap = None;
 	fw->icon_maskPixmap = None;
@@ -86,15 +100,7 @@ void clear_icon(FvwmWindow *fw)
 	fw->icon_no_limit = 0;
 	if (IS_ICON_MOVED(fw))
 	{
-		px = fw->icon_g.picture_w_g.x;
-		py = fw->icon_g.picture_w_g.y;
-		tx = fw->icon_g.title_w_g.x;
-		ty = fw->icon_g.title_w_g.y;
-		memset(&fw->icon_g, 0, sizeof(fw->icon_g));
-		fw->icon_g.picture_w_g.x = px;
-		fw->icon_g.picture_w_g.y = py;
-		fw->icon_g.title_w_g.x = tx;
-		fw->icon_g.title_w_g.y = ty;
+		clear_icon_dimensions(fw);
 	}
 	else
 	{
@@ -182,7 +188,7 @@ static void SetIconPixmapSize(
 	int r_w,r_h;
 	GC gc;
 	XGCValues gc_init;
-	
+
 	*nrx = 0;
 	*nry = 0;
 
@@ -204,7 +210,7 @@ static void SetIconPixmapSize(
 		{
 			*icon = CreateStretchPixmap(
 				dpy, oldPixmap, width, height, depth, newWidth,
-				newHeight, gc);			
+				newHeight, gc);
 		}
 		break;
 	case ICON_RESIZE_TYPE_STRETCHED:
@@ -510,7 +516,8 @@ ICON_DBG((stderr,"ciw: iph%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":"
 static void set_icon_pixmap_background(FvwmWindow *fw)
 {
 	if (fw->iconPixmap != None &&
-	    (Pdefault || (fw->iconDepth == 1) || IS_PIXMAP_OURS(fw)))
+	    (Pdefault || fw->iconDepth == 1 || fw->iconDepth == Pdepth ||
+	     IS_PIXMAP_OURS(fw)))
 	{
 		if (fw->icon_background_cs >= 0)
 		{
@@ -582,7 +589,8 @@ void CreateIconWindow(FvwmWindow *fw, int def_x, int def_y)
 	 * private colormap) and the client has supplied a pixmap (not a
 	 * bitmap) */
 	if ((IS_ICON_OURS(fw)) && (fw->icon_g.picture_w_g.height > 0)
-	    && (Pdefault || (fw->iconDepth == 1) || IS_PIXMAP_OURS(fw)))
+	    && (Pdefault || fw->iconDepth == 1 || fw->iconDepth == Pdepth ||
+		IS_PIXMAP_OURS(fw)))
 	{
 		fw->icon_g.picture_w_g.width +=
 			2 * abs(fw->icon_background_relief)
@@ -658,7 +666,8 @@ void CreateIconWindow(FvwmWindow *fw, int def_x, int def_y)
 	    fw->icon_g.picture_w_g.height > 0)
 	{
 		/* use fvwm's visuals in these cases */
-		if (Pdefault || (fw->iconDepth == 1) || IS_PIXMAP_OURS(fw))
+		if (Pdefault || fw->iconDepth == 1 || fw->iconDepth == Pdepth ||
+		    IS_PIXMAP_OURS(fw))
 		{
 			if (!old_icon_pixmap_w)
 			{
@@ -739,8 +748,8 @@ void CreateIconWindow(FvwmWindow *fw, int def_x, int def_y)
 			 * relief */
 			int off = 0;
 
-			if (Pdefault || (fw->iconDepth == 1) ||
-			    IS_PIXMAP_OURS(fw))
+			if (Pdefault || fw->iconDepth == 1 || 
+			    fw->iconDepth == Pdepth || IS_PIXMAP_OURS(fw))
 			{
 				off = abs(fw->icon_background_relief) +
 					fw->icon_background_padding;
@@ -1095,7 +1104,7 @@ void DrawIconTitleWindow(
 				ICON_TITLE_STICK_HEIGHT);
 		}
 	}
-	
+
 	return;
 }
 
@@ -1112,7 +1121,8 @@ void DrawIconPixmapWindow(
 			dpy, FW_W_ICON_PIXMAP(fw), fw->icon_g.picture_w_g.x,
 			fw->icon_g.picture_w_g.y);
 		if (reset_bg &&
-		    (fw->iconDepth == 1 || Pdefault || IS_PIXMAP_OURS(fw)))
+		    (fw->iconDepth == 1 || fw->iconDepth == Pdepth || Pdefault ||
+		     IS_PIXMAP_OURS(fw)))
 		{
 			set_icon_pixmap_background(fw);
 			XClearArea(dpy, FW_W_ICON_PIXMAP(fw), 0, 0, 0, 0, False);
@@ -1123,7 +1133,8 @@ void DrawIconPixmapWindow(
 	/* need to locate the icon pixmap */
 	if (fw->iconPixmap != None)
 	{
-		if (fw->iconDepth == 1 || Pdefault || IS_PIXMAP_OURS(fw))
+		if (fw->iconDepth == 1 || fw->iconDepth == Pdepth || Pdefault ||
+		    IS_PIXMAP_OURS(fw))
 		{
 			FvwmRenderAttributes fra;
 			Bool draw_icon = True;
@@ -1206,7 +1217,8 @@ void DrawIconPixmapWindow(
 	 * visual */
 	if ((fw->iconPixmap != None) &&
 	    (!IS_ICON_SHAPED(fw) || fw->icon_background_cs >= 0) &&
-	    (Pdefault || (fw->iconDepth == 1) || IS_PIXMAP_OURS(fw)))
+	    (Pdefault || fw->iconDepth == 1 || fw->iconDepth == Pdepth ||
+	     IS_PIXMAP_OURS(fw)))
 	{
 		RelieveRectangle(
 			dpy, FW_W_ICON_PIXMAP(fw), 0, 0,
@@ -1418,7 +1430,8 @@ void DrawIconWindow(
 		}
 		if (!relief_change &&
 		    (fw->iconPixmap != None) && !IS_ICON_SHAPED(fw)
-		    && (Pdefault || (fw->iconDepth == 1) || IS_PIXMAP_OURS(fw)))
+		    && (Pdefault || fw->iconDepth == Pdepth || fw->iconDepth == 1
+			|| IS_PIXMAP_OURS(fw)))
 		{
 			relief_change =
 				(draw_colors.hilight !=
@@ -1615,10 +1628,15 @@ void AutoPlaceIcon(
   int new_x, new_y;
   Bool do_move_icon = False;
 
+#if 0
+  /* dv (16-Mar-2003):  We need to place the icon even if there is no icon so
+   * the 'position' can be communicated to the modules to decide whether to show
+   * the icon or not. */
   if (FW_W_ICON_PIXMAP(t) == None && FW_W_ICON_TITLE(t) == None)
   {
 	  return;
   }
+#endif
   /* New! Put icon in same page as the center of the window */
   /* Not a good idea for StickyIcons. Neither for icons of windows that are
    * visible on the current page. */
@@ -2090,10 +2108,10 @@ static void GetIconFromFile(FvwmWindow *fw)
 		return;
 	}
 	if (!PImageLoadPixmapFromFile(
-		dpy, Scr.NoFocusWin, path, &fw->iconPixmap, &fw->icon_maskPixmap,
-		&fw->icon_alphaPixmap, &fw->icon_g.picture_w_g.width,
-		&fw->icon_g.picture_w_g.height, &fw->iconDepth,
-		&fw->icon_nalloc_pixels, &fw->icon_alloc_pixels,
+		dpy, Scr.NoFocusWin, path, &fw->iconPixmap,
+		&fw->icon_maskPixmap, &fw->icon_alphaPixmap,
+		&fw->icon_g.picture_w_g.width, &fw->icon_g.picture_w_g.height,
+		&fw->iconDepth, &fw->icon_nalloc_pixels, &fw->icon_alloc_pixels,
 		&fw->icon_no_limit, fpa))
 	{
 		fvwm_msg(ERR, "GetIconFromFile", "Failed to load %s", path);
@@ -2191,13 +2209,15 @@ static void GetIconBitmap(FvwmWindow *fw)
 	}
 	/* sanity check the pixmap depth, it must be the same as the root or 1
 	 */
-	if ((depth != 1) && (depth != DefaultDepth(dpy,Scr.screen)))
+	if (depth != 1 && depth != Pdepth &&
+	    depth != DefaultDepth(dpy,Scr.screen))
 	{
 		fvwm_msg(
 			ERR, "GetIconBitmap",
 			"Window '%s' has a bad icon bitmap depth %d (should"
-			" be 1 or %d)! Ignoring icon bitmap.",
-			 fw->name.name, depth, DefaultDepth(dpy,Scr.screen));
+			" be 1, %d or %d)! Ignoring icon bitmap.",
+			fw->name.name, depth, Pdepth,
+			DefaultDepth(dpy,Scr.screen));
 		/* disable icon pixmap hint */
 		fw->wmhints->icon_pixmap = None;
 		fw->wmhints->flags &= ~IconPixmapHint;
@@ -2545,15 +2565,12 @@ void Iconify(FvwmWindow *fw, initial_window_options_type *win_opts)
 	{
 		AutoPlaceIcon(fw, win_opts, True);
 	}
-	/* domivogt (1-Mar-2000): The next block is a hack to prevent animation
-	 * if the window has an icon, but neither a pixmap nor a title. */
+	/* domivogt (12-Mar-2003): Clean out the icon geometry if there is no
+	 * icon.  Necessary to initialise the values and to suppress animation
+	 * if there is no icon. */
 	if (HAS_NO_ICON_TITLE(fw) && FW_W_ICON_PIXMAP(fw) == None)
 	{
-		fw->icon_g.picture_w_g.width = 0;
-		fw->icon_g.picture_w_g.height = 0;
-		fw->icon_g.title_w_g.width = 0;
-		fw->icon_g.title_w_g.height = 0;
-		fw->icon_g.title_text_width = 0;
+		clear_icon_dimensions(fw);
 	}
 	SET_ICONIFIED(fw, 1);
 	SET_ICON_UNMAPPED(fw, 0);
