@@ -6,12 +6,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 /*****************************************************************************
@@ -31,29 +31,14 @@
 #include "config.h"
 
 #include <stdio.h>
-#include <string.h>
-#include <assert.h>
-#include <X11/keysym.h>
 
-#include <libs/fvwmlib.h>
 #include "fvwm.h"
-#include "externs.h"
-#include "events.h"
-#include "menus.h"
-#include "cursor.h"
 #include "functions.h"
 #include "repeat.h"
 #include "misc.h"
 #include "move_resize.h"
 #include "screen.h"
-#include "borders.h"
-#include "colors.h"
-#include "colormaps.h"
-#include "decorations.h"
-#include "colorset.h"
-#include "defaults.h"
-#include "libs/FScreen.h"
-#include "libs/Flocale.h"
+#include "menus.h"
 
 /* ---------------------------- local definitions --------------------------- */
 
@@ -79,20 +64,17 @@ static void menu_func(F_CMD_ARGS, Bool fStaysUp)
 	char *ret_action = NULL;
 	MenuOptions mops;
 	char *menu_name = NULL;
-	XEvent *teventp;
 	MenuParameters mp;
 	MenuReturn mret;
-	FvwmWindow *fw2;
-	int tc;
-	extern FvwmWindow *Fw;
-	extern FvwmWindow *ButtonWindow;
-	extern int Context;
+	FvwmWindow * const fw = exc->w.fw;
+	const Window w = exc->w.w;
+	const exec_context_t *exc2;
 
 	memset(&mops, 0, sizeof(mops));
 	memset(&mret, 0, sizeof(MenuReturn));
 	action = GetNextToken(action,&menu_name);
 	action = get_menu_options(
-		action, w, fw, eventp, NULL, NULL, &mops);
+		action, w, fw, NULL, NULL, NULL, &mops);
 	while (action && *action && isspace((unsigned char)*action))
 	{
 		action++;
@@ -118,37 +100,29 @@ static void menu_func(F_CMD_ARGS, Bool fStaysUp)
 		free(menu_name);
 	}
 
-	if (!action && eventp && eventp->type == KeyPress)
-	{
-		teventp = (XEvent *)1;
-	}
-	else
-	{
-		teventp = eventp;
-	}
-
 	memset(&mp, 0, sizeof(mp));
 	mp.menu = menu;
-	fw2 = (fw != None) ? fw : Fw;
-	mp.pfw = &fw2;
-	mp.button_window = ButtonWindow;
+	exc2 = exc_clone_context(exc, NULL, 0);
+	mp.pexc = &exc2;
 	MR_IS_TEAR_OFF_MENU(menu) = 0;
-	tc = Context;
-	mp.pcontext = &tc;
 	mp.flags.has_default_action = (action != NULL);
-	mp.flags.is_menu_from_frame_or_window_or_titlebar = False;
 	mp.flags.is_sticky = fStaysUp;
 	mp.flags.is_submenu = False;
 	mp.flags.is_already_mapped = False;
-	mp.eventp = teventp;
+	mp.flags.is_triggered_by_keypress =
+		(exc->x.etrigger->type == KeyPress);
 	mp.pops = &mops;
 	mp.ret_paction = &ret_action;
-
 	do_menu(&mp, &mret);
 	if (mret.rc == MENU_DOUBLE_CLICKED && action)
 	{
-		old_execute_function(F_PASS_EXEC_ARGS, 0, NULL);
+		execute_function(cond_rc, exc2, action, 0);
 	}
+	if (ret_action != NULL)
+	{
+		free(ret_action);
+	}
+	exc_destroy_context(exc2);
 
 	return;
 }
@@ -268,7 +242,7 @@ void CMD_DestroyMenuStyle(F_CMD_ARGS)
 	{
 		fvwm_msg(ERR,"DestroyMenuStyle",
 			 "cannot destroy default menu style. "
-			 "To reset the default menu style use\n	 %s",
+			 "To reset the default menu style use\n  %s",
 			 DEFAULT_MENU_STYLE);
 		return;
 	}
