@@ -212,19 +212,19 @@ MenuItem *menuitem_clone(MenuItem *mi)
 }
 
 /* Calculate the size of the various parts of the item.  The sizes are returned
- * through mips. */
+ * through mipst. */
 void menuitem_get_size(
-	MenuItem *mi, MenuItemPartSizes *mips, FlocaleFont *font,
+	MenuItem *mi, MenuItemPartSizesT *mipst, FlocaleFont *font,
 	Bool do_reverse_icon_order)
 {
 	int i;
 	int j;
 	unsigned short w;
 
-	memset(mips, 0, sizeof(MenuItemPartSizes));
+	memset(mipst, 0, sizeof(MenuItemPartSizesT));
 	if (MI_IS_POPUP(mi))
 	{
-		mips->triangle_width = MENU_TRIANGLE_WIDTH;
+		mipst->triangle_width = MENU_TRIANGLE_WIDTH;
 	}
 	else if (MI_IS_TITLE(mi) && !MI_HAS_PICTURE(mi))
 	{
@@ -252,9 +252,9 @@ void menuitem_get_size(
 				font, MI_LABEL(mi)[0], MI_LABEL_STRLEN(mi)[0]);
 			MI_LABEL_OFFSET(mi)[0] = w;
 			MI_IS_TITLE_CENTERED(mi) = True;
-			if (mips->title_width < w)
+			if (mipst->title_width < w)
 			{
-				mips->title_width = w;
+				mipst->title_width = w;
 			}
 			return;
 		}
@@ -268,15 +268,15 @@ void menuitem_get_size(
 			w = FlocaleTextWidth(
 				font, MI_LABEL(mi)[i], MI_LABEL_STRLEN(mi)[i]);
 			MI_LABEL_OFFSET(mi)[i] = w;
-			if (mips->label_width[i] < w)
+			if (mipst->label_width[i] < w)
 			{
-				mips->label_width[i] = w;
+				mipst->label_width[i] = w;
 			}
 		}
 	}
-	if (MI_PICTURE(mi) && mips->picture_width < MI_PICTURE(mi)->width)
+	if (MI_PICTURE(mi) && mipst->picture_width < MI_PICTURE(mi)->width)
 	{
-		mips->picture_width = MI_PICTURE(mi)->width;
+		mipst->picture_width = MI_PICTURE(mi)->width;
 	}
 	for (i = 0; i < MAX_MENU_ITEM_MINI_ICONS; i++)
 	{
@@ -287,7 +287,7 @@ void menuitem_get_size(
 			/* Reverse mini icon order for left submenu style. */
 			k = (do_reverse_icon_order == True) ?
 				MAX_MENU_ITEM_MINI_ICONS - 1 - i : i;
-			mips->icon_width[k] = MI_MINI_ICON(mi)[i]->width;
+			mipst->icon_width[k] = MI_MINI_ICON(mi)[i]->width;
 		}
 	}
 
@@ -318,20 +318,10 @@ void menuitem_paint(
 	int y;
 	int lit_x_start;
 	int lit_x_end;
-#if 0
-	GC ShadowGC;
-	GC ReliefGC;
-	GC on_gc;
-	GC off_gc;
-	GC text_gc;
-	int on_cs = -1;
-	int off_cs = -1;
-#else
 	gc_quad_t gcs;
 	gc_quad_t off_gcs;
 	int cs = -1;
-	int offff_cs;
-#endif
+	int off_cs;
 	FvwmRenderAttributes fra;
 	/*Pixel fg, fgsh;*/
 	short relief_thickness = ST_RELIEF_THICKNESS(ms);
@@ -384,21 +374,15 @@ void menuitem_paint(
 		}
 	}
 
-	offff_cs = ST_CSET_MENU(ms);
-	if (is_item_selected)
-	{
-		cs = ST_CSET_ACTIVE(ms);
-	}
-	else
-	{
-		cs = offff_cs;
-	}
+	off_cs = ST_HAS_MENU_CSET(ms) ? ST_CSET_MENU(ms) : -1;
 	/* Note: it's ok to pass a NULL label to is_function_allowed. */
-	if (!is_function_allowed(
+	if (!IS_EWMH_DESKTOP_FW(mpip->fw) &&
+	    !is_function_allowed(
 		    MI_FUNC_TYPE(mi), MI_LABEL(mi)[0], mpip->fw, True, False))
 	{
 		gcs = ST_MENU_STIPPLE_GCS(ms);
 		off_gcs = gcs;
+		off_cs = ST_HAS_GREYED_CSET(ms) ? ST_CSET_GREYED(ms) : -1;
 	}
 	else if (is_item_selected)
 	{
@@ -410,6 +394,14 @@ void menuitem_paint(
 		gcs = ST_MENU_INACTIVE_GCS(ms);
 		off_gcs = ST_MENU_INACTIVE_GCS(ms);
 	}
+	if (is_item_selected)
+	{
+		cs = (ST_HAS_ACTIVE_CSET(ms)) ? ST_CSET_ACTIVE(ms) : -1;
+	}
+	else
+	{
+		cs = off_cs;
+	}
 
 	/***************************************************************
 	 * Hilight the item.
@@ -466,6 +458,7 @@ void menuitem_paint(
 	}
 
 	MI_WAS_DESELECTED(mi) = False;
+	memset(&fra, 0, sizeof(fra));
 	fra.mask = 0;
 
 	/* Hilight 3D */
@@ -604,17 +597,15 @@ void menuitem_paint(
 	}
 	fws->win = mpip->w;
 	fws->y = text_y;
-	fws->flags.has_colorset = False;
+	fws->flags.has_colorset = 0;
 	b.y = text_y - ST_PSTDFONT(ms)->ascent;
 	b.height = ST_PSTDFONT(ms)->height + 1; /* ? */
 	if (!item_cleared && mpip->ev)
 	{
 		int u,v;
 		if (!frect_get_seg_intersection(
-			mpip->ev->xexpose.y,
-			mpip->ev->xexpose.height,
-			b.y, b.height,
-			&u, &v))
+			mpip->ev->xexpose.y, mpip->ev->xexpose.height,
+			b.y, b.height, &u, &v))
 		{
 			/* empty intersection */
 			empty_inter = True;
@@ -642,12 +633,12 @@ void menuitem_paint(
 			{
 				/* label is in unhilighted area */
 				fws->gc = off_gcs.fore_gc;
-				tmp_cs = offff_cs;
+				tmp_cs = off_cs;
 			}
 			if (tmp_cs >= 0)
 			{
 				fws->colorset = &Colorset[tmp_cs];
-				fws->flags.has_colorset = True;
+				fws->flags.has_colorset = 1;
 			}
 			fws->str = MI_LABEL(mi)[i];
 			b.x = fws->x = MI_LABEL_OFFSET(mi)[i];
@@ -665,7 +656,8 @@ void menuitem_paint(
 					b.x = s_x;
 					b.width = s_w;
 					region = XCreateRegion();
-					XUnionRectWithRegion(&b, region, region);
+					XUnionRectWithRegion(
+						&b, region, region);
 					fws->flags.has_clip_region = True;
 					fws->clip_region = region;
 					draw_string = True;
@@ -682,10 +674,11 @@ void menuitem_paint(
 				if (!item_cleared && xft_clear)
 				{
 					clear_menu_item_background(
-						mpip,
-						b.x, b.y, b.width, b.height);
+						mpip, b.x, b.y, b.width,
+						b.height);
 				}
-				FlocaleDrawString(dpy, ST_PSTDFONT(ms), fws, 0);
+				FlocaleDrawString(
+					dpy, ST_PSTDFONT(ms), fws, 0);
 
 				/* hot key */
 				if (MI_HAS_HOTKEY(mi) && !MI_IS_TITLE(mi) &&
@@ -694,7 +687,7 @@ void menuitem_paint(
 				    MI_HOTKEY_COLUMN(mi) == i)
 				{
 					FlocaleDrawUnderline(
-						dpy, ST_PSTDFONT(ms),fws,
+						dpy, ST_PSTDFONT(ms), fws,
 						MI_HOTKEY_COFFSET(mi));
 				}
 			}
@@ -761,7 +754,7 @@ void menuitem_paint(
 		else
 		{
 			tmp_gc = off_gcs.fore_gc;
-			tmp_cs = offff_cs;
+			tmp_cs = off_cs;
 		}
 		fra.mask = FRAM_DEST_IS_A_WINDOW;
 		if (tmp_cs >= 0)
@@ -795,7 +788,7 @@ void menuitem_paint(
 			}
 			PGraphicsRenderPicture(
 				dpy, mpip->w, MI_PICTURE(mi), &fra,
-				mpip->w, tmp_gc, Scr.MonoGC, None,
+				mpip->w, tmp_gc, Scr.MonoGC, Scr.AlphaGC,
 				b.x - x, b.y - y, b.width, b.height,
 				b.x, b.y, b.width, b.height, False);
 		}
@@ -844,7 +837,7 @@ void menuitem_paint(
 			{
 				/* icon is in unhilighted area */
 				tmp_gc = off_gcs.fore_gc;
-				tmp_cs = offff_cs;
+				tmp_cs = off_cs;
 			}
 			fra.mask = FRAM_DEST_IS_A_WINDOW;
 			if (tmp_cs >= 0)
@@ -882,7 +875,7 @@ void menuitem_paint(
 				}
 				PGraphicsRenderPicture(
 					dpy, mpip->w, MI_MINI_ICON(mi)[i], &fra,
-					mpip->w, tmp_gc, Scr.MonoGC, None,
+					mpip->w, tmp_gc, Scr.MonoGC, Scr.AlphaGC,
 					b.x - MDIM_ICON_X_OFFSET(*dim)[k],
 					b.y - y, b.width, b.height,
 					b.x, b.y, b.width, b.height, False);
