@@ -409,15 +409,15 @@ static int do_execute_module(F_CMD_ARGS, Bool desperate)
 #endif
 		if (!Pdefault)
 		{
-			char *visualid, *colormap;
+			char visualid[32];
+			char colormap[32];
 
-			visualid = safemalloc(32);
-			sprintf(visualid, "FVWM_VISUALID=%lx",
+			sprintf(
+				visualid, "FVWM_VISUALID=%lx",
 				XVisualIDFromVisual(Pvisual));
-			putenv(visualid);
-			colormap = safemalloc(32);
+			flib_putenv("FVWM_VISUALID", visualid);
 			sprintf(colormap, "FVWM_COLORMAP=%lx", Pcmap);
-			putenv(colormap);
+			flib_putenv("FVWM_COLORMAP", colormap);
 		}
 
 		/* Why is this execvp??  We've already searched the module
@@ -852,7 +852,10 @@ void CMD_KillModule(F_CMD_ARGS)
 	GetNextToken(action, &alias);
 	KillModuleByName(module, alias);
 	free(module);
-
+	if (alias)
+	{
+		free(alias);
+	}
 	return;
 }
 
@@ -1741,8 +1744,8 @@ static void DeleteMessageQueueBuff(int module)
 	{
 		/* remove from queue */
 		fqueue_remove_or_operate_from_front(
-			&pipeQueue[module], NULL, NULL);
-		/* we don't need to free the ocj->data here because it's in the
+			&pipeQueue[module], NULL, NULL, NULL, NULL);
+		/* we don't need to free the obj->data here because it's in the
 		 * same malloced block as the obj itself. */
 		free(obj);
 	}
@@ -1912,7 +1915,8 @@ void ExecuteCommandQueue(void)
 	while (fqueue_get_first(&cqueue, (void **)&obj) == 1)
 	{
 		/* remove from queue */
-		fqueue_remove_or_operate_from_front(&cqueue, NULL, NULL);
+		fqueue_remove_or_operate_from_front(
+			&cqueue, NULL, NULL, NULL, NULL);
 		/* execute and destroy */
 		if (obj->command)
 		{
@@ -1938,8 +1942,10 @@ void CMD_Send_WindowList(F_CMD_ARGS)
 	}
 	SendPacket(mod, M_NEW_DESK, 1, Scr.CurrentDesk);
 	SendPacket(
-		mod, M_NEW_PAGE, 5, Scr.Vx, Scr.Vy, Scr.CurrentDesk, Scr.VxMax,
-		Scr.VyMax);
+		mod, M_NEW_PAGE, 7, Scr.Vx, Scr.Vy, Scr.CurrentDesk,
+		Scr.MyDisplayWidth, Scr.MyDisplayHeight,
+		(int)(Scr.VxMax / Scr.MyDisplayWidth) + 1,
+		(int)(Scr.VyMax / Scr.MyDisplayHeight) + 1);
 
 	if (Scr.Hilite != NULL)
 	{
