@@ -1821,7 +1821,7 @@ static void DoSnapAttract(
 			&scr_y1);
 
 		/* snap to right edge */
-		if (scr_x1 != Scr.MyDisplayWidth  &&
+		if (scr_x1 < Scr.MyDisplayWidth &&
 		    *px + Width >= scr_x1 && *px + Width <
 		    scr_x1 + Scr.XiMoveResistance)
 		{
@@ -1829,7 +1829,7 @@ static void DoSnapAttract(
 			do_recalc_rectangle = True;
 		}
 		/* snap to left edge */
-		else if (scr_x0 != 0 &&
+		else if (scr_x0 > 0 &&
 			 *px <= scr_x0 && scr_x0 - *px < Scr.XiMoveResistance)
 		{
 			*px = scr_x0;
@@ -1845,14 +1845,14 @@ static void DoSnapAttract(
 				&scr_x1, &scr_y1);
 		}
 		/* snap to bottom edge */
-		if (scr_y1 != Scr.MyDisplayHeight &&
+		if (scr_y1 < Scr.MyDisplayHeight &&
 		    *py + Height >= scr_y1 && *py + Height <
 		    scr_y1 + Scr.XiMoveResistance)
 		{
 			*py = scr_y1 - Height;
 		}
 		/* snap to top edge */
-		else if (scr_y0 != 0 &&
+		else if (scr_y0 > 0 &&
 			 *py <= scr_y0 && scr_y0 - *py < Scr.XiMoveResistance)
 		{
 			*py = scr_y0;
@@ -1903,6 +1903,7 @@ Bool __move_loop(
 	Bool nosnap_enabled = False;
 	FvwmWindow *fw = exc->w.fw;
 	unsigned int draw_parts = PART_NONE;
+	XEvent e;
 
 	if (!GrabEm(CRS_MOVE, GRAB_NORMAL))
 	{
@@ -1980,10 +1981,10 @@ Bool __move_loop(
 	}
 	DisplayPosition(fw, exc->x.elast, xl, yt, True);
 
+	memset(&e, 0, sizeof(e));
 	while (!finished && bad_window != FW_W(fw))
 	{
 		int rc = 0;
-		XEvent e;
 		int old_xl;
 		int old_yt;
 
@@ -2828,8 +2829,8 @@ static Bool __resize_window(F_CMD_ARGS)
 	frame_move_resize_args mr_args = NULL;
 	long evmask;
 	FvwmWindow *fw = exc->w.fw;
+	XEvent ev;
 
-/* 	fprintf(stderr,"dje: fvwm entering resize window\n"); */
 	bad_window = False;
 	ResizeWindow = FW_W_FRAME(fw);
 	if (FQueryPointer(
@@ -2882,7 +2883,6 @@ static Bool __resize_window(F_CMD_ARGS)
 	{
 		rectangle new_g;
 
-/* 		fprintf(stderr,"dje: resize args equal 2\n"); */
 		/* size will be less or equal to requested */
 		new_g = fw->frame_g;
 		constrain_size(
@@ -3171,23 +3171,23 @@ static Bool __resize_window(F_CMD_ARGS)
 	}
 
 	/* loop to resize */
+	memset(&ev, 0, sizeof(ev));
 	while (!finished && bad_window != FW_W(fw))
 	{
 		int rc = 0;
-		XEvent ev;
 
 		/* block until there is an interesting event */
-		while (rc != -1 && !FCheckMaskEvent(dpy, evmask, &ev))
+		while (rc != -1 &&
+		       (!FPending(dpy) || !FCheckMaskEvent(dpy, evmask, &ev)))
 		{
 			rc = HandlePaging(
-				&ev, Scr.EdgeScrollX, Scr.EdgeScrollY, &x,
-				&y, &delta_x, &delta_y, False, False, True);
+				&ev, Scr.EdgeScrollX, Scr.EdgeScrollY, &x, &y,
+				&delta_x, &delta_y, False, False, True);
 			if (rc == 1)
 			{
 				/* Fake an event to force window reposition */
 				ev.type = MotionNotify;
 				ev.xmotion.time = fev_get_evtime();
-/* 				fprintf(stderr,"dje: force redraw\n"); */
 				fForceRedraw = True;
 				break;
 			}
