@@ -46,6 +46,7 @@
 #include "stack.h"
 #include "ewmh.h"
 #include "icons.h"
+#include "add_window.h"
 
 #ifndef MIN
 #define MIN(A,B) ((A)<(B)? (A):(B))
@@ -1031,12 +1032,20 @@ Bool PlaceWindow(
 
     if (SUSE_START_ON_SCREEN(sflags) && flags.do_honor_starts_on_screen)
     {
+      fscreen_scr_t mangle_screen;
+
       /*
        * If StartsOnScreen has been given for a window, translate its
        * USPosition so that it is relative to that particular screen.
        * If we don't do this, then a geometry would completely cancel
        * the effect of the StartsOnScreen style.
        *
+       * However, some applications try to remember their position.  This would
+       * break if these were translated to screen coordinates.  There is no
+       * reliable way to do it.  Currently, if the desired place does not
+       * intersect the target screen, we assume the window position must be
+       * adjusted to the screen origin.
+       *
        * So there are two ways to get a window to pop up on a particular
        * Xinerama screen.  1: The intuitive way giving a geometry hint
        * relative to the desired screen's 0,0 along with the appropriate
@@ -1045,8 +1054,24 @@ Bool PlaceWindow(
        * the geometry hint in terms of the global screen.
        */
 
-      FScreenTranslateCoordinates(
-	NULL, XineramaScreen, NULL, FSCREEN_GLOBAL, &attr_g->x, &attr_g->y);
+      mangle_screen = FScreenFetchMangledScreenFromUSPosHints(&(fw->hints));
+      if (mangle_screen != FSCREEN_GLOBAL)
+      {
+	/* whoever set this hint knew exactly what he was doing; so ignore the
+	 * StartsOnScreen style */
+	flags.do_honor_starts_on_screen = 0;
+      }
+      else if (attr_g->x + attr_g->width < screen_g.x ||
+	  attr_g->x >= screen_g.x + screen_g.width ||
+	  attr_g->y + attr_g->height < screen_g.y ||
+	  attr_g->y >= screen_g.y + screen_g.height)
+      {
+	/* desired coordinates do not intersect the target screen.  Let's
+	 * assume the application specified global coordinates and translate
+	 * them to the screen. */
+	FScreenTranslateCoordinates(
+	  NULL, XineramaScreen, NULL, FSCREEN_GLOBAL, &attr_g->x, &attr_g->y);
+      }
     }
 
     /*
@@ -1143,10 +1168,10 @@ Bool PlaceWindow(
 
 void CMD_PlaceAgain(F_CMD_ARGS)
 {
+	int old_desk;
 	char *token;
 	float noMovement[1] = {1.0};
 	float *ppctMovement = noMovement;
-	window_style style;
 	rectangle attr_g;
 	XWindowAttributes attr;
 	Bool do_move_animated = False;
@@ -1169,6 +1194,11 @@ void CMD_PlaceAgain(F_CMD_ARGS)
 			do_place_icon = True;
 		}
 	}
+	old_desk = fw->Desk;
+	if (IS_ICONIFIED(fw) && !do_place_icon)
+	{
+		return;
+	}
 	if (IS_ICONIFIED(fw) && do_place_icon)
 	{
 		rectangle new_g;
@@ -1178,6 +1208,7 @@ void CMD_PlaceAgain(F_CMD_ARGS)
 		{
 			return;
 		}
+		fw->Desk = Scr.CurrentDesk;
 		get_icon_geometry(fw, &old_g);
 		SET_ICON_MOVED(fw, 0);
 		AutoPlaceIcon(fw, NULL, False);
@@ -1188,6 +1219,7 @@ void CMD_PlaceAgain(F_CMD_ARGS)
 	}
 	else
 	{
+		window_style style;
 		initial_window_options_type win_opts;
 
 		memset(&win_opts, 0, sizeof(win_opts));
@@ -1196,14 +1228,19 @@ void CMD_PlaceAgain(F_CMD_ARGS)
 		attr_g.y = attr.y;
 		attr_g.width = attr.width;
 		attr_g.height = attr.height;
-		PlaceWindow(
-			exc, &style.flags, &attr_g, SGET_START_DESK(style),
-			SGET_START_PAGE_X(style), SGET_START_PAGE_Y(style),
-			SGET_START_SCREEN(style), PLACE_AGAIN, &win_opts);
+
+		setup_window_placement(exc->w.fw, &style, &attr_g, &win_opts);
 		AnimatedMoveFvwmWindow(
 			fw, FW_W_FRAME(fw), -1, -1, attr_g.x, attr_g.y, False,
 			-1, ppctMovement);
 	}
+	if (fw->Desk != old_desk)
+	{
+		int new_desk = fw->Desk;
+
+		fw->Desk = old_desk;
+		do_move_window_to_desk(fw, new_desk);
+	}
 
 	return;
 }
