@@ -145,10 +145,7 @@ static void apply_window_updates(
 				S_IS_STICKY_ACROSS_DESKS(SCF(*pstyle)), 1, 1);
 			handle_stick(NULL, exc, "", 0, 0, 1, 0);
 		}
-		else
-		{
-			flags->do_update_icon_title = True;
-		}
+		flags->do_update_icon_title = True;
 	}
 	else if (flags->do_update_stick)
 	{
@@ -324,7 +321,7 @@ static void apply_window_updates(
 		{
 			flags->do_setup_frame = True;
 			flags->do_redraw_decoration = True;
-		} 
+		}
 	}
 	if (0 && flags->do_update_title_dir)
 	{
@@ -456,7 +453,7 @@ static void apply_window_updates(
 	if (flags->do_update_icon_background_cs)
 	{
 		int old_cs = t->icon_background_cs;
-		
+
 		update_icon_background_cs_style(t, pstyle);
 		if ((old_cs < 0 && t->icon_background_cs >= 0) ||
 		    (old_cs >= 0 && t->icon_background_cs < 0))
@@ -614,8 +611,7 @@ static void apply_window_updates(
 /* takes only care of destroying windows that have to go away. */
 void destroy_scheduled_windows(void)
 {
-	FvwmWindow *t;
-	FvwmWindow *next;
+	flist *t;
 	Bool do_need_ungrab = False;
 
 	if (Scr.flags.is_executing_complex_function ||
@@ -633,15 +629,11 @@ void destroy_scheduled_windows(void)
 	Scr.flags.is_window_scheduled_for_destroy = 0;
 	/* need to destroy one or more windows before looking at the window
 	 * list */
-	for (t = Scr.FvwmRoot.next, next = NULL; t != NULL; t = next)
+	for (t = Scr.FWScheduledForDestroy; t != NULL; t = t->next)
 	{
-		next = t->next;
-		if (IS_SCHEDULED_FOR_DESTROY(t))
-		{
-			SET_SCHEDULED_FOR_DESTROY(t, 0);
-			destroy_window(t);
-		}
+		destroy_window(t->object);
 	}
+	Scr.FWScheduledForDestroy = flist_free_list(Scr.FWScheduledForDestroy);
 	MyXUngrabServer(dpy);
 	if (do_need_ungrab)
 	{
