@@ -16,12 +16,16 @@
 #ifndef _UPDATE_
 #define _UPDATE_
 
+/* Ipmortant not:  All the flags below must have a positive syntax.  If a flag
+ * is set, this indicates that something has to happen with the window. */
+
 typedef struct
 {
 	unsigned do_broadcast_focus : 1;
 	unsigned do_redecorate : 1;
 	unsigned do_redecorate_transient : 1;
 	unsigned do_redraw_decoration : 1;
+	unsigned do_redraw_icon : 1;
 	unsigned do_resize_window : 1;
 	unsigned do_refresh : 1;
 	unsigned do_setup_focus_policy : 1;
@@ -35,9 +39,13 @@ typedef struct
 	unsigned do_update_icon_placement : 1;
 	unsigned do_update_icon_size_limits : 1;
 	unsigned do_update_icon_title : 1;
+	unsigned do_update_icon_title_cs : 1;
+	unsigned do_update_icon_title_cs_hi : 1;
+	unsigned do_update_icon_background_cs : 1;
 	unsigned do_update_visible_icon_name : 1;
 	unsigned do_update_mini_icon : 1;
 	unsigned do_update_ewmh_mini_icon : 1;
+	unsigned do_update_rotated_title : 1;
 	unsigned do_update_stick : 1;
 	unsigned do_update_stick_icon : 1;
 	unsigned do_update_title_dir : 1;
