@@ -400,6 +400,8 @@ static void MapDesk(int desk, Bool grab)
 			/*  If window is sticky, just update its desk (it's
 			 * still mapped).  */
 			t->Desk = desk;
+			GNOME_SetDesk(t);
+			GNOME_SetWinArea(t);
 			if (sf == t)
 			{
 				StickyWin = t;
@@ -1808,7 +1810,12 @@ void CMD_GotoDeskAndPage(F_CMD_ARGS)
 		val[1] = prev_desk_and_page_page_x;
 		val[2] = prev_desk_and_page_page_y;
 	}
-	else if (GetIntegerArguments(action, NULL, val, 3) != 3)
+	else if (GetIntegerArguments(action, NULL, val, 3) == 3)
+	{
+		val[1] *= Scr.MyDisplayWidth;
+		val[2] *= Scr.MyDisplayHeight;
+	}
+	else
 	{
 		return;
 	}
@@ -1820,9 +1827,7 @@ void CMD_GotoDeskAndPage(F_CMD_ARGS)
 	}
 	prev_desk_and_page_page_x = Scr.Vx;
 	prev_desk_and_page_page_y = Scr.Vy;
-	MoveViewport(
-		val[1] * Scr.MyDisplayWidth, val[2] * Scr.MyDisplayHeight,
-		True);
+	MoveViewport(val[1], val[2], True);
 	if (is_new_desk)
 	{
 		prev_desk = Scr.CurrentDesk;
