@@ -88,18 +88,18 @@
 	(fw)->flags.common.s.icon_override = ((x) & ICON_OVERRIDE_MASK)
 #define SETM_ICON_OVERRIDE_MODE(fw,x) \
 	(fw)->flag_mask.common.s.icon_override = ((x) ? ICON_OVERRIDE_MASK : 0)
-#define IS_ICON_STICKY_ON_PAGE(fw) \
-	((fw)->flags.common.s.is_icon_sticky_on_page)
-#define SET_ICON_STICKY_ON_PAGE(fw,x) \
-	(fw)->flags.common.s.is_icon_sticky_on_page = !!(x)
-#define SETM_ICON_STICKY_ON_PAGE(fw,x) \
-	(fw)->flag_mask.common.s.is_icon_sticky_on_page = !!(x)
-#define IS_ICON_STICKY_ON_DESK(fw) \
-	((fw)->flags.common.s.is_icon_sticky_on_desk)
-#define SET_ICON_STICKY_ON_DESK(fw,x) \
-	(fw)->flags.common.s.is_icon_sticky_on_desk = !!(x)
-#define SETM_ICON_STICKY_ON_DESK(fw,x) \
-	(fw)->flag_mask.common.s.is_icon_sticky_on_desk = !!(x)
+#define IS_ICON_STICKY_ACROSS_PAGES(fw) \
+	((fw)->flags.common.s.is_icon_sticky_across_pages)
+#define SET_ICON_STICKY_ACROSS_PAGES(fw,x) \
+	(fw)->flags.common.s.is_icon_sticky_across_pages = !!(x)
+#define SETM_ICON_STICKY_ACROSS_PAGES(fw,x) \
+	(fw)->flag_mask.common.s.is_icon_sticky_across_pages = !!(x)
+#define IS_ICON_STICKY_ACROSS_DESKS(fw) \
+	((fw)->flags.common.s.is_icon_sticky_across_desks)
+#define SET_ICON_STICKY_ACROSS_DESKS(fw,x) \
+	(fw)->flags.common.s.is_icon_sticky_across_desks = !!(x)
+#define SETM_ICON_STICKY_ACROSS_DESKS(fw,x) \
+	(fw)->flag_mask.common.s.is_icon_sticky_across_desks = !!(x)
 #define USE_ICON_POSITION_HINT(fw) \
 	((fw)->flags.common.s.use_icon_position_hint)
 #define SET_USE_ICON_POSITION_HINT(fw,x) \
@@ -174,18 +174,18 @@
 	(fw)->flags.common.s.is_icon_suppressed = !!(x)
 #define SETM_ICON_SUPPRESSED(fw,x) \
 	(fw)->flag_mask.common.s.is_icon_suppressed = !!(x)
-#define IS_STICKY_ON_PAGE(fw) \
-	((fw)->flags.common.is_sticky_on_page)
-#define SET_STICKY_ON_PAGE(fw,x) \
-	(fw)->flags.common.is_sticky_on_page = !!(x)
-#define SETM_STICKY_ON_PAGE(fw,x) \
-	(fw)->flag_mask.common.is_sticky_on_page = !!(x)
-#define IS_STICKY_ON_DESK(fw) \
-	((fw)->flags.common.is_sticky_on_desk)
-#define SET_STICKY_ON_DESK(fw,x) \
-	(fw)->flags.common.is_sticky_on_desk = !!(x)
-#define SETM_STICKY_ON_DESK(fw,x) \
-	(fw)->flag_mask.common.is_sticky_on_desk = !!(x)
+#define IS_STICKY_ACROSS_PAGES(fw) \
+	((fw)->flags.common.is_sticky_across_pages)
+#define SET_STICKY_ACROSS_PAGES(fw,x) \
+	(fw)->flags.common.is_sticky_across_pages = !!(x)
+#define SETM_STICKY_ACROSS_PAGES(fw,x) \
+	(fw)->flag_mask.common.is_sticky_across_pages = !!(x)
+#define IS_STICKY_ACROSS_DESKS(fw) \
+	((fw)->flags.common.is_sticky_across_desks)
+#define SET_STICKY_ACROSS_DESKS(fw,x) \
+	(fw)->flags.common.is_sticky_across_desks = !!(x)
+#define SETM_STICKY_ACROSS_DESKS(fw,x) \
+	(fw)->flag_mask.common.is_sticky_across_desks = !!(x)
 #define HAS_ICON_FONT(fw) \
 	((fw)->flags.common.has_icon_font)
 #define SET_HAS_ICON_FONT(fw,x) \
@@ -246,6 +246,30 @@
 	(fw)->flags.common.s.is_psize_fixed = !!(x)
 #define SETM_PSIZE_FIXED(fw,x) \
 	(fw)->flag_mask.common.s.is_psize_fixed = !!(x)
+#define IS_UNICONIFIABLE(fw) \
+        ((fw)->flags.common.s.is_uniconifiable)
+#define SET_IS_UNICONIFIABLE(fw,x) \
+        (fw)->flags.common.s.is_uniconifiable = !!(x)
+#define SETM_IS_UNICONIFIABLE(fw,x) \
+        (fw)->flag_mask.common.s.is_uniconifiable = !!(x)
+#define IS_UNMAXIMIZABLE(fw) \
+        ((fw)->flags.common.s.is_unmaximizable)
+#define SET_IS_UNMAXIMIZABLE(fw,x) \
+        (fw)->flags.common.s.is_unmaximizable = !!(x)
+#define SETM_IS_UNMAXIMIZABLE(fw,x) \
+        (fw)->flag_mask.common.s.is_unmaximizable = !!(x)
+#define IS_UNCLOSABLE(fw) \
+        ((fw)->flags.common.s.is_unclosable)
+#define SET_IS_UNCLOSABLE(fw,x) \
+        (fw)->flags.common.s.is_unclosable = !!(x)
+#define SETM_IS_UNCLOSABLE(fw,x) \
+        (fw)->flag_mask.common.s.is_unclosable = !!(x)
+#define IS_MAXIMIZE_FIXED_SIZE_DISALLOWED(fw) \
+        ((fw)->flags.common.s.is_maximize_fixed_size_disallowed)
+#define SET_MAXIMIZE_FIXED_SIZE_DISALLOWED(fw,x) \
+        (fw)->flags.common.s.is_maximize_fixed_size_disallowed = !!(x)
+#define SETM_MAXIMIZE_FIXED_SIZE_DISALLOWED(fw,x) \
+        (fw)->flag_mask.common.s.is_maximize_fixed_size_disallowed = !!(x)
 #define HAS_DEPRESSABLE_BORDER(fw) \
 	((fw)->flags.common.s.has_depressable_border)
 
@@ -273,6 +297,12 @@
 	(fw)->flags.common.s.is_bottom_title_rotated = !!(x)
 #define SETM_IS_BOTTOM_TITLE_ROTATED(fw,x) \
 	(fw)->flag_mask.common.s.is_bottom_title_rotated = !!(x)
+#define USE_TITLE_DECOR_ROTATION(fw) \
+	((fw)->flags.common.s.use_title_decor_rotation)
+#define SET_USE_TITLE_DECOR_ROTATION(fw,x) \
+	(fw)->flags.common.s.use_title_decor_rotation = !!(x)
+#define SETM_USE_TITLE_DECOR_ROTATION(fw,x) \
+	(fw)->flag_mask.common.s.use_title_decor_rotation = !!(x)
 
 /* access to the special flags of a window */
 #define DO_REUSE_DESTROYED(fw) \
