@@ -203,6 +203,7 @@ void CMD_WindowList(F_CMD_ARGS)
 	char tname[128];
 	char loc[64];
 	char *name=NULL;
+	Bool free_name = False;
 	int dwidth;
 	int dheight;
 	char *tlabel;
@@ -216,6 +217,7 @@ void CMD_WindowList(F_CMD_ARGS)
 	int desk = Scr.CurrentDesk;
 	unsigned long flags = SHOW_DEFAULT;
 	char *func = NULL;
+	char *ffunc = NULL;
 	char *tfunc = NULL;
 	char *default_action = NULL;
 	MenuReturn mret;
@@ -223,7 +225,6 @@ void CMD_WindowList(F_CMD_ARGS)
 	int low_layer = 0;  /* show all layers by default */
 	int high_layer = INT_MAX;
 	int max_label_width = 0;
-	int tc;
 	int show_listskip = 0; /* do not show listskip by default */
 	Bool use_hotkey = True;
 	KeyCode old_sor_keycode;
@@ -242,6 +243,7 @@ void CMD_WindowList(F_CMD_ARGS)
 	Bool was_get_menu_opts_called = False;
 	FvwmWindow * const fw = exc->w.fw;
 	const Window w = exc->w.w;
+	const exec_context_t *exc2;
 
 	memset(&mops, 0, sizeof(mops));
 	memset(&mret, 0, sizeof(MenuReturn));
@@ -831,6 +833,7 @@ void CMD_WindowList(F_CMD_ARGS)
 					name = t->visible_name;
 				}
 
+				free_name = False;
 				if (!name)
 				{
 					name = "NULL_NAME";
@@ -840,6 +843,7 @@ void CMD_WindowList(F_CMD_ARGS)
 				{
 					name = strdup(name);
 					name[max_label_width] = '\0';
+					free_name = True;
 				}
 
 				t_hot = safemalloc(strlen(name) + 80);
@@ -994,17 +998,12 @@ void CMD_WindowList(F_CMD_ARGS)
 					strcat(t_hot,"\t");
 					strcat(t_hot,tname);
 				}
-				if (!func)
-				{
-					tfunc = safemalloc(40);
-					sprintf(tfunc, "WindowListFunc %lu",
-						FW_W(t));
-				}
-				else
-				{
-					tfunc = safemalloc(strlen(func) + 32);
-					sprintf(tfunc,"%s %lu", func, FW_W(t));
-				}
+				ffunc = func ? func : "WindowListFunc";
+				tfunc = safemalloc(strlen(ffunc) + 36);
+				/* support two ways for now: window context
+				 * (new) and window id param (old) */
+				sprintf(tfunc, "WindowId %lu %s %lu",
+					FW_W(t), ffunc, FW_W(t));
 				AddToMenu(
 					mr, t_hot, tfunc, False, False, False);
 				free(tfunc);
@@ -1023,6 +1022,10 @@ void CMD_WindowList(F_CMD_ARGS)
 				{
 					free(t_hot);
 				}
+				if (free_name)
+				{
+					free(name);
+				}
 			}
 		}
 	}
@@ -1060,11 +1063,8 @@ void CMD_WindowList(F_CMD_ARGS)
 
 	memset(&mp, 0, sizeof(mp));
 	mp.menu = mr;
-	mp.exc = exc;
-	t = exc->w.fw;
-	mp.pfw = &t;
-	tc = exc->w.wcontext;
-	mp.pcontext = &tc;
+	exc2 = exc_clone_context(exc, NULL, 0);
+	mp.pexc = &exc2;
 	mp.flags.has_default_action = (default_action && *default_action != 0);
 	mp.flags.is_sticky = 1;
 	mp.flags.is_submenu = 0;
@@ -1083,7 +1083,7 @@ void CMD_WindowList(F_CMD_ARGS)
 	DestroyMenu(mr, False, False);
 	if (mret.rc == MENU_DOUBLE_CLICKED && default_action && *default_action)
 	{
-		execute_function(cond_rc, exc, default_action, 0);
+		execute_function(cond_rc, exc2, default_action, 0);
 	}
 	if (default_action != NULL)
 	{
@@ -1093,6 +1093,11 @@ void CMD_WindowList(F_CMD_ARGS)
 	{
 		FreeConditionMask(&mask);
 	}
+	if (sor_keyname && sor_keyname != sor_default_keyname)
+	{
+		free(sor_keyname);
+	}
+	exc_destroy_context(exc2);
 
 	return;
 }
