@@ -8,24 +8,27 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifndef F_RENDER_INTERFACE_H
 #define F_RENDER_INTERFACE_H
 
-void FRenderCopyArea(Display *dpy, Pixmap pixmap, Pixmap mask, Pixmap alpha,
-		     Drawable d,
-		     int src_x, int src_y,
-		     int dest_x, int dest_y, int dest_w, int dest_h,
-		     Bool do_repeat);
-void FRenderTintRectangle(Display *dpy, Window win, int shade_percent,
-			  Pixel tint, Pixmap mask, Drawable d,
-			 int dest_x, int dest_y, int dest_w, int dest_h);
+Bool FRenderTintRectangle(
+	Display *dpy, Window win, Pixmap mask, Pixel tint, int shade_percent,
+	Drawable d, int dest_x, int dest_y, int dest_w, int dest_h);
+
+int FRenderRender(
+	Display *dpy, Window win, Pixmap pixmap, Pixmap mask, Pixmap alpha,
+	int depth, int shade_percent, Pixel tint, int tint_percent,
+	Drawable d, GC gc, GC alpha_gc,
+	int src_x, int src_y, int src_w, int src_h,
+	int dest_x, int dest_y, int dest_w, int dest_h,
+	Bool do_repeat);
 
 #endif
