@@ -383,10 +383,10 @@ void FlocaleEncodeWinString(
  * ***************************************************************************/
 
 static
-void FlocaleFontStructDrawString(Display *dpy, FlocaleFont *flf, Drawable d,
-				 GC gc, int x, int y, Pixel fg, Pixel fgsh,
-				 Bool has_fg_pixels, FlocaleWinString *fws,
-				 int len, Bool image)
+void FlocaleFontStructDrawString(
+	Display *dpy, FlocaleFont *flf, Drawable d, GC gc, int x, int y,
+	Pixel fg, Pixel fgsh, Bool has_fg_pixels, FlocaleWinString *fws,
+	int len, Bool image)
 {
 	int xt = x;
 	int yt = y;
@@ -646,6 +646,136 @@ void FlocaleRotateDrawString(
 	return;
 }
 
+/* ***************************************************************************
+ * Fonts info and checking
+ * ***************************************************************************/
+
+static
+char *FlocaleGetFullNameOfFontStruct(Display *dpy, XFontStruct *font)
+{
+	char *full_name = NULL;
+	unsigned long value;
+
+	if (XGetFontProperty(font, XA_FONT, &value))
+	{
+		full_name = XGetAtomName(dpy, value);
+	}
+	return full_name;
+}
+
+static
+char *FlocaleGetCharsetOfFontStruct(Display *dpy, XFontStruct *font)
+{
+	int i = 0;
+	int count = 0;
+	char *charset = NULL;
+	char *full_name;
+
+	full_name = FlocaleGetFullNameOfFontStruct(dpy, font);
+	if (full_name == NULL)
+	{
+		return NULL;
+	}
+	while(full_name[i] != '\0' && count < 13)
+	{
+		if (full_name[i] == '-')
+		{
+			count++;
+		}
+		i++;
+	}
+
+	if (count != 13)
+	{
+		return NULL;
+	}
+	CopyString(&charset, full_name+i);
+	XFree(full_name);
+	return charset;
+}
+
+static
+char *FlocaleGetCharsetFromName(char *name)
+{
+	int l,i,e;
+	char *charset;
+
+	l = strlen(name);
+	i = l-1;
+	while(i >= 0 && name[i] != '-')
+	{
+		i--;
+	}
+	if (i == 0 || i == l-1)
+	{
+		return NULL;
+	}
+	i--;
+	e = i;
+	while(i >= 0 && name[i] != '-')
+	{
+		i--;
+	}
+	if (i <= 0 || e == i)
+	{
+		return NULL;
+	}
+	CopyString(&charset, name + i + 1);
+	return charset;
+}
+
+/* return NULL if it is not reasonable to load a FontSet.
+ * Currently return name if it is reasonable to load a FontSet, but in the
+ * future we may want to transform name for faster FontSet loading */
+static
+char *FlocaleFixNameForFontSet(Display *dpy, char *name, char *module)
+{
+	char *new_name;
+	char *charset;
+	XFontStruct *test_font = NULL;
+
+	if (!name)
+	{
+		return NULL;
+	}
+
+	new_name = name;
+
+	if (strchr(name, ','))
+	{
+		/* tmp, do not handle "," separated list */
+		return name;
+	}
+	charset = FlocaleGetCharsetFromName(name);
+	if (charset == NULL && !strchr(name, '*') && !strchr(name, '?'))
+	{
+		/* probably a font alias! */
+		if ((test_font = XLoadQueryFont(dpy, name)))
+		{
+			charset = FlocaleGetCharsetOfFontStruct(dpy, test_font);
+			XFreeFont(dpy, test_font);
+		}
+	}
+	if (charset != NULL)
+	{
+		if (!strchr(charset, '*') && !strchr(charset, '?') &&
+		    !FlocaleCharsetIsCharsetXLocale(dpy, charset, module))
+		{
+			/* if the charset is fully specified and do not match
+			 * one of the X locale charset */
+			new_name = NULL;
+#if 0
+			fprintf(stderr,"[%s][FlocaleGetFontSet]: WARNING -- "
+				"Use of a non X locale charset '%s' when "
+				"loading font: %s\n",
+				(module)? module:"fvwmlibs", charset, name);
+#endif
+		}
+		free(charset);
+	}
+	return new_name;
+}
+
 /* ***************************************************************************
  * Fonts loading
  * ***************************************************************************/
@@ -659,11 +789,18 @@ FlocaleFont *FlocaleGetFftFont(
 	char *fn, *hints = NULL;
 
 	hints = GetQuotedString(fontname, &fn, "/", NULL, NULL, NULL);
+	if (*fn == '\0')
+	{
+		free(fn);
+		fn = FLOCALE_FFT_FALLBACK_FONT;
+	}
 	fftf = FftGetFont(dpy, fn, module);
 	if (fftf == NULL)
 	{
-		if (fn != NULL)
+		if (fn != NULL && fn != FLOCALE_FFT_FALLBACK_FONT)
+		{
 			free(fn);
+		}
 		return NULL;
 	}
 	flf = (FlocaleFont *)safemalloc(sizeof(FlocaleFont));
@@ -671,13 +808,14 @@ FlocaleFont *FlocaleGetFftFont(
 	flf->count = 1;
 	flf->fftf = *fftf;
 	FlocaleCharsetSetFlocaleCharset(dpy, flf, hints, encoding, module);
-	FftGetFontHeights(
-		&flf->fftf, &flf->height, &flf->ascent, &flf->descent);
-	FftGetFontWidths(
-		flf, &flf->max_char_width);
+	FftGetFontHeights(&flf->fftf, &flf->height, &flf->ascent, &flf->descent);
+	FftGetFontWidths(flf, &flf->max_char_width);
 	free(fftf);
-	if (fn != NULL)
+	if (fn != NULL && fn != FLOCALE_FFT_FALLBACK_FONT)
+	{
 		free(fn);
+	}
+
 	return flf;
 }
 
@@ -692,13 +830,32 @@ FlocaleFont *FlocaleGetFontSet(
 	int mc,i;
 	char *ds;
 	XFontSetExtents *fset_extents;
-	char *fn, *hints = NULL;
+	char *fn, *hints = NULL, *fn_fixed = NULL;
 
 	hints = GetQuotedString(fontname, &fn, "/", NULL, NULL, NULL);
-	if (!(fontset = XCreateFontSet(dpy, fn, &ml, &mc, &ds)))
+	if (*fn == '\0')
 	{
-		if (fn != NULL)
+		free(fn);
+		fn = fn_fixed = FLOCALE_MB_FALLBACK_FONT;
+	}
+	else if (!(fn_fixed = FlocaleFixNameForFontSet(dpy, fn, module)))
+	{
+		if (fn != NULL && fn != FLOCALE_MB_FALLBACK_FONT)
+		{
 			free(fn);
+		}
+		return NULL;
+	}
+	if (!(fontset = XCreateFontSet(dpy, fn_fixed, &ml, &mc, &ds)))
+	{
+		if (fn_fixed && fn_fixed != fn)
+		{
+			free(fn_fixed);
+		}
+		if (fn != NULL && fn != FLOCALE_MB_FALLBACK_FONT)
+		{
+			free(fn);
+		}
 		return NULL;
 	}
 
@@ -740,8 +897,14 @@ FlocaleFont *FlocaleGetFontSet(
 	flf->descent = fset_extents->max_ink_extent.height +
 		fset_extents->max_ink_extent.y;
 	flf->max_char_width = fset_extents->max_ink_extent.width;
-	if (fn != NULL)
+	if (fn_fixed && fn_fixed != fn)
+	{
+		free(fn_fixed);
+	}
+	if (fn != NULL && fn != FLOCALE_MB_FALLBACK_FONT)
+	{
 		free(fn);
+	}
 
 	return flf;
 }
@@ -757,10 +920,15 @@ FlocaleFont *FlocaleGetFont(
 
 	hints = GetQuotedString(fontname, &tmp, "/", NULL, NULL, NULL);
 	str = GetQuotedString(tmp, &fn, ",", NULL, NULL, NULL);
-	while (!font && (fn && *fn))
+	while (!font && fn)
 	{
+		if (*fn == '\0')
+		{
+			free(fn);
+			fn = FLOCALE_FALLBACK_FONT;
+		}
 		font = XLoadQueryFont(dpy, fn);
-		if (fn != NULL)
+		if (fn != NULL && fn != FLOCALE_FALLBACK_FONT)
 		{
 			free(fn);
 			fn = NULL;
@@ -772,10 +940,14 @@ FlocaleFont *FlocaleGetFont(
 	}
 	if (font == NULL)
 	{
-		if (fn != NULL)
+		if (fn != NULL && fn != FLOCALE_FALLBACK_FONT)
+		{
 			free(fn);
+		}
 		if (tmp != NULL)
+		{
 			free(tmp);
+		}
 		return NULL;
 	}
 
@@ -792,10 +964,14 @@ FlocaleFont *FlocaleGetFont(
 	flf->max_char_width = font->max_bounds.width;
 	if (flf->font->max_byte1 > 0)
 		flf->flags.is_mb = True;
-	if (fn != NULL)
+	if (fn != NULL && fn != FLOCALE_FALLBACK_FONT)
+	{
 		free(fn);
+	}
 	if (tmp != NULL)
+	{
 		free(tmp);
+	}
 
 	return flf;
 }
@@ -807,7 +983,7 @@ FlocaleFont *FlocaleGetFontOrFontSet(
 {
 	FlocaleFont *flf = NULL;
 
-	if (fontname && strlen(fontname) > 4 &&
+	if (fontname && strlen(fontname) > 3 &&
 	    strncasecmp("xft:", fontname, 4) == 0)
 	{
 		if (FftSupport)
@@ -1375,6 +1551,21 @@ void FlocaleDrawString(
 		fgsh = fws->colorset->fgsh;
 		has_fg_pixels = True;
 	}
+	else if (flf->shadow_size != 0)
+	{
+		XGCValues xgcv;
+
+		if (XGetGCValues(dpy, fws->gc, GCForeground, &xgcv) != 0)
+		{
+			fg = xgcv.foreground;
+		}
+		else
+		{
+			fg = PictureBlackPixel();
+		}
+		fgsh = GetShadow(fg);
+		has_fg_pixels = True;
+	}
 
 	if (fws->flags.text_rotation != ROTATION_0 &&
 	    flf->fftf.fftfont == NULL)
@@ -1393,7 +1584,7 @@ void FlocaleDrawString(
 		int yt = fws->y;
 
 		FlocaleInitGstpArgs(&gstp_args, flf, fws, fws->x, fws->y);
-		if (flf->shadow_size != 0 && has_fg_pixels)
+		if (flf->shadow_size != 0)
 		{
 			XSetForeground(dpy, fws->gc, fgsh);
 			while (FlocaleGetShadowTextPosition(
@@ -1521,13 +1712,13 @@ int FlocaleGetMinOffset(
 	{
 	case ROTATION_270:
 	case ROTATION_180:
-		/* better than descent */ 
+		/* better than descent */
 		min_offset = (flf->descent + flf->height - flf->ascent)/2;
 		break;
 	case ROTATION_0:
-	case ROTATION_90:	
+	case ROTATION_90:
 	default:
-		/* better than ascent */ 
+		/* better than ascent */
 		min_offset = (flf->ascent + flf->height - flf->descent)/2;
 		break;
 	}
@@ -1536,13 +1727,13 @@ int FlocaleGetMinOffset(
 	{
 	case ROTATION_180:
 	case ROTATION_90:
-		/* better than descent */ 
+		/* better than descent */
 		min_offset = (flf->descent + flf->height - flf->ascent)/2;
 		break;
 	case ROTATION_270:
 	case ROTATION_0:
 	default:
-		/* better than ascent */ 
+		/* better than ascent */
 		min_offset = (flf->ascent + flf->height - flf->descent)/2;
 		break;
 	}
@@ -1585,8 +1776,9 @@ void FlocaleGetNameProperty(
 	{
 		/* Does not consider the conversion is REALLY succeeded:
 		 * XmbTextPropertyToTextList return 0 (== Success) on success,
-		 * a negative int if it fails (and in this case we are not here),
-		 * the number of unconvertible char on "partial" success*/
+		 * a negative int if it fails (and in this case we are not
+		 * here), the number of unconvertible char on "partial"
+		 * success*/
 		XFree(text_prop.value); /* return of XGetWM(Icon)Name() */
 		ret_name->name = *list;
 		ret_name->name_list = list;
@@ -1678,6 +1870,7 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 		(cs->iconv_index >= 0)?
 		cs->locale[cs->iconv_index]:"Not defined",
 		(cs->bidi)? "Yes":"No");
+	FlocaleCharsetPrintXOMInfo();
 	while (flf)
 	{
 		count++;
@@ -1699,7 +1892,7 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 			fprintf(stderr,"      Type: ");
 			if (flf->font)
 			{
-				fprintf(stderr,"FontStuct\n");
+				fprintf(stderr,"FontStruct\n");
 			}
 			else if (flf->fontset)
 			{
@@ -1729,11 +1922,11 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 					FftFontType *fftf;
 
 					fftf = &flf->fftf;
-					fprintf(stderr, "   Xft info:\n"
-						"     - Vertical font:");
+					fprintf(stderr, "    Xft info:\n"
+						"      - Vertical font:");
 					FftPrintPatternInfo(
 						fftf->fftfont, False);
-					fprintf(stderr, "     "
+					fprintf(stderr, "      "
 						"- Rotated font 90:");
 					if (fftf->fftfont_rotated_90)
 						FftPrintPatternInfo(
@@ -1742,7 +1935,7 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 							True);
 					else
 						fprintf(stderr, " None\n");
-					fprintf(stderr, "     "
+					fprintf(stderr, "      "
 						"- Rotated font 270:");
 					if (fftf->fftfont_rotated_270)
 						FftPrintPatternInfo(
@@ -1751,7 +1944,7 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 							True);
 					else
 						fprintf(stderr, " None\n");
-					fprintf(stderr, "     "
+					fprintf(stderr, "      "
 						"- Rotated font 180:");
 					if (fftf->fftfont_rotated_180)
 						FftPrintPatternInfo(
@@ -1761,6 +1954,39 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 					else
 						fprintf(stderr, " None\n");
 				}
+				else if (flf->font != NULL)
+				{
+					char *full_name;
+
+					full_name =
+						FlocaleGetFullNameOfFontStruct(
+							dpy, flf->font);
+					fprintf(stderr, "    X info:\n"
+						"      %s\n",
+						(full_name)? full_name:"?");
+					if (full_name != NULL)
+					{
+						XFree(full_name);
+					}
+				}
+				else if (flf->fontset != NULL)
+				{
+					int n,i;
+					XFontStruct **font_struct_list;
+					char **font_name_list;
+
+					fprintf(stderr, "    X info:\n");
+					n = XFontsOfFontSet(
+						flf->fontset,
+						&font_struct_list,
+						&font_name_list);
+					for(i = 0; i < n; i++)
+					{
+						fprintf(stderr,
+							"      %s\n",
+							font_name_list[i]);
+					}
+				}
 			}
 			count++;
 			flf = flf->next;
