@@ -86,158 +86,158 @@ void PrintXErrorAndCoredump(Display *dpy, XErrorEvent *error, char *MyName)
 #ifndef USE_GET_ERROR_TEXT
 /* this comes out of X.h */
 static char *error_names[] = {
-  "BadRequest",
-  "BadValue",
-  "BadWindow",
-  "BadPixmap",
-  "BadAtom",
-  "BadCursor",
-  "BadFont",
-  "BadMatch",
-  "BadDrawable",
-  "BadAccess",
-  "BadAlloc",
-  "BadColor",
-  "BadGC",
-  "BadIDChoice",
-  "BadName",
-  "BadLength",
-  "BadImplementation"
+	"BadRequest",
+	"BadValue",
+	"BadWindow",
+	"BadPixmap",
+	"BadAtom",
+	"BadCursor",
+	"BadFont",
+	"BadMatch",
+	"BadDrawable",
+	"BadAccess",
+	"BadAlloc",
+	"BadColor",
+	"BadGC",
+	"BadIDChoice",
+	"BadName",
+	"BadLength",
+	"BadImplementation",
 };
 
 
 static char *error_name(unsigned char code)
 {
-  if (code == 0 || code > (sizeof(error_names) / sizeof(char *)))
-  {
-    sprintf(unknown, "Unknown: %d", (int)code);
-    return unknown;
-  }
-  return error_names[code - 1];
+	if (code == 0 || code > (sizeof(error_names) / sizeof(char *)))
+	{
+		sprintf(unknown, "Unknown: %d", (int)code);
+		return unknown;
+	}
+	return error_names[code - 1];
 }
 #endif
 
 /* this comes out of Xproto.h */
 static char *code_names[] = {
-  "CreateWindow",
-  "ChangeWindowAttributes",
-  "GetWindowAttributes",
-  "DestroyWindow",
-  "DestroySubwindows",
-  "ChangeSaveSet",
-  "ReparentWindow",
-  "MapWindow",
-  "MapSubwindows",
-  "UnmapWindow",
-  "UnmapSubwindows",
-  "ConfigureWindow",
-  "CirculateWindow",
-  "GetGeometry",
-  "QueryTree",
-  "InternAtom",
-  "GetAtomName",
-  "ChangeProperty",
-  "DeleteProperty",
-  "GetProperty",
-  "ListProperties",
-  "SetSelectionOwner",
-  "GetSelectionOwner",
-  "ConvertSelection",
-  "SendEvent",
-  "GrabPointer",
-  "UngrabPointer",
-  "GrabButton",
-  "UngrabButton",
-  "ChangeActivePointerGrab",
-  "GrabKeyboard",
-  "UngrabKeyboard",
-  "GrabKey",
-  "UngrabKey",
-  "AllowEvents",
-  "GrabServer",
-  "UngrabServer",
-  "QueryPointer",
-  "GetMotionEvents",
-  "TranslateCoords",
-  "WarpPointer",
-  "SetInputFocus",
-  "GetInputFocus",
-  "QueryKeymap",
-  "OpenFont",
-  "CloseFont",
-  "QueryFont",
-  "QueryTextExtents",
-  "ListFonts",
-  "ListFontsWithInfo",
-  "SetFontPath",
-  "GetFontPath",
-  "CreatePixmap",
-  "FreePixmap",
-  "CreateGC",
-  "ChangeGC",
-  "CopyGC",
-  "SetDashes",
-  "SetClipRectangles",
-  "FreeGC",
-  "ClearArea",
-  "CopyArea",
-  "CopyPlane",
-  "PolyPoint",
-  "PolyLine",
-  "PolySegment",
-  "PolyRectangle",
-  "PolyArc",
-  "FillPoly",
-  "PolyFillRectangle",
-  "PolyFillArc",
-  "PutImage",
-  "GetImage",
-  "PolyText",
-  "PolyText1",
-  "ImageText",
-  "ImageText1",
-  "CreateColormap",
-  "FreeColormap",
-  "CopyColormapAndFree",
-  "InstallColormap",
-  "UninstallColormap",
-  "ListInstalledColormaps",
-  "AllocColor",
-  "AllocNamedColor",
-  "AllocColorCells",
-  "AllocColorPlanes",
-  "FreeColors",
-  "StoreColors",
-  "StoreNamedColor",
-  "QueryColors",
-  "LookupColor",
-  "CreateCursor",
-  "CreateGlyphCursor",
-  "FreeCursor",
-  "RecolorCursor",
-  "QueryBestSize",
-  "QueryExtension",
-  "ListExtensions",
-  "ChangeKeyboardMapping",
-  "GetKeyboardMapping",
-  "ChangeKeyboardControl",
-  "GetKeyboardControl",
-  "Bell",
-  "ChangePointerControl",
-  "GetPointerControl",
-  "SetScreenSaver",
-  "GetScreenSaver",
-  "ChangeHosts",
-  "ListHosts",
-  "SetAccessControl",
-  "SetCloseDownMode",
-  "KillClient",
-  "RotateProperties",
-  "ForceScreenSaver",
-  "SetPointerMapping",
-  "GetPointerMapping",
-  "SetModifierMapping",
-  "GetModifierMapping"
+	"CreateWindow",
+	"ChangeWindowAttributes",
+	"GetWindowAttributes",
+	"DestroyWindow",
+	"DestroySubwindows",
+	"ChangeSaveSet",
+	"ReparentWindow",
+	"MapWindow",
+	"MapSubwindows",
+	"UnmapWindow",
+	"UnmapSubwindows",
+	"ConfigureWindow",
+	"CirculateWindow",
+	"GetGeometry",
+	"QueryTree",
+	"InternAtom",
+	"GetAtomName",
+	"ChangeProperty",
+	"DeleteProperty",
+	"GetProperty",
+	"ListProperties",
+	"SetSelectionOwner",
+	"GetSelectionOwner",
+	"ConvertSelection",
+	"SendEvent",
+	"GrabPointer",
+	"UngrabPointer",
+	"GrabButton",
+	"UngrabButton",
+	"ChangeActivePointerGrab",
+	"GrabKeyboard",
+	"UngrabKeyboard",
+	"GrabKey",
+	"UngrabKey",
+	"AllowEvents",
+	"GrabServer",
+	"UngrabServer",
+	"QueryPointer",
+	"GetMotionEvents",
+	"TranslateCoords",
+	"WarpPointer",
+	"SetInputFocus",
+	"GetInputFocus",
+	"QueryKeymap",
+	"OpenFont",
+	"CloseFont",
+	"QueryFont",
+	"QueryTextExtents",
+	"ListFonts",
+	"ListFontsWithInfo",
+	"SetFontPath",
+	"GetFontPath",
+	"CreatePixmap",
+	"FreePixmap",
+	"CreateGC",
+	"ChangeGC",
+	"CopyGC",
+	"SetDashes",
+	"SetClipRectangles",
+	"FreeGC",
+	"ClearArea",
+	"CopyArea",
+	"CopyPlane",
+	"PolyPoint",
+	"PolyLine",
+	"PolySegment",
+	"PolyRectangle",
+	"PolyArc",
+	"FillPoly",
+	"PolyFillRectangle",
+	"PolyFillArc",
+	"PutImage",
+	"GetImage",
+	"PolyText",
+	"PolyText1",
+	"ImageText",
+	"ImageText1",
+	"CreateColormap",
+	"FreeColormap",
+	"CopyColormapAndFree",
+	"InstallColormap",
+	"UninstallColormap",
+	"ListInstalledColormaps",
+	"AllocColor",
+	"AllocNamedColor",
+	"AllocColorCells",
+	"AllocColorPlanes",
+	"FreeColors",
+	"StoreColors",
+	"StoreNamedColor",
+	"QueryColors",
+	"LookupColor",
+	"CreateCursor",
+	"CreateGlyphCursor",
+	"FreeCursor",
+	"RecolorCursor",
+	"QueryBestSize",
+	"QueryExtension",
+	"ListExtensions",
+	"ChangeKeyboardMapping",
+	"GetKeyboardMapping",
+	"ChangeKeyboardControl",
+	"GetKeyboardControl",
+	"Bell",
+	"ChangePointerControl",
+	"GetPointerControl",
+	"SetScreenSaver",
+	"GetScreenSaver",
+	"ChangeHosts",
+	"ListHosts",
+	"SetAccessControl",
+	"SetCloseDownMode",
+	"KillClient",
+	"RotateProperties",
+	"ForceScreenSaver",
+	"SetPointerMapping",
+	"GetPointerMapping",
+	"SetModifierMapping",
+	"GetModifierMapping",
 };
 
 
@@ -254,6 +254,6 @@ static char *request_name(unsigned char code)
 			sprintf(unknown, "Unknown: %d", (int)code);
 		}
 		return unknown;
-  }
-  return code_names[code - 1];
+	}
+	return code_names[code - 1];
 }
