@@ -591,6 +591,7 @@ void SetTransparentBackground(button_info *ub,int w,int h)
       Dpy, MyWindow, FShapeBounding, 0, 0, pmap_mask, FShapeSet);
     XFreePixmap(Dpy, pmap_mask);
     XDestroyRegion(shape_r);
+    XFlush(Dpy);
   }
 
   return;
@@ -787,8 +788,7 @@ int main(int argc, char **argv)
   /* parse the geometry string */
   if (geom_option_argc != 0)
   {
-    parse_window_geometry(argv[geom_option_argc]);
-    has_button_geometry = 0;
+    parse_window_geometry(argv[geom_option_argc], 0);
   }
 
   /* Don't quit if only a subpanel is empty */
@@ -1047,13 +1047,13 @@ void Loop(void)
 	  SetButtonSize(UberButton,Width,Height);
 	  button=-1;
 	  ub=UberButton;
+	  /* what follow can be optimized */
+	  while(NextButton(&ub,&b,&button,0))
+	    MakeButton(b);
 	  if (FShapesSupported && UberButton->c->flags & b_TransBack)
 	  {
 	    SetTransparentBackground(UberButton, Width, Height);
 	  }
-	  /* what follow can be optimized */
-	  while(NextButton(&ub,&b,&button,0))
-	    MakeButton(b);
 	  for (i = 0; i < nColorsets; i++)
 		  change_colorset(i, &Event);
 	  if (!(UberButton->c->flags & b_Colorset))
@@ -1760,8 +1760,8 @@ static void HandlePanelPress(button_info *b)
     mysizehints.flags = 0;
     XGetWMNormalHints(Dpy, b->PanelWin, &mysizehints, &supplied);
     mysizehints.flags |= USPosition;
-    mysizehints.x = 32767;
-    mysizehints.y = 32767;
+    /* hack to prevent mapping panels on wrong screen with StartsOnScreen */
+    FScreenMangleScreenIntoUSPosHints(FSCREEN_XYPOS, &mysizehints);
     XSetWMNormalHints(Dpy, b->PanelWin, &mysizehints);
     /* make sure its not mapped as an icon */
     wmhints.flags = StateHint;
@@ -1895,6 +1895,8 @@ void CreateUberButtonWindow(button_info *ub,int maxx,int maxy)
   XGCValues gcv;
   unsigned long gcm;
   XClassHint myclasshints;
+  int wx;
+  int wy;
 
   x = UberButton->x; /* Geometry x where to put the panel */
   y = UberButton->y; /* Geometry y where to put the panel */
@@ -1936,34 +1938,36 @@ void CreateUberButtonWindow(button_info *ub,int maxx,int maxy)
 #ifdef DEBUG_INIT
   fprintf(stderr,"gravity...");
 #endif
-  mysizehints.x=0;
-  mysizehints.y=0;
+  wx=0;
+  wy=0;
   if(x > -100000)
   {
     if (xneg)
     {
-      mysizehints.x = DisplayWidth(Dpy,screen) + x - mysizehints.width;
+      wx = DisplayWidth(Dpy,screen) + x - mysizehints.width;
       gravity = NorthEastGravity;
     }
     else
-      mysizehints.x = x;
+      wx = x;
     if (yneg)
     {
-      mysizehints.y = DisplayHeight(Dpy,screen) + y - mysizehints.height;
+      wy = DisplayHeight(Dpy,screen) + y - mysizehints.height;
       gravity = SouthWestGravity;
     }
     else
-      mysizehints.y = y;
+      wy = y;
     if(xneg && yneg)
       gravity = SouthEastGravity;
     mysizehints.flags |= USPosition;
+    /* hack to prevent mapping panels on wrong screen with StartsOnScreen */
+    FScreenMangleScreenIntoUSPosHints(FSCREEN_XYPOS, &mysizehints);
   }
   mysizehints.win_gravity = gravity;
 
 #ifdef DEBUG_INIT
   if(mysizehints.flags&USPosition)
     fprintf(stderr,"create(%i,%i,%u,%u,1,%u,%u)...",
-	    mysizehints.x,mysizehints.y,
+	    wx,wy,
 	    mysizehints.width,mysizehints.height,
 	    (ushort)fore_pix,(ushort)back_pix);
   else
@@ -1972,7 +1976,7 @@ void CreateUberButtonWindow(button_info *ub,int maxx,int maxy)
 	    (ushort)fore_pix,(ushort)back_pix);
 #endif
 
-  XMoveResizeWindow(Dpy, MyWindow, mysizehints.x, mysizehints.y,
+  XMoveResizeWindow(Dpy, MyWindow, wx, wy,
 	      mysizehints.width, mysizehints.height);
 
   XSetWMNormalHints(Dpy,MyWindow,&mysizehints);
