@@ -19,16 +19,23 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#define DRAW_RELIEF      0
+#define DRAW_CLEAN       1
+#define DRAW_ALL         2
+#define DRAW_FORCE       3
+#define DRAW_DESK_RELIEF 4
+
 void RelieveButton(Window,int,int,int,int,int,Pixel,Pixel,int);
 void MakeButton(button_info*);
-void RedrawButton(button_info*,int);
-void DrawTitle(button_info*,Window,GC);
+void RedrawButton(button_info*, int draw, XEvent *pev);
+void DrawTitle(
+	button_info *b,Window win,GC gc, XEvent *pev, Bool do_not_modify_fg);
 
