@@ -473,7 +473,7 @@ static void ParsePanel(char **ss, unsigned int *flags, unsigned int *mask,
       {
 	s = trimleft(s);
 	/* get x and y offset */
-	if((*s>='0' && *s<='9') || *s=='+' || *s=='-')
+	if(isdigit(*s) || *s=='+' || *s=='-')
 	{
 	  sscanf(s, "%i%n", rela_x, &n);
 	  s += n;
@@ -809,7 +809,13 @@ static void ParseButton(button_info **uberb,char *s)
     {
       Bool is_swallow = False;
 
-      if((*s>='0' && *s<='9') || *s=='+' || *s=='-')
+      if (*s == ',')
+      {
+	      s++;
+	      s = trimleft(s);
+	      continue;
+      }
+      if(isdigit(*s) || *s=='+' || *s=='-')
       {
 	char *geom;
 	int x,y,flags;
@@ -841,8 +847,6 @@ static void ParseButton(button_info **uberb,char *s)
 	s = trimleft(s);
 	continue;
       }
-      if(*s==',' && s++)
-	s = trimleft(s);
       switch(GetTokenIndex(s,opts,-1,&s))
       {
       case 0: /* Back */
@@ -1378,7 +1382,7 @@ static void ParseConfigLine(button_info **ubb,char *s)
     i=sscanf(s,"%63s",geom);
     if(i==1)
     {
-      parse_window_geometry(geom);
+      parse_window_geometry(geom, 0);
     }
     break;
   }
@@ -1389,32 +1393,7 @@ static void ParseConfigLine(button_info **ubb,char *s)
     i=sscanf(s,"%63s",geom);
     if(i==1)
     {
-      int flags;
-      int g_x;
-      int g_y;
-      unsigned int width;
-      unsigned int height;
-
-      flags = XParseGeometry(geom,&g_x,&g_y,&width,&height);
-      if (!flags)
-	break;
-      UberButton->w = 0;
-      UberButton->h = 0;
-      UberButton->x = 0;
-      UberButton->y = 0;
-      if (flags&WidthValue)
-	button_width = width;
-      if (flags&HeightValue)
-	button_height = height;
-      if (flags&XValue)
-	UberButton->x = g_x;
-      if (flags&YValue)
-	UberButton->y = g_y;
-      if (flags&XNegative)
-	UberButton->w = 1;
-      if (flags&YNegative)
-	UberButton->h = 1;
-      has_button_geometry = 1;
+      parse_window_geometry(geom, 1);
     }
     break;
   }
@@ -1537,7 +1516,7 @@ static void ParseConfigFile(button_info *ub)
   fclose(f);
 }
 
-void parse_window_geometry(char *geom)
+void parse_window_geometry(char *geom, int is_button_geometry)
 {
   int flags;
   int g_x;
@@ -1550,10 +1529,20 @@ void parse_window_geometry(char *geom)
   UberButton->h = 0;
   UberButton->x = 0;
   UberButton->y = 0;
-  if (flags&WidthValue)
-    w = width;
-  if (flags&HeightValue)
-    h = height;
+  if (is_button_geometry)
+  {
+    if (flags&WidthValue)
+      button_width = width;
+    if (flags&HeightValue)
+      button_height = height;
+  }
+  else
+  {
+    if (flags&WidthValue)
+      w = width;
+    if (flags&HeightValue)
+      h = height;
+  }
   if (flags&XValue)
     UberButton->x = g_x;
   if (flags&YValue)
@@ -1562,7 +1551,7 @@ void parse_window_geometry(char *geom)
     UberButton->w = 1;
   if (flags&YNegative)
     UberButton->h = 1;
-  has_button_geometry = 0;
+  has_button_geometry = is_button_geometry;
 
   return;
 }
