@@ -15,7 +15,7 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
@@ -83,6 +83,7 @@ int main ( int argc, char *argv[])
   char cmd[MAX_MODULE_INPUT_TEXT_LEN + 1];
   char *f_stem, *fc_name, *fm_name;
   char *sf_stem;
+  char *c;
   int  i;
   int  opt;
   int  ncnt;
@@ -90,7 +91,7 @@ int main ( int argc, char *argv[])
   int  Rc;
   struct timeval tv2;
   extern char *optarg;
-  extern int  optind, opterr, optopt;
+  extern int  optind;
 
 #ifdef HAVE_SIGACTION
   {
@@ -202,13 +203,38 @@ int main ( int argc, char *argv[])
   if( f_stem == NULL )
   {
     char *dpy_name;
+    char dpy_name_add[3];
+    int i;
 
     /* default name */
     dpy_name = getenv("DISPLAY");
-    if (!dpy_name)
-      dpy_name = ":0";
+    if (!dpy_name || *dpy_name == 0)
+      dpy_name = ":0.0";
     if (strncmp(dpy_name, "unix:", 5) == 0)
       dpy_name += 4;
+    dpy_name_add[0] = 0;
+    c = strrchr(dpy_name, '.');
+    i = 0;
+    if (c != NULL)
+    {
+      if (*(c + 1) != 0)
+      {
+	for (c++, i = 0; isdigit(*c); c++, i++)
+	{
+	  /* nothing */
+	}
+      }
+      else
+      {
+	/* cut off trailing period */
+	*c = 0;
+      }
+    }
+    if (i == 0)
+    {
+      /* append screen number */
+      strcpy(dpy_name_add, ".0");
+    }
     f_stem = safemalloc(11 + strlen(F_NAME) + MAXHOSTNAME + strlen(dpy_name));
 
     if ((stat("/var/tmp", &stat_buf) == 0) && (stat_buf.st_mode & S_IFDIR))
@@ -221,9 +247,10 @@ int main ( int argc, char *argv[])
     if (!dpy_name[0] || ':' == dpy_name[0])
     {
       gethostname(hostname, MAXHOSTNAME);
-      strcat(f_stem, hostname);	 /* Put hostname before dpy if not there */
+      strcat(f_stem, hostname);  /* Put hostname before dpy if not there */
     }
     strcat(f_stem, dpy_name);
+    strcat(f_stem, dpy_name_add);
   }
 
   /* create 2 fifos */
@@ -492,38 +519,38 @@ void usage(void)
   fprintf (stderr, "Usage: %s [OPTION] [COMMAND]...\n", MYNAME);
   fprintf (stderr, "Send commands to fvwm via %sS\n\n", MYNAME);
   fprintf (stderr,
-	   "  -c		  read and send commands from stdin\n"
-	   "			  The COMMAND if any is ignored.\n");
+	   "  -c                  read and send commands from stdin\n"
+	   "                      The COMMAND if any is ignored.\n");
   fprintf (stderr,
-	   "  -S <file name>	  "
+	   "  -S <file name>      "
 	   "invoke another %s server with fifo <file name>\n",
 	   MYNAME);
   fprintf (stderr,
-	   "  -f <file name>	  use fifo <file name> to connect to %sS\n",
+	   "  -f <file name>      use fifo <file name> to connect to %sS\n",
 	   MYNAME);
   fprintf (stderr,
-	   "  -i <info level>	  0 - error only\n" );
+	   "  -i <info level>     0 - error only\n" );
   fprintf (stderr,
-	   "			  1 - above and config info (default)\n" );
+	   "                      1 - above and config info (default)\n" );
   fprintf (stderr,
-	   "			  2 - above and static info\n" );
+	   "                      2 - above and static info\n" );
   fprintf (stderr,
-	   "			  3 - above and dynamic info\n" );
+	   "                      3 - above and dynamic info\n" );
   fprintf (stderr,
-	   "			 -1 - none (default, much faster)\n" );
+	   "                     -1 - none (default, much faster)\n" );
   fprintf (stderr,
-	   "  -F <flag info>	  0 - no flag info\n");
+	   "  -F <flag info>      0 - no flag info\n");
   fprintf (stderr,
-	   "			  2 - full flag info (default)\n");
+	   "                      2 - full flag info (default)\n");
   fprintf (stderr,
-	   "  -m		  monitor fvwm message transaction\n");
+	   "  -m                  monitor fvwm message transaction\n");
   fprintf (stderr,
-	   "  -r		  "
+	   "  -r                  "
 	   "wait for a reply (overrides waiting time)\n");
   fprintf (stderr,
-	   "  -v		  print version number\n");
+	   "  -v                  print version number\n");
   fprintf (stderr,
-	   "  -w <micro sec>	  waiting time for the reponse from fvwm\n");
+	   "  -w <micro sec>      waiting time for the reponse from fvwm\n");
   fprintf (stderr, "\nDefault fifo names are ~/.%sC and ~/.%sM\n",
 	   MYNAME, MYNAME);
   fprintf (stderr, "Default waiting time is 500,000 us\n");
@@ -699,8 +726,10 @@ void list_configure(unsigned long *body)
   if (Opt_flags == 2)
   {
     printf( "Packet flags\n" );
-    printf( "is_sticky: %d\n",
-	    IS_STICKY( cfgpacket ) );
+    printf( "is_sticky_across_pages: %d\n",
+	    IS_STICKY_ACROSS_PAGES( cfgpacket ) );
+    printf( "is_sticky_across_desks: %d\n",
+	    IS_STICKY_ACROSS_DESKS( cfgpacket ) );
     printf( "has_icon_font: %d\n",
 	    HAS_ICON_FONT( cfgpacket ) );
     printf( "has_window_font: %d\n",
@@ -712,9 +741,9 @@ void list_configure(unsigned long *body)
     printf( "do_circulate_skip_shaded: %d\n",
 	    DO_SKIP_SHADED_CIRCULATE( cfgpacket ) );
     printf( "do_grab_focus_when_created: %d\n",
-	    DO_GRAB_FOCUS( cfgpacket ) );
+	    FP_DO_GRAB_FOCUS( FW_FOCUS_POLICY(cfgpacket) ) );
     printf( "do_grab_focus_when_transient_created: %d\n",
-	    DO_GRAB_FOCUS_TRANSIENT( cfgpacket ) );
+	    FP_DO_GRAB_FOCUS_TRANSIENT( FW_FOCUS_POLICY(cfgpacket) ) );
     printf( "do_ignore_restack: %d\n",
 	    DO_IGNORE_RESTACK( cfgpacket ) );
     printf( "do_lower_transient: %d\n",
@@ -722,11 +751,7 @@ void list_configure(unsigned long *body)
     printf( "do_not_show_on_map: %d\n",
 	    DO_NOT_SHOW_ON_MAP( cfgpacket ) );
     printf( "do_not_pass_click_focus_click: %d\n",
-	    DO_NOT_PASS_CLICK_FOCUS_CLICK( cfgpacket ) );
-    printf( "do_not_raise_click_focus_click: %d\n",
-	    DO_NOT_RAISE_CLICK_FOCUS_CLICK( cfgpacket ) );
-    printf( "do_raise_mouse_focus_click: %d\n",
-	    DO_RAISE_MOUSE_FOCUS_CLICK( cfgpacket ) );
+	    FP_DO_PASS_FOCUS_CLICK( FW_FOCUS_POLICY(cfgpacket) ) );
     printf( "do_raise_transient: %d\n",
 	    DO_RAISE_TRANSIENT( cfgpacket ) );
     printf( "do_resize_opaque: %d\n",
@@ -737,8 +762,6 @@ void list_configure(unsigned long *body)
 	    DO_STACK_TRANSIENT_PARENT( cfgpacket ) );
     printf( "do_window_list_skip: %d\n",
 	    DO_SKIP_WINDOW_LIST( cfgpacket ) );
-    printf( "focus_mode: %d\n",
-	    GET_FOCUS_MODE( cfgpacket ) );
     printf( "has_depressable_border: %d\n",
 	    HAS_DEPRESSABLE_BORDER( cfgpacket ) );
     printf( "has_mwm_border: %d\n",
@@ -755,12 +778,14 @@ void list_configure(unsigned long *body)
 	    HAS_STIPPLED_TITLE( cfgpacket ) );
     printf( "is_fixed: %d\n",
 	    IS_FIXED( cfgpacket ) );
-    printf( "is_sticky_icon: %d\n",
-	    IS_ICON_STICKY( cfgpacket ) );
+    printf( "is_icon_sticky_across_pages: %d\n",
+	    IS_ICON_STICKY_ACROSS_PAGES( cfgpacket ) );
+    printf( "is_icon_sticky_across_desks: %d\n",
+	    IS_ICON_STICKY_ACROSS_DESKS( cfgpacket ) );
     printf( "is_icon_suppressed: %d\n",
 	    IS_ICON_SUPPRESSED( cfgpacket ) );
     printf( "is_lenient: %d\n",
-	    IS_LENIENT( cfgpacket ) );
+	    FP_IS_LENIENT( FW_FOCUS_POLICY(cfgpacket) ) );
     printf( "does_wm_delete_window: %d\n",
 	    WM_DELETES_WINDOW( cfgpacket ) );
     printf( "does_wm_take_focus: %d\n",
@@ -773,8 +798,8 @@ void list_configure(unsigned long *body)
 	    !HAS_NO_BORDER( cfgpacket ) );
     printf( "has_title: %d\n",
 	    HAS_TITLE( cfgpacket ) );
-    printf( "is_deiconify_pending: %d\n",
-	    IS_DEICONIFY_PENDING( cfgpacket ) );
+    printf( "is_iconify_pending: %d\n",
+	    IS_ICONIFY_PENDING( cfgpacket ) );
     printf( "is_fully_visible: %d\n",
 	    IS_FULLY_VISIBLE( cfgpacket ) );
     printf( "is_iconified: %d\n",
@@ -825,7 +850,7 @@ void list_configure(unsigned long *body)
 	    GET_TITLE_DIR( cfgpacket ) );
   }
 
-  printf( "0x%08lx %-20s %ld\n",
+  printf( "0x%08lx %-20s %hd\n",
 	  cfgpacket->w, "title height", cfgpacket->title_height);
   printf( "0x%08lx %-20s %hd\n",
 	  cfgpacket->w, "border width", cfgpacket->border_width);
@@ -923,7 +948,7 @@ void list( unsigned long *body, char *text )
  ************************************************************************/
 void list_new_page(unsigned long *body)
 {
-  printf( "	      %-20s x %ld, y %ld, desk %ld, max x %ld, max y %ld\n",
+  printf( "           %-20s x %ld, y %ld, desk %ld, max x %ld, max y %ld\n",
 	  "new page",
 	  body[0], body[1], body[2], body[3], body[4]);
 }
@@ -935,7 +960,7 @@ void list_new_page(unsigned long *body)
  ************************************************************************/
 void list_new_desk(unsigned long *body)
 {
-  printf( "	      %-20s %ld\n",  "new desk", body[0] );
+  printf( "           %-20s %ld\n",  "new desk", body[0] );
 }
 
 /*************************************************************************
