@@ -1456,7 +1456,6 @@ static void Restart ()
       item->input.n = strlen(item->input.init_value);
       strcpy(item->input.value, item->input.init_value);
       item->input.left = 0;
-      item->input.o_cursor = 0;
       break;
     case I_CHOICE:
       item->choice.on = item->choice.init_on;
@@ -1498,7 +1497,7 @@ void RedrawFrame(XEvent *pev)
 	if (pev)
 	{
 		XRectangle r;
-	
+
 		r.x = pev->xexpose.x;
 		r.y =  pev->xexpose.y;
 		r.width = pev->xexpose.width;
@@ -1660,6 +1659,12 @@ void RedrawItem (Item *item, int click, XEvent *pev)
   Bool text_inter = True;
   DrawTable *dt_ptr = item->header.dt_ptr;
 
+  /* Init intersection to size of the item. */
+  inter.x = BOX_SPC + TEXT_SPC - 1;
+  inter.y = BOX_SPC;
+  inter.width = item->header.size_x - (2 * BOX_SPC) - 2 - TEXT_SPC;
+  inter.height = (item->header.size_y - 1) - 2 * BOX_SPC + 1;
+  /* This is a slightly altered expose event from ReadXServer. */
   if (pev)
   {
 	  r.x = pev->xexpose.x;
@@ -1668,19 +1673,18 @@ void RedrawItem (Item *item, int click, XEvent *pev)
 	  r.height = pev->xexpose.height;
 	  text_inter = frect_get_intersection(
 		  r.x, r.y, r.width, r.height,
-		  BOX_SPC + TEXT_SPC - 1, BOX_SPC,
-		  item->header.size_x - (2 * BOX_SPC) - 2 - TEXT_SPC,
-		  (item->header.size_y - 1) - 2 * BOX_SPC + 1,
+		  inter.x,inter.y,inter.width,inter.height,
 		  &inter);
   }
   else
   {
-	  inter.x = BOX_SPC + TEXT_SPC - 1;
-	  inter.y = BOX_SPC;
-	  inter.width = item->header.size_x - (2 * BOX_SPC) - 2 - TEXT_SPC;
-	  inter.height = (item->header.size_y - 1) - 2 * BOX_SPC + 1;
+	  /* If its not an expose event, the area assume the
+	     whole item is intersected. */
+	  r.x = inter.x;
+	  r.y = inter.y;
+	  r.width = inter.width;
+	  r.height = inter.height;
   }
-
   if (pev && text_inter && dt_ptr && dt_ptr->dt_Fstr)
   {
 	  region = XCreateRegion();
@@ -1714,14 +1718,12 @@ void RedrawItem (Item *item, int click, XEvent *pev)
        multifield paste.  dje */
     if (frect_get_intersection(
 	    r.x, r.y, r.width, r.height,
-	    BOX_SPC + TEXT_SPC - 1, BOX_SPC,
-	    item->header.size_x - (2 * BOX_SPC) - 2 - TEXT_SPC,
-	    (item->header.size_y - 1) - 2 * BOX_SPC + 1,
+	    inter.x, inter.y, inter.width, inter.height,
 	    &inter))
     {
 	    XClearArea(
-		    dpy, item->header.win,
-		    inter.x, inter.y, inter.width, inter.height, False);
+		       dpy, item->header.win,
+		       inter.x, inter.y, inter.width, inter.height, False);
     }
 
     xsegs[0].x1 = 0, xsegs[0].y1 = 0;
@@ -2082,6 +2084,7 @@ static void OpenWindows ()
   static XSizeHints sh =
     { PPosition | PSize | USPosition | USSize | PWinGravity};
   XClassHint myclasshints;
+  fscreen_scr_t scr;
 
   if (!CF.pointer[input_pointer]) {
     CF.pointer[input_pointer] = XCreateFontCursor(dpy, XC_xterm);
@@ -2155,10 +2158,14 @@ static void OpenWindows ()
     {
       gravity = SouthEastGravity;
     }
+    scr = FSCREEN_XYPOS;
   } else {
     FScreenCenterOnScreen(
       NULL, FSCREEN_CURRENT, &x, &y, CF.max_width, CF.total_height);
+    scr = FSCREEN_CURRENT;
   }
+  /* hack to prevent mapping on wrong screen with StartsOnScreen */
+  FScreenMangleScreenIntoUSPosHints(FSCREEN_CURRENT, &sh);
   xswa.background_pixel = CF.screen_background;
   xswa.border_pixel = 0;
   xswa.colormap = Pcmap;
@@ -2181,8 +2188,6 @@ static void OpenWindows ()
   myclasshints.res_name = MyName+1;
   myclasshints.res_class = "FvwmForm";
   XSetClassHint(dpy,CF.frame,&myclasshints);
-  sh.x = x;
-  sh.y = y;
   sh.width = CF.max_width;
   sh.height = CF.total_height;
   sh.win_gravity = gravity;
@@ -2382,9 +2387,15 @@ static void ParseActiveMessage(char *buf)
 					}
 				}
 			}
-			CheckAlloc(
-				root_item_ptr,
-				root_item_ptr->header.dt_ptr);
+			for (item = root_item_ptr; item != 0;
+			     item = item->header.next)
+			{
+				DrawTable *dt_ptr = item->header.dt_ptr;
+				if (dt_ptr)
+				{
+					CheckAlloc(item, dt_ptr);
+				}
+			}
 			if (colorset >= 0)
 			{
 				SetWindowBackground(
@@ -2399,23 +2410,17 @@ static void ParseActiveMessage(char *buf)
 			     item = item->header.next)
 			{
 				DrawTable *dt_ptr = item->header.dt_ptr;
-				if (dt_ptr)
+				if (dt_ptr && itemcolorset >= 0 &&
+				    item->header.win != 0)
 				{
-					CheckAlloc(item, dt_ptr);
-					if (itemcolorset >= 0 &&
-					    item->header.win != 0)
-					{
-						SetWindowBackground(
-							dpy, item->header.win,
-							item->header.size_x,
-							item->header.size_y,
-							&Colorset
-							[(itemcolorset)],
-							Pdepth, dt_ptr->dt_GC,
-							True);
-					}
+					SetWindowBackground(
+						dpy, item->header.win,
+						item->header.size_x,
+						item->header.size_y,
+						&Colorset[(itemcolorset)],
+						Pdepth, dt_ptr->dt_GC, True);
+					RedrawItem(item, 0, NULL);
 				} /* end item has a drawtable */
-				RedrawItem(item, 0, NULL);
 			} /* end all items */
 		}
 		return;
