@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "config.h"
@@ -39,7 +39,9 @@ window_list_item (window_list_entry *wle, window_list_options *opts)
   char *argv[4];
   char desk[10], cmd[200], geo[200];
 
-  g_snprintf (cmd, sizeof (cmd), "%s %#lx",
+  /* support two ways for now: window context (new) and window id param (old) */
+  g_snprintf (cmd, sizeof (cmd), "WindowId %#lx %s %#lx",
+	      wle->w,
 	      opts->function ? opts->function : "WindowListFunc",
 	      wle->w);
   g_snprintf(desk, sizeof (desk), "%d", wle->desk);
