@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 /*************************************************************************
@@ -30,7 +30,7 @@ extern Pixel  GetColor(char *name);
 extern Pixel  GetHilite(Pixel background);
 extern Pixel  GetShadow(Pixel background);
 extern void   nocolor(char *a, char *b);
-extern void   RedrawWindow(void);
+extern void   RedrawWindow(XEvent *evp);
 extern void   match_string(char *tline);
 extern void   Loop(void);
 extern void   ParseOptions(void);
@@ -50,7 +50,7 @@ extern struct icon_info *UpdateItem(unsigned long type, unsigned long id, char *
 extern void freeitem(struct icon_info *item, int d);
 extern void RedrawHScrollbar(void);
 extern void RedrawVScrollbar(void);
-extern void RedrawIcons(void);
+extern void RedrawIcons(XEvent *evp);
 extern void GetIconwinSize(int *dx, int *dy);
 extern void RedrawLeftButton(GC rgc, GC sgc);
 extern void RedrawRightButton(GC rgc, GC sgc);
@@ -66,7 +66,7 @@ extern void parseaction(char *tline);
 extern void AdjustIconWindow(struct icon_info *item, int n);
 extern int AdjustIconWindows(void);
 extern struct icon_info *SetFlag(unsigned long id, int t);
-extern void RedrawIcon(struct icon_info *item, int f);
+extern void RedrawIcon(struct icon_info *item, int f, XEvent *evp);
 extern void animate(struct icon_info *item, unsigned long *body);
 extern void Next(void);
 extern void Prev(void);
@@ -86,7 +86,7 @@ extern int window_cond(struct icon_info *item);
 extern int itemcmp(struct icon_info *item1, struct icon_info *item2);
 
 
-extern Display *dpy;			/* which display are we talking to */
+extern Display *dpy;                    /* which display are we talking to */
 extern Window Root;
 extern Window main_win;
 extern Window holder_win;
@@ -110,52 +110,55 @@ extern char *IconwinPixmapFile;
 
 struct icon_info
 {
-  char *action;
-  char *name;
-  char *window_name;
-  char *res_class;
-  char *res_name;
-  char *icon_file;
-  int x;
-  int y;
-  int icon_w;
-  int icon_h;
-  Pixmap iconPixmap;		/* pixmap for the icon */
-  Pixmap icon_maskPixmap;
-  Pixmap icon_alphaPixmap;
-  Window IconWin;
-  Window icon_pixmap_w;
-  XWMHints *wmhints;
-  int icon_depth;
-  long id;
-  long desk;
-  window_flags flags;
-  long extra_flags;
-  struct icon_info *next;
-  struct icon_info *prev;
+	char *action;
+	char *name;
+	char *window_name;
+	char *res_class;
+	char *res_name;
+	char *icon_file;
+	int x;
+	int y;
+	int icon_w;
+	int icon_h;
+	Pixmap iconPixmap;            /* pixmap for the icon */
+	Pixmap icon_maskPixmap;
+	Pixmap icon_alphaPixmap;
+	int icon_depth;
+	int icon_nalloc_pixels;
+	Pixel *icon_alloc_pixels;
+	int icon_no_limit;
+	Window IconWin;
+	Window icon_pixmap_w;
+	XWMHints *wmhints;
+	long id;
+	long desk;
+	window_flags flags;
+	long extra_flags;
+	struct icon_info *next;
+	struct icon_info *prev;
 };
 
 struct iconfile
 {
-  char *name;
-  char *iconfile;
-  struct iconfile *next;
+	char *name;
+	char *iconfile;
+	struct iconfile *next;
 };
 
 struct mousefunc
 {
-  int mouse;
-  int type;
-  char *action;
-  struct mousefunc *next;
+	int mouse;
+	int type;
+	char *action;
+	struct mousefunc *next;
 };
 
 struct keyfunc
 {
-  char *name;
-  KeyCode keycode;
-  char *action;
-  struct keyfunc *next;
+	char *name;
+	KeyCode keycode;
+	char *action;
+	struct keyfunc *next;
 };
 
 extern struct icon_info *Head;
@@ -185,19 +188,19 @@ extern int icon_relief;
 #define TIMEOUT 3
 
 /* sorting */
-#define UNSORT	   0
+#define UNSORT     0
 #define WINDOWNAME 1
 #define ICONNAME   2
-#define RESNAME	   3
+#define RESNAME    3
 #define RESCLASS   4
 
 /* local flags */
-#define HIDE_H	      (1<<0)
-#define HIDE_V	      (1<<1)
+#define HIDE_H        (1<<0)
+#define HIDE_V        (1<<1)
 #define SETWMICONSIZE (1<<2)
 #define CURRENT_ONLY  (1<<3)
 
 #define DEFAULTICON   (1<<0)
-#define NONAME	      (1<<1)
-#define NOCLASS	      (1<<2)
+#define NONAME        (1<<1)
+#define NOCLASS       (1<<2)
 
