@@ -215,6 +215,7 @@ int main(int argc, char **argv)
 	x_fd = XConnectionNumber(dpy);
 	screen= DefaultScreen(dpy);
 	Root = RootWindow(dpy, screen);
+	XSetErrorHandler(ErrorHandler);
 
 	PictureInitCMap(dpy);
 	FScreenInit(dpy);
@@ -699,18 +700,22 @@ int ProcessXEvent(int x, int y)
 						main_width, main_height);
 					do_eat_expose = True;
 				}
+				else if (colorset == -1)
+				{
+					do_eat_expose = True;
+				}
 				else if (UpdateBackgroundTransparency(
-						 dpy, main_win, main_width,
-						 main_height,
-						 &Colorset[(colorset)], Pdepth,
-						 gc, True) == True)
+					dpy, main_win, main_width,
+					main_height,
+					&Colorset[(colorset)], Pdepth,
+					gc, True) == True)
 				{
 					do_eat_expose = True;
 				}
 				if (do_eat_expose == True)
 				{
 					while (FCheckTypedEvent(
-						       dpy, Expose, &Event))
+						dpy, Expose, &Event))
 					{
 						/* nothing */
 					}
@@ -815,8 +820,6 @@ void list_end(void)
 				mysizehints.win_gravity = NorthEastGravity;
 		}
 	}
-	mysizehints.x = x;
-	mysizehints.y = y;
 
 	if (Pdepth < 2)
 	{
@@ -841,6 +844,8 @@ void list_end(void)
 	wm_del_win = XInternAtom(dpy,"WM_DELETE_WINDOW",False);
 	XSetWMProtocols(dpy,main_win,&wm_del_win,1);
 
+	/* hack to prevent mapping on wrong screen with StartsOnScreen */
+	FScreenMangleScreenIntoUSPosHints(FSCREEN_XYPOS, &mysizehints);
 	XSetWMNormalHints(dpy,main_win,&mysizehints);
 	/* have to ask for configure events when transparent */
 	if (CSET_IS_TRANSPARENT(colorset))
@@ -1373,10 +1378,15 @@ void MakeList(void)
 	{
 		strcat(ewmh_init_state, "Sticky ");
 	}
-	if (target.ewmh_hint_layer > 0)
+	/* FIXME: we should use the fvwm default layers */
+	if (target.ewmh_hint_layer == 6)
 	{
 		strcat(ewmh_init_state, "StaysOnTop ");
 	}
+	else if (target.ewmh_hint_layer == 2)
+	{
+		strcat(ewmh_init_state, "StaysOnBottom ");
+	}
 	if (HAS_EWMH_INIT_WM_DESKTOP(targ) == EWMH_STATE_HAS_HINT &&
 	    target.ewmh_hint_desktop < 256)
 	{
@@ -1391,3 +1401,28 @@ void MakeList(void)
 		AddToList("EWMH Init State:",ewmh_init_state);
 	}
 }
+
+/************************************************************************
+  X Error Handler
+************************************************************************/
+static int
+ErrorHandler(Display *d, XErrorEvent *event)
+{
+#if 0
+	if (event->error_code == BadPixmap)
+	{
+		return 0;
+	}
+	if (event->error_code == BadDrawable)
+	{
+		return 0;
+	}
+	if (event->error_code == FRenderGetErrorCodeBase() + FRenderBadPicture)
+	{
+		return 0;
+	}
+#endif
+
+	PrintXErrorAndCoredump(d, event, MyName);
+	return 0;
+}
