@@ -120,11 +120,22 @@ static char s_g_bits[] = {0x01, 0x02, 0x04, 0x08};
 
 Window icon_win;	       /* icon window */
 
+static int MyVx, MyVy;		/* copy of Scr.Vx/y for drag logic */
+
 static char *GetBalloonLabel(const PagerWindow *pw,const char *fmt);
 extern void ExitPager(void);
 
 Pixmap default_pixmap = None;
 
+#ifdef DEBUG
+#define MYFPRINTF(X) \
+  fprintf X;\
+  fflush (stderr);
+#else
+#define MYFPRINTF(X)
+#endif
+
+
 /* discard certain events on a window */
 static void discard_events(long event_type, Window w, XEvent *last_ev)
 {
@@ -429,6 +440,7 @@ void initialize_pager(void)
   int n,m,w,h,i,x,y;
   XGCValues gcv;
   char dash_list[2];
+  FlocaleFont *balloon_font;
 
   /* I don't think that this is necessary - just let pager die */
   /* domivogt (07-mar-1999): But it is! A window being moved in the pager
@@ -608,8 +620,6 @@ void initialize_pager(void)
   }
   sizehints.width = window_w;
   sizehints.height = window_h;
-  sizehints.x = window_x;
-  sizehints.y = window_y;
 
   if(usposition)
     sizehints.flags |= USPosition;
@@ -627,6 +637,8 @@ void initialize_pager(void)
 			       window_h, 0, Pdepth, InputOutput, Pvisual,
 			       valuemask, &attributes);
   XSetWMProtocols(dpy,Scr.Pager_w,&wm_del_win,1);
+  /* hack to prevent mapping on wrong screen with StartsOnScreen */
+  FScreenMangleScreenIntoUSPosHints(FSCREEN_XYPOS, &sizehints);
   XSetWMNormalHints(dpy,Scr.Pager_w,&sizehints);
   if (is_transient)
   {
@@ -731,6 +743,7 @@ void initialize_pager(void)
     Scr.asGC = fvwmlib_XCreateGC(dpy, Scr.Pager_w, GCForeground, &gcv);
   }
 
+  balloon_font = FlocaleLoadFont(dpy, BalloonFont, MyName);
   for(i=0;i<ndesks;i++)
   {
     w = window_w / Columns;
@@ -891,7 +904,7 @@ void initialize_pager(void)
     XMapRaised(dpy,Desks[i].title_w);
 
     /* get font for balloon */
-    Desks[i].balloon.Ffont = FlocaleLoadFont(dpy, BalloonFont, MyName);
+    Desks[i].balloon.Ffont = balloon_font;
     if (Desks[i].balloon.Ffont == NULL)
     {
       fprintf(stderr, "%s: No fonts available, giving up!.\n", MyName);
@@ -1097,6 +1110,9 @@ void DispatchEvent(XEvent *Event)
     }
     else if (Event->xbutton.button == 3)
     {
+      /* save initial virtual desk position for drag */
+      MyVx=Scr.Vx;
+      MyVy=Scr.Vy;
       for(i=0;i<ndesks;i++)
       {
 	if(Event->xany.window == Desks[i].w)
@@ -1338,7 +1354,6 @@ void ReConfigure(void)
     for(j=0;j<Columns;j++)
     {
       i = k*Columns+j;
-
       if (i<ndesks)
       {
 	XMoveResizeWindow(
@@ -1352,7 +1367,6 @@ void ReConfigure(void)
 		{
 			draw_desk_background(i, w, h);
 		}
-		continue;
 	}
 	if (HilightDesks)
 	{
@@ -1630,8 +1644,8 @@ void DrawGrid(int desk, int erase, Window ew, XRectangle *r)
 				XDrawLine(
 					dpy,Desks[desk].w,Desks[desk].DashedGC,
 					x1,y1,x1,y2);
-				x += Scr.MyDisplayWidth;
 			}
+			x += Scr.MyDisplayWidth;
 		}
 		y = Scr.MyDisplayHeight;
 		x1 = 0;
@@ -1640,9 +1654,11 @@ void DrawGrid(int desk, int erase, Window ew, XRectangle *r)
 		{
 			y1 = (y * desk_h) / Scr.VHeight;
 			if (!use_no_separators)
+			{
 				XDrawLine(
 					dpy,Desks[desk].w,Desks[desk].DashedGC,
 					x1,y1,x2,y1);
+			}
 			y += Scr.MyDisplayHeight;
 		}
 	}
@@ -1896,79 +1912,95 @@ void IconSwitchPage(XEvent *Event)
 
 void AddNewWindow(PagerWindow *t)
 {
-  unsigned long valuemask;
-  XSetWindowAttributes attributes;
-  int i, x, y, w, h;
+	unsigned long valuemask;
+	XSetWindowAttributes attributes;
+	int i, x, y, w, h;
 
-  i = t->desk - desk1;
-  CalcGeom(t, desk_w, desk_h, &x, &y, &w, &h);
-  t->pager_view_x = x;
-  t->pager_view_y = y;
-  t->pager_view_width = w;
-  t->pager_view_height = h;
-  valuemask = CWBackPixel | CWEventMask;
-  attributes.background_pixel = t->back;
-  attributes.event_mask = ExposureMask;
+	i = t->desk - desk1;
+	CalcGeom(t, desk_w, desk_h, &x, &y, &w, &h);
+	t->pager_view_x = x;
+	t->pager_view_y = y;
+	t->pager_view_width = w;
+	t->pager_view_height = h;
+	valuemask = CWBackPixel | CWEventMask;
+	attributes.background_pixel = t->back;
+	attributes.event_mask = ExposureMask;
 
-  /* ric@giccs.georgetown.edu -- added Enter and Leave events for
-     popping up balloon window */
-  attributes.event_mask = ExposureMask | EnterWindowMask | LeaveWindowMask;
+	/* ric@giccs.georgetown.edu -- added Enter and Leave events for
+	   popping up balloon window */
+	attributes.event_mask =
+		ExposureMask | EnterWindowMask | LeaveWindowMask;
 
-  if ((i >= 0) && (i < ndesks))
-  {
-    t->PagerView = XCreateWindow(dpy,Desks[i].w, x, y, w, h, 0,
-				 CopyFromParent, InputOutput, CopyFromParent,
-				 valuemask, &attributes);
-    if (windowcolorset > -1)
-    {
-      SetWindowBackground(
-	dpy, t->PagerView, w, h, &Colorset[windowcolorset], Pdepth,
-	Scr.NormalGC, True);
-    }
-    if (!UseSkipList || !DO_SKIP_WINDOW_LIST(t))
-    {
-      XMapRaised(dpy, t->PagerView);
-    }
-  }
-  else
-  {
-    t->PagerView = None;
-  }
+	if ((i >= 0) && (i < ndesks))
+	{
+		t->PagerView = XCreateWindow(
+			dpy,Desks[i].w, x, y, w, h, 0, CopyFromParent,
+			InputOutput, CopyFromParent, valuemask, &attributes);
+		if (windowcolorset > -1)
+		{
+			SetWindowBackground(
+				dpy, t->PagerView, w, h,
+				&Colorset[windowcolorset], Pdepth,
+				Scr.NormalGC, True);
+		}
+		if (!UseSkipList || !DO_SKIP_WINDOW_LIST(t))
+		{
+			if (IS_ICONIFIED(t))
+			{
+				XMoveResizeWindow(
+					dpy, t->PagerView, -32768, -32768, 1,
+					1);
+			}
+			XMapRaised(dpy, t->PagerView);
+		}
+	}
+	else
+	{
+		t->PagerView = None;
+	}
 
-  CalcGeom(t, icon_w, icon_h, &x, &y, &w, &h);
-  t->icon_view_width = w;
-  t->icon_view_height = h;
-  if(Scr.CurrentDesk != t->desk)
-  {
-    x = -32768;
-    y = -32768;
-  }
-  t->IconView = XCreateWindow(
-    dpy,icon_win, x, y, w, h, 0, CopyFromParent, InputOutput,
-    CopyFromParent, valuemask, &attributes);
-  if (windowcolorset > -1)
-  {
-    SetWindowBackground(
-      dpy, t->IconView, w, h, &Colorset[windowcolorset], Pdepth,
-      Scr.NormalGC, True);
-  }
-  if(Scr.CurrentDesk == t->desk)
-  {
-    XGrabButton(
-      dpy, 2, AnyModifier, t->IconView, True,
-      ButtonPressMask | ButtonReleaseMask|ButtonMotionMask,
-      GrabModeAsync, GrabModeAsync, None, None);
-  }
-  if (!UseSkipList || !DO_SKIP_WINDOW_LIST(t))
-  {
-    XMapRaised(dpy,t->IconView);
-    t->myflags.is_mapped = 1;
-  }
-  else
-  {
-    t->myflags.is_mapped = 0;
-  }
-  Hilight(t,False);
+	CalcGeom(t, icon_w, icon_h, &x, &y, &w, &h);
+	t->icon_view_width = w;
+	t->icon_view_height = h;
+	if(Scr.CurrentDesk != t->desk)
+	{
+		x = -32768;
+		y = -32768;
+	}
+	t->IconView = XCreateWindow(
+		dpy,icon_win, x, y, w, h, 0, CopyFromParent, InputOutput,
+		CopyFromParent, valuemask, &attributes);
+	if (windowcolorset > -1)
+	{
+		SetWindowBackground(
+			dpy, t->IconView, w, h, &Colorset[windowcolorset],
+			Pdepth, Scr.NormalGC, True);
+	}
+	if(Scr.CurrentDesk == t->desk)
+	{
+		XGrabButton(
+			dpy, 2, AnyModifier, t->IconView, True,
+			ButtonPressMask | ButtonReleaseMask|ButtonMotionMask,
+			GrabModeAsync, GrabModeAsync, None, None);
+	}
+	if (!UseSkipList || !DO_SKIP_WINDOW_LIST(t))
+	{
+		if (IS_ICONIFIED(t))
+		{
+			XMoveResizeWindow(
+				dpy, t->IconView, -32768, -32768, 1,
+				1);
+		}
+		XMapRaised(dpy, t->IconView);
+		t->myflags.is_mapped = 1;
+	}
+	else
+	{
+		t->myflags.is_mapped = 0;
+	}
+	Hilight(t,False);
+
+	return;
 }
 
 
@@ -2123,8 +2155,8 @@ void MoveStickyWindows(void)
   t = Start;
   while(t!= NULL)
   {
-    if(((IS_ICONIFIED(t))&&(IS_ICON_STICKY(t)))||
-       (IS_STICKY(t)))
+    if(((IS_ICONIFIED(t))&&(IS_ICON_STICKY_ACROSS_DESKS(t)))||
+       (IS_STICKY_ACROSS_DESKS(t)))
     {
       if(t->desk != Scr.CurrentDesk)
       {
@@ -2155,7 +2187,7 @@ void Hilight(PagerWindow *t, int on)
     }
     else
     {
-      if(IS_STICKY(t))
+      if(IS_STICKY_ACROSS_DESKS(t) || IS_STICKY_ACROSS_PAGES(t))
       {
 	if(t->PagerView != None)
 	  XSetWindowBackgroundPixmap(dpy,t->PagerView,
@@ -2217,66 +2249,85 @@ void Scroll(int window_w, int window_h, int x, int y, int Desk,
 	static int last_sy = -999999;
 	int sx;
 	int sy;
+	int adjx,adjy;
 
 	/* Desk < 0 means we want to scroll an icon window */
-	if(Desk >= 0 && Desk + desk1 != Scr.CurrentDesk)
+	if (Desk >= 0 && Desk + desk1 != Scr.CurrentDesk)
 	{
 		return;
 	}
 
 	/* center around mouse */
-	x -= (desk_w / (1 + Scr.VxMax / Scr.MyDisplayWidth)) / 2;
-	y -= (desk_h / (1 + Scr.VyMax / Scr.MyDisplayHeight)) / 2;
+	adjx = (desk_w / (1 + Scr.VxMax / Scr.MyDisplayWidth));
+	adjy = (desk_h / (1 + Scr.VyMax / Scr.MyDisplayHeight));
+	x-=adjx/2;
+	y-=adjy/2;
 
-	if(x < 0)
+	/* adjust for pointer going out of range */
+	if (x < 0)
 	{
 		x = 0;
 	}
-	if(y < 0)
+	if (y < 0)
 	{
 		y = 0;
 	}
 
-	if(x > window_w)
+	if (x > window_w-adjx)
 	{
-		x = window_w;
+		x = window_w-adjx;
 	}
-	if(y > window_h)
+	if (y > window_h-adjy)
 	{
-		y = window_h;
+		y = window_h-adjy;
 	}
 
 	sx = 0;
 	sy = 0;
-	if(window_w != 0)
+	if (window_w != 0)
 	{
-		sx = 100 * (x * Scr.VWidth / window_w - Scr.Vx) /
+		sx = 100 * (x * Scr.VWidth / window_w - MyVx) /
 			Scr.MyDisplayWidth;
 	}
-	if(window_h != 0)
+	if (window_h != 0)
 	{
-		sy = 100 * (y * Scr.VHeight / window_h - Scr.Vy) /
+		sy = 100 * (y * Scr.VHeight / window_h - MyVy) /
 			Scr.MyDisplayHeight;
 	}
-#ifdef DEBUG
-	fprintf(stderr,"[scroll]: %d %d %d %d %d %d\n", window_w, window_h, x,
-		y, sx, sy);
-#endif
-	/* Make sure weExecuteCommandQueue(); don't get stuck a few pixels fromt
+	MYFPRINTF((stderr,"[scroll]: %d %d %d %d %d %d\n", window_w, window_h, x,
+		y, sx, sy));
+	/* Make sure weExecuteCommandQueue(); don't get stuck a few pixels from
 	 * the top/left border. Since sx/sy are ints, values between 0 and 1 are
 	 * rounded down. */
-	if (sx == 0 && x == 0 && Scr.Vx != 0)
+	if (sx == 0 && x == 0 && MyVx != 0)
 	{
 		sx = -1;
 	}
-	if (sy == 0 && y == 0 && Scr.Vy != 0)
+	if (sy == 0 && y == 0 && MyVy != 0)
 	{
 		sy = -1;
 	}
+	if (sx == 0 && sy == 0)
+	{
+		return;
+	}
 	if (Wait == 0 || last_sx != sx || last_sy != sy)
 	{
 		sprintf(command, "Scroll %d %d", sx, sy);
 		SendText(fd, command, 0);
+		/* Here we need to track the view offset on the desk. */
+		/* sx/y are are a percent of the screen to scroll. */
+		/* We don't use Scr.Vx/y since they lag the true position. */
+		MyVx += Scr.MyDisplayWidth * sx / 100;
+		if (MyVx < 0)
+		{
+			MyVx = 0;
+		}
+		MyVy += Scr.MyDisplayHeight * sy / 100;
+		if (MyVy < 0)
+		{
+			MyVy = 0;
+		}
 		Wait = 1;
 	}
 	if (Wait == 0)
@@ -2466,7 +2517,8 @@ void MoveWindow(XEvent *Event)
       x = Scr.VWidth - Scr.Vx - 1;
     if (y + Scr.Vy >= Scr.VHeight)
       y = Scr.VHeight - Scr.Vy - 1;
-    if(((IS_ICONIFIED(t))&&(IS_ICON_STICKY(t)))||(IS_STICKY(t)))
+    if((IS_ICONIFIED(t) && IS_ICON_STICKY_ACROSS_DESKS(t)) ||
+       (IS_STICKY_ACROSS_DESKS(t)))
     {
       NewDesk = Scr.CurrentDesk - desk1;
       if (x > Scr.MyDisplayWidth - 16)
@@ -2480,7 +2532,8 @@ void MoveWindow(XEvent *Event)
     }
     if(NewDesk + desk1 != t->desk)
     {
-      if(((IS_ICONIFIED(t))&&(IS_ICON_STICKY(t)))||(IS_STICKY(t)))
+      if((IS_ICONIFIED(t) && IS_ICON_STICKY_ACROSS_DESKS(t)) ||
+	 (IS_STICKY_ACROSS_DESKS(t)))
       {
 	NewDesk = Scr.CurrentDesk - desk1;
 	if(t->desk != Scr.CurrentDesk)
@@ -2865,7 +2918,8 @@ void IconMoveWindow(XEvent *Event,PagerWindow *t)
       x = Scr.VWidth - Scr.Vx - 1;
     if (y + Scr.Vy >= Scr.VHeight)
       y = Scr.VHeight - Scr.Vy - 1;
-    if(((IS_ICONIFIED(t))&&(IS_ICON_STICKY(t)))||(IS_STICKY(t)))
+    if((IS_ICONIFIED(t) && IS_ICON_STICKY_ACROSS_DESKS(t)) ||
+       IS_STICKY_ACROSS_DESKS(t))
     {
       if (x > Scr.MyDisplayWidth - 16)
 	x = Scr.MyDisplayWidth - 16;
