@@ -5,18 +5,18 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "types.h"
 #include "libs/fvwmsignal.h"
-#include <time.h>
-#include <sys/time.h>
+#include "libs/ftime.h"
+#include "libs/FGettext.h"
 #ifdef HAVE_GETPWUID
 #  include <pwd.h>
 #endif
@@ -24,8 +24,8 @@
 extern int fd[2];
 extern Window ref;
 
-void (*TabCom[26]) (int NbArg,long *TabArg);
-char *(*TabFunc[26]) (int *NbArg, long *TabArg);
+void (*TabCom[27]) (int NbArg,long *TabArg);
+char *(*TabFunc[27]) (int *NbArg, long *TabArg);
 int (*TabComp[7]) (char *arg1,char *arg2);
 
 extern Display *dpy;
@@ -50,7 +50,7 @@ char Command[255]="None";
 time_t TimeCom=0;
 
 /*************************************************************/
-/* Utilities						     */
+/* Utilities                                                 */
 /*************************************************************/
 void setFvwmUserDir(void)
 {
@@ -80,7 +80,7 @@ void setFvwmUserDir(void)
 }
 
 /*************************************************************/
-/* Ensemble de fonction de comparaison de deux entiers	     */
+/* Ensemble de fonction de comparaison de deux entiers       */
 /*************************************************************/
 static int Inf(char *arg1,char *arg2)
 {
@@ -138,7 +138,7 @@ static char *CalcArg (long *TabArg,int *Ix)
   char *TmpStr;
   int i;
 
-  if (TabArg[*Ix]>100000)	/* Cas du codage d'un nombre */
+  if (TabArg[*Ix]>100000)       /* Cas du codage d'un nombre */
   {
     i = (int)TabArg[*Ix] - 200000;
     TmpStr = (char*)safecalloc(1,sizeof(char)*10);
@@ -150,11 +150,11 @@ static char *CalcArg (long *TabArg,int *Ix)
    TmpStr = (char*)safecalloc(1,sizeof(char)*10);
    sprintf(TmpStr,"%d",i);
   }
-  else if (TabArg[*Ix] < -100000)	/* Cas d'un id de fonction */
+  else if (TabArg[*Ix] < -100000)       /* Cas d'un id de fonction */
   {
     TmpStr = TabFunc[TabArg[*Ix]+150000](Ix,TabArg);
   }
-  else				/* Cas d'une variable */
+  else                          /* Cas d'une variable */
   {
     TmpStr=safestrdup(TabVVar[TabArg[*Ix]]);
   }
@@ -171,7 +171,7 @@ static char *FuncGetValue(int *NbArg, long *TabArg)
   char *tmp;
   long Id;
 
-  (*NbArg)++;		/* La fonction GetValue n'a qu'un seul argument */
+  (*NbArg)++;           /* La fonction GetValue n'a qu'un seul argument */
   tmp = CalcArg(TabArg,NbArg);
   Id = atoi(tmp);
   free(tmp);
@@ -186,7 +186,7 @@ static char *FuncGetMinValue(int *NbArg, long *TabArg)
   char *tmp;
   long Id;
 
-  (*NbArg)++;		   /* La fonction GetValue n'a qu'un seul argument */
+  (*NbArg)++;              /* La fonction GetValue n'a qu'un seul argument */
   tmp = CalcArg(TabArg,NbArg);
   Id = atoi(tmp);
   free(tmp);
@@ -201,7 +201,7 @@ static char *FuncGetMaxValue(int *NbArg, long *TabArg)
   char *tmp;
   long Id;
 
-  (*NbArg)++;	      /* La fonction GetValue n'a qu'un seul argument */
+  (*NbArg)++;         /* La fonction GetValue n'a qu'un seul argument */
   tmp = CalcArg(TabArg,NbArg);
   Id = atoi(tmp);
   free(tmp);
@@ -217,7 +217,7 @@ static char *FuncGetFore(int *NbArg, long *TabArg)
   long Id;
   XColor color;
 
-  (*NbArg)++;		 /* La fonction GetValue n'a qu'un seul argument */
+  (*NbArg)++;            /* La fonction GetValue n'a qu'un seul argument */
   tmp = CalcArg(TabArg,NbArg);
   Id = atoi(tmp);
   free(tmp);
@@ -236,7 +236,7 @@ static char *FuncGetBack(int *NbArg, long *TabArg)
   long Id;
   XColor color;
 
-  (*NbArg)++;		  /* La fonction GetValue n'a qu'un seul argument */
+  (*NbArg)++;             /* La fonction GetValue n'a qu'un seul argument */
   tmp = CalcArg(TabArg,NbArg);
   Id = atoi(tmp);
   free(tmp);
@@ -255,7 +255,7 @@ static char *FuncGetHili(int *NbArg, long *TabArg)
   long Id;
   XColor color;
 
-  (*NbArg)++;	    /* La fonction GetValue n'a qu'un seul argument */
+  (*NbArg)++;       /* La fonction GetValue n'a qu'un seul argument */
   tmp = CalcArg(TabArg,NbArg);
   Id = atoi(tmp);
   free(tmp);
@@ -274,7 +274,7 @@ static char *FuncGetShad(int *NbArg, long *TabArg)
   long Id;
   XColor color;
 
-  (*NbArg)++;	    /* La fonction GetValue n'a qu'un seul argument */
+  (*NbArg)++;       /* La fonction GetValue n'a qu'un seul argument */
   tmp = CalcArg(TabArg,NbArg);
   Id = atoi(tmp);
   free(tmp);
@@ -381,7 +381,7 @@ static char *FuncGetOutput(int *NbArg, long *TabArg)
     str = (char*)safecalloc(sizeof(char),255);
     sscanf(&BufCom[j],"%s",str);
   }
-  else		/* Lecture de la ligne complete */
+  else          /* Lecture de la ligne complete */
   {
     if (i != 2) j++;
     k=j;
@@ -721,7 +721,7 @@ static char *ReceivFromScript (int *NbArg,long *TabArg)
 
   /* Recuperation du message */
   XConvertSelection(dpy,ASend,AReceiv,propriete,x11base->win,CurrentTime);
-  while ((!XCheckTypedEvent(dpy,SelectionNotify,&event)) && (NbEssai < 10))
+  while ((!FCheckTypedEvent(dpy,SelectionNotify,&event)) && (NbEssai < 10))
   {
     usleep(1);
     NbEssai++;
@@ -759,7 +759,7 @@ static char *FuncGetPid(int *NbArg,long *TabArg)
 
 /*******  SendMsgAndGet *******/
 #define IN_FIFO_NBR_OF_TRY 200
-#define IN_FIFO_TIMEOUT	   100000 /* usec: 0.1 sec (20 sec) */
+#define IN_FIFO_TIMEOUT    100000 /* usec: 0.1 sec (20 sec) */
 #define OUT_FIFO_NBR_OF_TRY  400
 #define OUT_FIFO_TIMEOUT     50000 /* usec: 0.05 sec (20 sec) */
 static char *FuncSendMsgAndGet(int *NbArg,long *TabArg)
@@ -780,7 +780,7 @@ static char *FuncSendMsgAndGet(int *NbArg,long *TabArg)
   (*NbArg)++;
   cmd=CalcArg(TabArg,NbArg);
   /* 0: no answer (so no locking) from the receiver  *
-   * 1: real send and get mode			     */
+   * 1: real send and get mode                       */
   (*NbArg)++;
   tmp=CalcArg(TabArg,NbArg);
   lock=atoi(tmp);
@@ -793,7 +793,7 @@ static char *FuncSendMsgAndGet(int *NbArg,long *TabArg)
 
   /* unlock the receiver, wait IN_FIFO_TIMEOUT * IN_FIFO_NBR_OF_TRY so that *
    * the receiver has the time to go in its communication loop at startup   *
-   * or if it do an other job than waiting for a cmd			    */
+   * or if it do an other job than waiting for a cmd                        */
   i = 0;
   while(1)
   {
@@ -850,7 +850,7 @@ static char *FuncSendMsgAndGet(int *NbArg,long *TabArg)
     return str;
   }
 
-  /* get the answer from the receiver.				    *
+  /* get the answer from the receiver.                              *
    * we wait OUT_FIFO_TIMEOUT * OUT_FIFO_NBR_OF_TRY for this answer */
   out_fifo =
     (char*)safecalloc(strlen(com_name)+strlen(FvwmUserDir)+15,sizeof(char));
@@ -1045,7 +1045,7 @@ static void ShowObj (int NbArg,long *TabArg)
 
   tabxobj[IdItem]->flags[0] = False;
   XMapWindow(dpy,tabxobj[IdItem]->win);
-  tabxobj[IdItem]->DrawObj(tabxobj[IdItem]);
+  tabxobj[IdItem]->DrawObj(tabxobj[IdItem], NULL);
   free(arg[0]);
 }
 
@@ -1063,7 +1063,7 @@ static void ChangeValue (int NbArg,long *TabArg)
   /* On redessine l'objet pour le mettre a jour */
   if (tabxobj[TabIdObj[atoi(arg[0])]]->TypeWidget != SwallowExec)
     XClearWindow(dpy, tabxobj[TabIdObj[atoi(arg[0])]]->win);
-  tabxobj[TabIdObj[atoi(arg[0])]]->DrawObj(tabxobj[TabIdObj[atoi(arg[0])]]);
+  tabxobj[TabIdObj[atoi(arg[0])]]->DrawObj(tabxobj[TabIdObj[atoi(arg[0])]],NULL);
   free(arg[0]);
   free(arg[1]);
 }
@@ -1087,7 +1087,7 @@ static void ChangeValueMax (int NbArg,long *TabArg)
     tabxobj[TabIdObj[j]]->value = atoi(arg[1]);
     if (tabxobj[TabIdObj[j]]->TypeWidget != SwallowExec)
       XClearWindow(dpy, tabxobj[TabIdObj[j]]->win);
-    tabxobj[TabIdObj[j]]->DrawObj(tabxobj[TabIdObj[j]]);
+    tabxobj[TabIdObj[j]]->DrawObj(tabxobj[TabIdObj[j]],NULL);
   }
   free(arg[0]);
   free(arg[1]);
@@ -1112,7 +1112,7 @@ static void ChangeValueMin (int NbArg,long *TabArg)
     tabxobj[TabIdObj[j]]->value = atoi(arg[1]);
     if (tabxobj[TabIdObj[j]]->TypeWidget != SwallowExec)
       XClearWindow(dpy, tabxobj[TabIdObj[j]]->win);
-    tabxobj[TabIdObj[j]]->DrawObj(tabxobj[TabIdObj[j]]);
+    tabxobj[TabIdObj[j]]->DrawObj(tabxobj[TabIdObj[j]],NULL);
   }
   free(arg[0]);
   free(arg[1]);
@@ -1175,7 +1175,7 @@ static void ChangeFont (int NbArg,long *TabArg)
 
   if (tabxobj[IdItem]->TypeWidget != SwallowExec)
     XClearWindow(dpy, tabxobj[IdItem]->win);
-  tabxobj[IdItem]->DrawObj(tabxobj[IdItem]);
+  tabxobj[IdItem]->DrawObj(tabxobj[IdItem],NULL);
   free(arg[0]);
   free(arg[1]);
 }
@@ -1201,7 +1201,7 @@ static void ChangeSize (int NbArg,long *TabArg)
   tabxobj[IdItem]->width = an[1];
   tabxobj[IdItem]->height = an[2];
   XResizeWindow(dpy,tabxobj[IdItem]->win,an[1],an[2]);
-  tabxobj[IdItem]->DrawObj(tabxobj[IdItem]);
+  tabxobj[IdItem]->DrawObj(tabxobj[IdItem],NULL);
   free(arg[0]);
   free(arg[1]);
   free(arg[2]);
@@ -1224,13 +1224,13 @@ static void ChangeTitle (int NbArg,long *TabArg)
   tabxobj[IdItem]->title=safestrdup(arg[1]);
   if (tabxobj[IdItem]->TypeWidget != SwallowExec)
     XClearWindow(dpy, tabxobj[IdItem]->win);
-  tabxobj[IdItem]->DrawObj(tabxobj[IdItem]);
+  tabxobj[IdItem]->DrawObj(tabxobj[IdItem],NULL);
   free(arg[0]);
   free(arg[1]);
 }
 
-/******* ChangeIcon *******/
-static void ChangeIcon (int NbArg,long *TabArg)
+/******* ChangeLocaleTitle *******/
+static void ChangeLocaleTitle (int NbArg,long *TabArg)
 {
   int i=0;
   char *arg[2];
@@ -1240,15 +1240,43 @@ static void ChangeIcon (int NbArg,long *TabArg)
   i++;
   arg[1] = CalcArg(TabArg,&i);
   IdItem = TabIdObj[atoi(arg[0])];
-  tabxobj[IdItem]->icon = safestrdup(arg[1]);
-  LoadIcon(tabxobj[IdItem]);
+
+  if (tabxobj[IdItem]->title)
+    free(tabxobj[IdItem]->title);
+  tabxobj[IdItem]->title=safestrdup(FGettext(arg[1]));
   if (tabxobj[IdItem]->TypeWidget != SwallowExec)
     XClearWindow(dpy, tabxobj[IdItem]->win);
-  tabxobj[IdItem]->DrawObj(tabxobj[IdItem]);
+  tabxobj[IdItem]->DrawObj(tabxobj[IdItem],NULL);
   free(arg[0]);
   free(arg[1]);
 }
 
+/******* ChangeIcon *******/
+static void ChangeIcon (int NbArg,long *TabArg)
+{
+	int i=0;
+	char *arg[2];
+	int IdItem;
+
+	arg[0] = CalcArg(TabArg,&i);
+	i++;
+	arg[1] = CalcArg(TabArg,&i);
+	IdItem = TabIdObj[atoi(arg[0])];
+	if (tabxobj[IdItem]->icon)
+	{
+		free(tabxobj[IdItem]->icon);
+	}
+	tabxobj[IdItem]->icon = safestrdup(arg[1]);
+	LoadIcon(tabxobj[IdItem]);
+	if (tabxobj[IdItem]->TypeWidget != SwallowExec)
+	{
+		XClearWindow(dpy, tabxobj[IdItem]->win);
+	}
+	tabxobj[IdItem]->DrawObj(tabxobj[IdItem],NULL);
+	free(arg[0]);
+	free(arg[1]);
+}
+
 /******* ChangeForeColor *******/
 static void ChangeForeColor (int NbArg,long *TabArg)
 {
@@ -1263,10 +1291,14 @@ static void ChangeForeColor (int NbArg,long *TabArg)
 
   /* Liberation de la couleur */
   if (tabxobj[IdItem]->colorset < 0)
-    XFreeColors(dpy,Pcmap,(void*)(&(tabxobj[IdItem])->TabColor[fore]),1,0);
+    PictureFreeColors(
+	    dpy,Pcmap,(void*)(&(tabxobj[IdItem])->TabColor[fore]),1,0, True);
 
-  tabxobj[IdItem]->forecolor=(char*)safecalloc(100,sizeof(char));
-  sprintf(tabxobj[IdItem]->forecolor,"%s",arg[1]);
+  if (tabxobj[IdItem]->forecolor)
+  {
+	  free(tabxobj[IdItem]->forecolor);
+  }
+  tabxobj[IdItem]->forecolor= safestrdup(arg[1]);
 
   tabxobj[IdItem]->TabColor[fore] = GetColor(tabxobj[IdItem]->forecolor);
   if (tabxobj[IdItem]->colorset >= 0) {
@@ -1278,7 +1310,7 @@ static void ChangeForeColor (int NbArg,long *TabArg)
 
   if (tabxobj[IdItem]->TypeWidget != SwallowExec)
     XClearWindow(dpy, tabxobj[IdItem]->win);
-  tabxobj[IdItem]->DrawObj(tabxobj[IdItem]);
+  tabxobj[IdItem]->DrawObj(tabxobj[IdItem],NULL);
 
   free(arg[0]);
   free(arg[1]);
@@ -1299,10 +1331,14 @@ static void ChangeBackColor (int NbArg,long *TabArg)
 
   /* Liberation de la couleur */
   if (tabxobj[IdItem]->colorset < 0)
-    XFreeColors(dpy,Pcmap,(void*)(&(tabxobj[IdItem])->TabColor[back]),1,0);
+    PictureFreeColors(
+	    dpy,Pcmap,(void*)(&(tabxobj[IdItem])->TabColor[back]),1,0,True);
 
-  tabxobj[IdItem]->backcolor = (char*)safecalloc(100,sizeof(char));
-  sprintf(tabxobj[IdItem]->backcolor,"%s",arg[1]);
+  if (tabxobj[IdItem]->backcolor)
+  {
+	  free(tabxobj[IdItem]->backcolor);
+  }
+  tabxobj[IdItem]->backcolor= safestrdup(arg[1]);
 
   tabxobj[IdItem]->TabColor[back] = GetColor(tabxobj[IdItem]->backcolor);
   if (tabxobj[IdItem]->colorset >= 0) {
@@ -1318,7 +1354,7 @@ static void ChangeBackColor (int NbArg,long *TabArg)
 			 tabxobj[IdItem]->TabColor[back]);
     XClearWindow(dpy, tabxobj[IdItem]->win);
   }
-  tabxobj[IdItem]->DrawObj(tabxobj[IdItem]);
+  tabxobj[IdItem]->DrawObj(tabxobj[IdItem],NULL);
 
   free(arg[0]);
   free(arg[1]);
@@ -1329,10 +1365,10 @@ static void ChangeMainColorset (int i)
 {
  /* Liberation de la couleur */
   if (x11base->colorset < 0) {
-    XFreeColors(dpy,Pcmap,&x11base->TabColor[fore],1,0);
-    XFreeColors(dpy,Pcmap,&x11base->TabColor[back],1,0);
-    XFreeColors(dpy,Pcmap,&x11base->TabColor[hili],1,0);
-    XFreeColors(dpy,Pcmap,&x11base->TabColor[shad],1,0);
+    PictureFreeColors(dpy,Pcmap,&x11base->TabColor[fore],1,0,True);
+    PictureFreeColors(dpy,Pcmap,&x11base->TabColor[back],1,0,True);
+    PictureFreeColors(dpy,Pcmap,&x11base->TabColor[hili],1,0,True);
+    PictureFreeColors(dpy,Pcmap,&x11base->TabColor[shad],1,0,True);
   }
   x11base->colorset = i;
   AllocColorset(i);
@@ -1364,10 +1400,10 @@ static void ChangeColorset (int NbArg,long *TabArg)
 
   /* Liberation de la couleur */
   if (tabxobj[IdItem]->colorset < 0) {
-    XFreeColors(dpy,Pcmap,&tabxobj[IdItem]->TabColor[fore],1,0);
-    XFreeColors(dpy,Pcmap,&tabxobj[IdItem]->TabColor[back],1,0);
-    XFreeColors(dpy,Pcmap,&tabxobj[IdItem]->TabColor[hili],1,0);
-    XFreeColors(dpy,Pcmap,&tabxobj[IdItem]->TabColor[shad],1,0);
+    PictureFreeColors(dpy,Pcmap,&tabxobj[IdItem]->TabColor[fore],1,0,True);
+    PictureFreeColors(dpy,Pcmap,&tabxobj[IdItem]->TabColor[back],1,0,True);
+    PictureFreeColors(dpy,Pcmap,&tabxobj[IdItem]->TabColor[hili],1,0,True);
+    PictureFreeColors(dpy,Pcmap,&tabxobj[IdItem]->TabColor[shad],1,0,True);
   }
   sscanf(arg[1], "%d", &i);
   tabxobj[IdItem]->colorset = i;
@@ -1383,7 +1419,7 @@ static void ChangeColorset (int NbArg,long *TabArg)
 			tabxobj[IdItem]->gc, False);
     XClearWindow(dpy, tabxobj[IdItem]->win);
   }
-  tabxobj[IdItem]->DrawObj(tabxobj[IdItem]);
+  tabxobj[IdItem]->DrawObj(tabxobj[IdItem],NULL);
 
   free(arg[0]);
   free(arg[1]);
@@ -1437,7 +1473,7 @@ static void MyWarpPointer(int NbArg,long *TabArg)
   arg=CalcArg(TabArg,&i);
   IdItem= TabIdObj[atoi(arg)];
   /* Deplacement du pointeur sur l'objet */
-  XWarpPointer(dpy, None, tabxobj[IdItem]->win, 0, 0, 0, 0,
+  FWarpPointer(dpy, None, tabxobj[IdItem]->win, 0, 0, 0, 0,
 	       tabxobj[IdItem]->width / 2, tabxobj[IdItem]->height + 10);
   free(arg);
 }
@@ -1459,7 +1495,7 @@ static void IfThen (int NbArg,long *TabArg)
   /* Verification de la condition */
   for (j=0; j<NbArg-2; j++)
   {
-    if (TabArg[j] > 100000)	/* Cas du codage d'un nombre */
+    if (TabArg[j] > 100000)     /* Cas du codage d'un nombre */
     {
       i = (int)TabArg[j] - 200000;
       arg[CurrArg] = (char*)safecalloc(1,sizeof(char)*10);
@@ -1470,12 +1506,12 @@ static void IfThen (int NbArg,long *TabArg)
     {
       IdFuncComp = TabArg[j] + 250000;
     }
-    else if (TabArg[j] < -100000)	/* Cas d'un id de fonction */
+    else if (TabArg[j] < -100000)       /* Cas d'un id de fonction */
     {
       arg[CurrArg] = TabFunc[TabArg[j]+150000](&j,TabArg);
       CurrArg++;
     }
-    else				/* Cas d'une variable */
+    else                                /* Cas d'une variable */
     {
       arg[CurrArg] = safestrdup(TabVVar[TabArg[j]]);
       CurrArg++;
@@ -1508,17 +1544,17 @@ static void Loop (int NbArg,long *TabArg)
   /* Calcul des 2 autres arguments */
   for (i=1; i<NbArg-1; i++)
   {
-    if (TabArg[i] > 100000)	/* Cas du codage d'un nombre */
+    if (TabArg[i] > 100000)     /* Cas du codage d'un nombre */
     {
       i = (int)TabArg[i] - 200000;
       arg[CurrArg] = (char*)safecalloc(1,sizeof(char)*10);
       sprintf(arg[CurrArg],"%d",i);
     }
-    else if (TabArg[i] < -100000)	/* Cas d'un id de fonction */
+    else if (TabArg[i] < -100000)       /* Cas d'un id de fonction */
     {
       arg[CurrArg] = TabFunc[TabArg[i]+150000](&i,TabArg);
     }
-    else				/* Cas d'une variable */
+    else                                /* Cas d'une variable */
       arg[CurrArg] = safestrdup(TabVVar[TabArg[i]]);
     CurrArg++;
   }
@@ -1644,7 +1680,7 @@ static void WriteToFile (int NbArg,long *TabArg)
       memmove(&buf[CurrPos+strlen(arg[1])],&buf[CurrPos],strlen(buf)-CurrPos);
       memmove(&buf[CurrPos],arg[1],strlen(arg[1]));
     }
-    else	  /* Remplacement des anciennes commandes */
+    else          /* Remplacement des anciennes commandes */
     {
       CurrPos = CurrPos+strlen(StrBegin);
       CurrPos2 = CurrPos;
@@ -1783,13 +1819,33 @@ static void Key (int NbArg,long *TabArg)
     return;
   }
 
-  AddBinding(dpy, &BindingsList, KEY_BINDING, STROKE_ARG(0)
-	     0, keysym, key_string, modifier, C_WINDOW,
-	     (void *)action, NULL);
+  AddBinding(
+	  dpy, &BindingsList, BIND_KEYPRESS, STROKE_ARG(0) 0, keysym,
+	  key_string, modifier, C_WINDOW, (void *)action, NULL);
   free(key_string);
   free(in_modifier);
 }
 
+/****************************************************/
+/* GetText Support                                  */
+/****************************************************/
+
+static char *FuncGettext(int *NbArg,long *TabArg)
+{
+	char *str;
+	char *string;
+
+	(*NbArg)++;
+	str = CalcArg(TabArg,NbArg);
+
+	string = FGettextCopy(str);
+	if (str && string != str)
+	{
+		free(str);
+	}
+	return (char *)string;
+}
+
 /****************************************************/
 /* Fonction d'initialisation de TabCom et TabFunc   */
 /****************************************************/
@@ -1820,6 +1876,7 @@ void InitCom()
   TabCom[23]=SendToScript;
   TabCom[24]=ChangeColorset;
   TabCom[25]=Key;
+  TabCom[26]=ChangeLocaleTitle;
 
   /* Fonction */
   TabFunc[1]=FuncGetValue;
@@ -1847,6 +1904,7 @@ void InitCom()
   TabFunc[23]=FuncSendMsgAndGet;
   TabFunc[24]=FuncParse;
   TabFunc[25]=FuncGetLastString;
+  TabFunc[26]=FuncGettext;
 
   /* Fonction de comparaison */
   TabComp[1]=Inf;
