@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "Tools.h"
@@ -78,7 +78,7 @@ void DestroyCheckBox(struct XObj *xobj)
   XDestroyWindow(dpy,xobj->win);
 }
 
-void DrawCheckBox(struct XObj *xobj)
+void DrawCheckBox(struct XObj *xobj, XEvent *evp)
 {
   XSegment segm[2];
 
@@ -89,7 +89,7 @@ void DrawCheckBox(struct XObj *xobj)
   /* Calcul de la position de la chaine de charactere */
   /* Compute the position of string */
   MyDrawString(dpy, xobj, xobj->win, 23, xobj->Ffont->ascent, xobj->title,
-	       fore, hili, back, !xobj->flags[1]);
+	       fore, hili, back, !xobj->flags[1], NULL, evp);
   /* Dessin de la croix / draw the cross */
   if (xobj->value)
   {
@@ -121,11 +121,11 @@ void EvtMouseCheckBox(struct XObj *xobj, XButtonEvent *EvtButton)
 
   while (End)
   {
-    XNextEvent(dpy, &event);
+    FNextEvent(dpy, &event);
     switch (event.type)
     {
     case EnterNotify:
-      XQueryPointer(dpy, *xobj->ParentWin,
+      FQueryPointer(dpy, *xobj->ParentWin,
 		    &Win1, &Win2, &x1, &y1, &x2, &y2, &modif);
       if (WinBut == 0)
       {
@@ -154,7 +154,7 @@ void EvtMouseCheckBox(struct XObj *xobj, XButtonEvent *EvtButton)
       }
       break;
     case LeaveNotify:
-      XQueryPointer(dpy, *xobj->ParentWin,
+      FQueryPointer(dpy, *xobj->ParentWin,
 		    &Win1, &Win2, &x1, &y1, &x2, &y2, &modif);
       if (Win2 == WinBut)
       {
