@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "Tools.h"
@@ -18,7 +18,7 @@
 extern int fd[2];
 
 /***********************************************/
-/* Fonction pour Swallow		       */
+/* Fonction pour Swallow                       */
 /***********************************************/
 
 void DrawRelief(struct XObj *xobj)
@@ -108,7 +108,7 @@ void DestroySwallow(struct XObj *xobj)
   XKillClient(dpy, xobj->win);
 }
 
-void DrawSwallow(struct XObj *xobj)
+void DrawSwallow(struct XObj *xobj, XEvent *evp)
 {
  DrawRelief(xobj);
 }
@@ -126,7 +126,7 @@ void CheckForHangon(struct XObj *xobj,unsigned long *body)
 {
   char *cbody;
 
-  cbody=(char*)calloc(100,sizeof(char));
+  cbody=(char*)calloc(strlen((char *)&body[3]) + 1,sizeof(char));
   sprintf(cbody,"%s",(char *)&body[3]);
   if(strcmp(cbody,xobj->title)==0)
   {
