@@ -75,6 +75,7 @@
 #include "libs/gravity.h"
 #include "libs/FRender.h"
 #include "libs/FRenderInit.h"
+#include "libs/FGettext.h"
 
 #include "FvwmTaskBar.h"
 #include "ButtonArray.h"
@@ -170,7 +171,7 @@ static volatile sig_atomic_t stick_taskbar_alarm = False;
 
 int UpdateInterval = 30;
 
-int whichButton = -1; 
+int whichButton = -1;
 Bool startButtonPressed = FALSE;
 
 ButtonArray buttons;
@@ -266,6 +267,7 @@ int main(int argc, char **argv)
 
   FlocaleInit(LC_CTYPE, "", "", "FvwmTaskBar");
   setlocale(LC_TIME, "");
+  FGettextInit("FvwmTaskBar", LOCALEDIR, "FvwmTaskBar");
 
   for (i = 3; i < NUMBER_OF_MOUSE_BUTTONS; i++)
   {
@@ -431,7 +433,7 @@ void EndLessLoop(void)
     }
     DoAlarmAction();
 
-    DrawGoodies();
+    DrawGoodies(NULL);
   } /* while */
 }
 
@@ -556,6 +558,8 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 	hints.base_width  = win_width;
 	hints.max_width   = win_width;
 
+	/* hack to prevent mapping on wrong screen with StartsOnScreen */
+	FScreenMangleScreenIntoUSPosHints(fscreen, &hints);
 	XSetWMNormalHints(dpy,win,&hints);
 
 	if (AutoStick)
@@ -568,6 +572,8 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 		    - WindowButtonsLeftMargin - WindowButtonsRightMargin,
 		    -1, -1);
 	ArrangeButtonArray (&buttons);
+	AdjustWindow(win_width, win_height);
+	redraw = 1;
       }
       if (AutoStick && win_is_shaded != IS_SHADED(cfgpacket))
       {
@@ -699,7 +705,7 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 	redraw = 1;
       }
     }
-    else
+    else if (!UseSkipList || !DO_SKIP_WINDOW_LIST(cfgpacket))
     {
       AddItem(&windows, cfgpacket->w,
 	      cfgpacket, cfgpacket->desk, Count++);
@@ -820,7 +826,7 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 	}
 	temp->needsupdate = 1;
 	temp->iconified = iconified;
-	DrawButtonArray(&buttons, 0);
+	DrawButtonArray(&buttons, 0, NULL);
       }
       if (AnimCommand && AnimCommand[0] != 0)
 	SendUnlockNotification(Fvwm_fd);
@@ -854,9 +860,13 @@ void ProcessMessage(unsigned long type,unsigned long *body)
 
   case MX_PROPERTY_CHANGE:
     if (body[0] == MX_PROPERTY_CHANGE_BACKGROUND && body[2] == 0 &&
-	colorset > -1 && Colorset[colorset].pixmap == ParentRelative)
+	CSET_IS_TRANSPARENT_PR(colorset))
     {
-      redraw = 1;
+	    SetWindowBackground(
+		    dpy, win, win_width, win_height,
+		    &Colorset[colorset],
+		    Pdepth, graph, True);
+	    redraw = 1;
     }
     break;
 
@@ -885,7 +895,7 @@ void ProcessMessage(unsigned long type,unsigned long *body)
   } /* switch */
 
   if (redraw >= 0)
-    RedrawWindow(redraw);
+    RedrawWindow(redraw, NULL);
 }
 
 void redraw_buttons()
@@ -896,16 +906,26 @@ void redraw_buttons()
 
   for (item=windows.head; item; item=item->next)
   {
-    if ((DeskNumber == item->Desk || IS_STICKY(item) ||
-	 (IS_ICONIFIED(item) && IS_ICON_STICKY(item))) &&
-	(!DO_SKIP_WINDOW_LIST(item) || !UseSkipList))
+    if ((DeskNumber != item->Desk && !IS_STICKY_ACROSS_DESKS(item) &&
+	 (!IS_ICONIFIED(item) || !IS_ICON_STICKY_ACROSS_DESKS(item))))
     {
-      AddButton(&buttons, item->name, &(item->p), BUTTON_UP, item->count,
-		IS_ICONIFIED(item));
+	    continue;
     }
+    if (DO_SKIP_WINDOW_LIST(item) && UseSkipList)
+    {
+	    continue;
+    }
+    if (PageOnly &&
+	!fvwmrect_do_rectangles_intersect(&item->win_g, &global_scr_g))
+    {
+	    continue;
+    }
+    AddButton(
+	    &buttons, item->name, &(item->p), BUTTON_UP, item->count,
+	    IS_ICONIFIED(item));
   }
 
-  RedrawWindow(1);
+  RedrawWindow(1, NULL);
 }
 
 
@@ -932,6 +952,7 @@ TerminateHandler(int sig)
   fvwmSetTerminate(sig);
 }
 
+#if 0
 /******************************************************************************
   WaitForExpose - Used to wait for expose event so we don't draw too early
 ******************************************************************************/
@@ -946,33 +967,45 @@ void WaitForExpose(void)
     }
   }
 }
+#endif
 
 /******************************************************************************
   RedrawWindow - Update the needed lines and erase any old ones
 ******************************************************************************/
-void RedrawWindow(int force)
+void RedrawWindow(int force, XEvent *evp)
 {
-  if (Tip.open)
-  {
-    RedrawTipWindow();
+	if (Tip.open)
+	{
+		RedrawTipWindow();
 
-    /* 98-11-21 13:45, Mohsin_Ahmed, mailto:mosh@sasi.com. */
-    if( Tip.type >= 0 && AutoFocus )
-    {
-      SendFvwmPipe(Fvwm_fd, "Iconify off, Raise, Focus",
-		    ItemID( &windows, Tip.type ) );
-    }
-  }
+		/* 98-11-21 13:45, Mohsin_Ahmed, mailto:mosh@sasi.com. */
+		if( Tip.type >= 0 && AutoFocus )
+		{
+			SendFvwmPipe(
+				Fvwm_fd, "Iconify off, Raise, Focus",
+				ItemID( &windows, Tip.type ) );
+		}
+	}
 
-  if (force)
-  {
-    XClearArea (dpy, win, 0, 0, win_width, win_height, False);
-    DrawGoodies();
-  }
-  DrawButtonArray(&buttons, force);
-  StartButtonDraw(force);
-  if (FQLength(dpy) && !force)
-    LoopOnEvents();
+	if (force)
+	{
+		if (evp)
+		{
+			XClearArea(
+				dpy, win, evp->xexpose.x, evp->xexpose.y,
+				evp->xexpose.width, evp->xexpose.height, False);
+		}
+		else
+		{
+			XClearArea(
+				dpy, win, 0, 0, win_width, win_height, False);
+		}
+		DrawGoodies(evp);
+	}
+	DrawButtonArray(&buttons, force, evp);
+	StartButtonDraw(force, evp);
+	if (FQLength(dpy) && !force)
+		LoopOnEvents();
 }
 
 static char *configopts[] =
@@ -1284,7 +1317,7 @@ void CheckForTip(int x, int y)
   if (MouseInStartButton(x, y, &whichButton, &startButtonPressed)) {
     if((!whichButton) && (First_Start_Button->isStartButton))
     {
-      if (Tip.type != START_TIP) PopupTipWindow(3, 0, "Click here to start");
+      if (Tip.type != START_TIP) PopupTipWindow(3, 0, _("Click here to start"));
       Tip.type = START_TIP;
     }
     else
@@ -1320,291 +1353,432 @@ void CheckForTip(int x, int y)
   }
 }
 
+/******************************************************************************
+   HandleButtonRelease - Process a ButtonRelease X event
+******************************************************************************/
+void HandleButtonRelease(
+	XEvent *evp, Time *NewTimestamp, int *redraw)
+{
+	int  num = 0;
+	char *tmp;
+
+	*NewTimestamp = evp->xbutton.time;
+	num = WhichButton(
+		&buttons, evp->xbutton.x, evp->xbutton.y);
+	StartButtonUpdate(NULL, -1, BUTTON_UP);
+	if (num == -1)
+	{
+		if (MouseInStartButton(
+			evp->xbutton.x, evp->xbutton.y,
+			&whichButton, &startButtonPressed))
+		{
+			if (whichButton == ButtonPressed)
+			{
+				if ((First_Start_Button->buttonStartCommand
+				     != NULL) && (startButtonPressed))
+				{
+					rectangle r;
+					Window tmpw;
+					r.x = 0;
+					r.y = 0;
+					r.width =
+						StartAndLaunchButtonsWidth;
+					r.height = StartAndLaunchButtonsHeight;
+					XTranslateCoordinates(
+						dpy, win, Root, r.x, r.y,
+						&r.x, &r.y, &tmpw);
+					tmp = module_expand_action(
+						dpy, screen,
+						First_Start_Button->
+						buttonStartCommand, &r,
+						NULL, NULL);
+					if (tmp)
+					{
+						SendText(Fvwm_fd, tmp, 0);
+						free(tmp);
+					}
+					else
+					{
+						SendText(
+							Fvwm_fd,
+							First_Start_Button->
+							buttonStartCommand, 0);
+					}
+				}
+				else
+				{
+					tmp = (char *)safemalloc(
+						100 * sizeof(char));
+					/* fix this later */
+					getButtonCommand(
+						whichButton, tmp,
+						evp->xbutton.button);
+					SendText(Fvwm_fd, tmp, 0);
+					free(tmp);
+				}
+			}
+		}
+	}
+	else
+	{
+		ButReleased = ButPressed; /* Avoid race fvwm pipe */
+		if (evp->xbutton.button >= 1 &&
+		    evp->xbutton.button <= NUMBER_OF_MOUSE_BUTTONS)
+		{
+			rectangle r;
+			Window tmpw;
+
+			ButtonCoordinates(&buttons, num, &r.x, &r.y);
+			ButtonDimensions(&buttons, &r.width, &r.height);
+			XTranslateCoordinates(
+				dpy, win, Root, r.x, r.y, &r.x, &r.y, &tmpw);
+			tmp = module_expand_action(
+				dpy, screen, ClickAction[evp->xbutton.button-1],
+				&r, NULL, NULL);
+			if (tmp)
+			{
+				SendFvwmPipe(
+					Fvwm_fd, tmp, ItemID(&windows, num));
+				free(tmp);
+			}
+			else
+			{
+				SendFvwmPipe(
+					Fvwm_fd,
+					ClickAction[evp->xbutton.button-1],
+					ItemID(&windows, num));
+			}
+		}
+	}
+
+	if (MouseInStartButton(
+		evp->xbutton.x, evp->xbutton.y, &whichButton,
+		&startButtonPressed))
+	{
+		*redraw = 0;
+		usleep(50000);
+	}
+	if (HighlightFocus)
+	{
+		if (num == ButPressed)
+			RadioButton(&buttons, num, BUTTON_DOWN);
+		if (num != -1)
+			SendText(
+				Fvwm_fd, "Focus 0", ItemID(&windows, num));
+	}
+	ButPressed = -1;
+	*redraw = 0;
+}
+
+/******************************************************************************
+  HandleEvents - Process an X event
+******************************************************************************/
+void HandleEvents(
+	XEvent *evp, Time *NewTimestamp, int *redraw, int *expose_redraw)
+{
+	int  num = 0;
+	XEvent *evp_save;
+	int x, y;
+	int ex=10000, ey=10000, ex2=0, ey2=0;
+
+	*redraw = -1;
+	*expose_redraw = False;
+
+	switch(evp->type)
+	{
+	case ButtonRelease:
+		HandleButtonRelease(evp, NewTimestamp, redraw);
+		break;
+	case ButtonPress:
+		*NewTimestamp = evp->xbutton.time;
+		RadioButton(&buttons, -1, BUTTON_UP); /* no windows focused
+						       * anymore */
+		if (MouseInStartButton(
+			evp->xbutton.x, evp->xbutton.y, &whichButton,
+			&startButtonPressed))
+		{
+			StartButtonUpdate(NULL, whichButton, BUTTON_DOWN);
+			ButtonPressed = whichButton;
+			x = win_x;
+			if (win_y < Midline)
+			{
+				/* bar in top half of the screen */
+				y = win_y + RowHeight;
+			}
+			else
+			{
+				/* bar in bottom of the screen */
+				y = win_y - screen_g.height;
+			}
+		}
+		else
+		{
+			StartButtonUpdate(NULL, whichButton, BUTTON_UP);
+			if (MouseInMail(evp->xbutton.x, evp->xbutton.y))
+			{
+				HandleMailClick(*evp);
+			}
+			else
+			{
+				num = WhichButton(
+					&buttons, evp->xbutton.x,
+					evp->xbutton.y);
+				UpdateButton(&buttons, num, NULL,
+					     (ButPressed == num) ?
+					     BUTTON_BRIGHT : BUTTON_DOWN);
+				ButPressed = num;
+			}
+		}
+		*redraw = 0;
+		break;
+
+	case Expose:
+		if (evp->xexpose.window == Tip.win)
+		{
+			while (FCheckTypedWindowEvent(
+				dpy, evp->xexpose.window, Expose, evp));
+			if (Tip.open)
+			{
+				RedrawTipWindow();
+			}
+			break;
+		}
+		/* eat up excess Expose events. */
+		ex = evp->xexpose.x;
+		ey = evp->xexpose.y;
+		ex2 = evp->xexpose.x + evp->xexpose.width;
+		ey2 = evp->xexpose.y + evp->xexpose.height;
+		while (FCheckTypedWindowEvent(dpy, win, Expose, evp))
+		{
+			ex = min(ex, evp->xexpose.x);
+			ey = min(ey, evp->xexpose.y);
+			ex2 = max(ex2, evp->xexpose.x + evp->xexpose.width);
+			ey2= max(ey2 , evp->xexpose.y + evp->xexpose.height);
+		}
+		evp->xexpose.x = ex;
+		evp->xexpose.y = ey;
+		evp->xexpose.width = ex2 - ex;
+		evp->xexpose.height = ey2 - ey;
+		*redraw = 1;
+		*expose_redraw = True;
+		break;
+
+	case ClientMessage:
+		if ((evp->xclient.format==32) &&
+		    (evp->xclient.data.l[0]==wm_del_win))
+			exit(0);
+		break;
+
+	case EnterNotify:
+		*NewTimestamp = evp->xcrossing.time;
+		if (AutoHide)
+		{
+			RevealTaskBar();
+		}
+		if (evp->xcrossing.mode != NotifyNormal)
+			break;
+		num = WhichButton(
+			&buttons, evp->xcrossing.x, evp->xcrossing.y);
+		if (!HighlightFocus)
+		{
+			if (SomeButtonDown(evp->xcrossing.state))
+			{
+				if (num != -1)
+				{
+					RadioButton(&buttons, num, BUTTON_DOWN);
+					ButPressed = num;
+					*redraw = 0;
+				}
+				else
+				{
+					ButPressed = -1;
+				}
+			}
+		}
+		else
+		{
+			if (num != -1 && num != ButPressed)
+				SendText(
+					Fvwm_fd, "Focus 0",
+					ItemID(&windows, num));
+		}
+
+		CheckForTip(evp->xmotion.x, evp->xmotion.y);
+		break;
+
+	case LeaveNotify:
+		*NewTimestamp = evp->xcrossing.time;
+		ClearAlarm(SHOW_TIP);
+		if (Tip.open)
+			ShowTipWindow(0);
+
+		if (AutoHide)
+			SetAlarm(HIDE_TASK_BAR);
+
+		if (evp->xcrossing.mode != NotifyNormal)
+			break;
+
+		if (!HighlightFocus)
+		{
+			if (SomeButtonDown(evp->xcrossing.state))
+			{
+				if (ButPressed != -1)
+				{
+					RadioButton(&buttons, -1, BUTTON_UP);
+					ButPressed = -1;
+					*redraw = 0;
+				}
+			}
+			else
+			{
+				if (ButReleased != -1)
+				{
+					RadioButton(&buttons, -1, BUTTON_UP);
+					ButReleased = -1;
+					*redraw = 0;
+				}
+			}
+		}
+		break;
+
+	case MotionNotify:
+		*NewTimestamp = evp->xmotion.time;
+		if (MouseInStartButton(
+			evp->xmotion.x, evp->xbutton.y, &whichButton,
+			&startButtonPressed))
+		{
+			CheckForTip(evp->xmotion.x, evp->xmotion.y);
+			break;
+		}
+		num = WhichButton(&buttons, evp->xmotion.x, evp->xmotion.y);
+		if (!HighlightFocus)
+		{
+			if (SomeButtonDown(evp->xmotion.state) &&
+			    num != ButPressed)
+			{
+				if (num != -1)
+				{
+					RadioButton(&buttons, num, BUTTON_DOWN);
+					ButPressed = num;
+				}
+				else
+				{
+					RadioButton(&buttons, num, BUTTON_UP);
+					ButPressed = -1;
+				}
+				*redraw = 0;
+			}
+		}
+		else if (num != -1 && num != ButPressed)
+			SendText(Fvwm_fd, "Focus 0", ItemID(&windows, num));
+
+		CheckForTip(evp->xmotion.x, evp->xmotion.y);
+		break;
+
+	case ConfigureNotify:
+	{
+		Bool moved = False;
+		int cx = win_x, cy = win_y;
+
+		/* eat up excess ConfigureNotify events. */
+		if (evp->xconfigure.send_event)
+		{
+			moved = True;
+			cx = evp->xconfigure.x;
+			cy = evp->xconfigure.y;
+		}
+		evp_save = evp;
+		while (FCheckTypedWindowEvent(dpy, win, ConfigureNotify, evp))
+		{
+			evp_save = evp;
+			if (evp->xconfigure.send_event)
+			{
+				moved = True;
+				cx = evp->xconfigure.x;
+				cy = evp->xconfigure.y;
+			}
+		}
+		evp = evp_save;
+		if (evp->xconfigure.height != win_height)
+		{
+			AdjustWindow(
+				evp->xconfigure.width, evp->xconfigure.height);
+			if (colorset >= 0)
+			{
+				SetWindowBackground(
+					dpy, win, win_width, win_height,
+					&Colorset[colorset], Pdepth, graph,
+					True);
+			}
+			*redraw = 1;
+		}
+		/* useful because of dynamic style change */
+		if (!moved)
+		{
+			break;
+		}
+		else if (cx != win_x || cy != win_y)
+		{
+			if (CSET_IS_TRANSPARENT(colorset))
+			{
+				SetWindowBackground(
+					dpy, win, win_width, win_height,
+					&Colorset[colorset],
+					Pdepth, graph, True);
+				*redraw = 1;
+			}
+			else if (CheckRootTransparentButtons(&buttons))
+			{
+				*redraw = 0;
+			}
+			if (AutoStick)
+			{
+				SetAlarm(STICK_TASK_BAR);
+				auto_stick_y = evp->xconfigure.y;
+			}
+			else
+			{
+				win_x = cx;
+				win_y = cy;
+			}
+		}
+	}
+	break;
+	} /* switch evp->type */
+
+	XSync(dpy,0); /* needed (tips) */
+}
+
 /******************************************************************************
   LoopOnEvents - Process all the X events we get
 ******************************************************************************/
 void LoopOnEvents(void)
 {
-  int  num = 0;
-  char *tmp;
-  XEvent Event;
-  XEvent Event2;
-  int x, y, redraw;
-  static unsigned long lasttime = 0L;
-  Time NewTimestamp = lasttime;
+	XEvent Event;
+	int redraw, expose_redraw;
+	static unsigned long lasttime = 0L;
+	Time NewTimestamp = lasttime;
 
-  while(FPending(dpy))
-  {
-    redraw = -1;
-    FNextEvent(dpy, &Event);
-    if (Event.xany.type == ConfigureNotify)
-    {
-      /* Purge all but the last configure events */
-      while (FCheckTypedEvent(dpy, ConfigureNotify, &Event))
-	;
-    }
-
-    NewTimestamp = lasttime;
-    switch(Event.type)
-    {
-    case ButtonRelease:
-      NewTimestamp = Event.xbutton.time;
-      num = WhichButton(&buttons, Event.xbutton.x, Event.xbutton.y);
-      StartButtonUpdate(NULL, -1, BUTTON_UP);
-      if (num == -1) 
-      {
-	if (MouseInStartButton(Event.xbutton.x, Event.xbutton.y, &whichButton, &startButtonPressed))
+	while(FPending(dpy))
 	{
-	  if (whichButton == ButtonPressed)
-	  {
-	    if ((First_Start_Button->buttonStartCommand != NULL) && (startButtonPressed))
-	    {
-	      rectangle r;
-	      Window tmpw;
-	      r.x = 0;
-	      r.y = 0;
-	      r.width = StartAndLaunchButtonsWidth;
-	      r.height = StartAndLaunchButtonsHeight;
-	      XTranslateCoordinates(dpy, win, Root, r.x, r.y, &r.x, &r.y, &tmpw);
-	      tmp = module_expand_action(dpy, screen, First_Start_Button->buttonStartCommand, &r, NULL, NULL);  
-	      if (tmp)
-	      {
-		SendText(Fvwm_fd, tmp, 0);
-		free(tmp);
-	      }
-	      else
-	      {
-		SendText(Fvwm_fd, First_Start_Button->buttonStartCommand, 0);
-	      }
-	    }
-	    else
-	    {
-	      tmp = (char *)safemalloc(100 * sizeof(char)); /* fix this later */
-	      getButtonCommand(whichButton, tmp, Event.xbutton.button);
-	      SendText(Fvwm_fd, tmp, 0);
-	      free(tmp);
-	    }
-	  }
+		redraw = -1;
+		expose_redraw = False,
+
+		FNextEvent(dpy, &Event);
+		NewTimestamp = lasttime;
+		HandleEvents(&Event, &NewTimestamp, &redraw, &expose_redraw);
+		if (redraw >= 0)
+		{
+			RedrawWindow(redraw, (expose_redraw)? &Event:NULL);
+		}
+		DoAlarmAction();
+		if (NewTimestamp - lasttime > UpdateInterval*1000L)
+		{
+			DrawGoodies(NULL);
+			lasttime = NewTimestamp;
+		}
 	}
-      } 
-      else 
-      {
-	ButReleased = ButPressed; /* Avoid race fvwm pipe */
-	if (Event.xbutton.button >= 1 &&
-	    Event.xbutton.button <= NUMBER_OF_MOUSE_BUTTONS)
-	{
-	  rectangle r;
-	  Window tmpw;
-
-	  ButtonCoordinates(&buttons, num, &r.x, &r.y);
-	  ButtonDimensions(&buttons, &r.width, &r.height);
-	  XTranslateCoordinates(dpy, win, Root, r.x, r.y, &r.x, &r.y, &tmpw);
-	  tmp = module_expand_action(
-		  dpy, screen, ClickAction[Event.xbutton.button-1], &r, NULL,
-		  NULL);
-	  if (tmp)
-	  {
-	    SendFvwmPipe(Fvwm_fd, tmp, ItemID(&windows, num));
-	    free(tmp);
-	  }
-	  else
-	  {
-	    SendFvwmPipe(
-		    Fvwm_fd, ClickAction[Event.xbutton.button-1],
-		    ItemID(&windows, num));
-	  }
-	}
-      }
-
-      if (MouseInStartButton(Event.xbutton.x, Event.xbutton.y, &whichButton, &startButtonPressed)) {
-	redraw = 0;
-	usleep(50000);
-      }
-      if (HighlightFocus) {
-	if (num == ButPressed)
-	  RadioButton(&buttons, num, BUTTON_DOWN);
-	if (num != -1)
-	  SendText(Fvwm_fd, "Focus 0", ItemID(&windows, num));
-      }
-      ButPressed = -1;
-      redraw = 0;
-      break;
-
-    case ButtonPress:
-      NewTimestamp = Event.xbutton.time;
-      RadioButton(&buttons, -1, BUTTON_UP); /* no windows focused anymore */
-      if (MouseInStartButton(Event.xbutton.x, Event.xbutton.y, &whichButton, &startButtonPressed))
-      {
-	StartButtonUpdate(NULL, whichButton, BUTTON_DOWN);
-	ButtonPressed = whichButton;
-	x = win_x;
-	if (win_y < Midline) {
-	  /* bar in top half of the screen */
-	  y = win_y + RowHeight;
-	} else {
-	  /* bar in bottom of the screen */
-	  y = win_y - screen_g.height;
-	}
-      } else {
-	StartButtonUpdate(NULL, whichButton, BUTTON_UP);
-	if (MouseInMail(Event.xbutton.x, Event.xbutton.y)) {
-	  HandleMailClick(Event);
-	} else {
-	  num = WhichButton(&buttons, Event.xbutton.x, Event.xbutton.y);
-	  UpdateButton(&buttons, num, NULL, (ButPressed == num) ?
-		       BUTTON_BRIGHT : BUTTON_DOWN);
-
-	  ButPressed = num;
-	}
-      }
-      redraw = 0;
-      break;
-
-    case Expose:
-      memcpy(&Event2, &Event, sizeof(Event));
-      /* eat up excess Expose events. */
-      while (FCheckTypedWindowEvent(dpy, win, Expose, &Event2))
-      {
-	memcpy(&Event, &Event2, sizeof(Event));
-      }
-      if (Event.xexpose.count == 0)
-      {
-	if (Event.xexpose.window == Tip.win)
-	  redraw = 0;
-	else
-	  redraw = 1;
-      }
-      break;
-
-    case ClientMessage:
-      if ((Event.xclient.format==32) && (Event.xclient.data.l[0]==wm_del_win))
-	exit(0);
-      break;
-
-    case EnterNotify:
-      NewTimestamp = Event.xcrossing.time;
-      if (AutoHide)
-	RevealTaskBar();
-
-      if (Event.xcrossing.mode != NotifyNormal)
-	break;
-      num = WhichButton(&buttons, Event.xcrossing.x, Event.xcrossing.y);
-      if (!HighlightFocus) {
-	if (SomeButtonDown(Event.xcrossing.state)) {
-	  if (num != -1) {
-	    RadioButton(&buttons, num, BUTTON_DOWN);
-	    ButPressed = num;
-	    redraw = 0;
-	  } else {
-	    ButPressed = -1;
-	  }
-	}
-      } else {
-	if (num != -1 && num != ButPressed)
-	  SendText(Fvwm_fd, "Focus 0", ItemID(&windows, num));
-      }
-
-      CheckForTip(Event.xmotion.x, Event.xmotion.y);
-      break;
-
-    case LeaveNotify:
-      NewTimestamp = Event.xcrossing.time;
-      ClearAlarm(SHOW_TIP);
-      if (Tip.open)
-	ShowTipWindow(0);
-
-      if (AutoHide)
-	SetAlarm(HIDE_TASK_BAR);
-
-      if (Event.xcrossing.mode != NotifyNormal)
-	break;
-
-      if (!HighlightFocus) {
-	if (SomeButtonDown(Event.xcrossing.state)) {
-	  if (ButPressed != -1) {
-	    RadioButton(&buttons, -1, BUTTON_UP);
-	    ButPressed = -1;
-	    redraw = 0;
-	  }
-	} else {
-	  if (ButReleased != -1) {
-	    RadioButton(&buttons, -1, BUTTON_UP);
-	    ButReleased = -1;
-	    redraw = 0;
-	  }
-	}
-      }
-      break;
-
-    case MotionNotify:
-      NewTimestamp = Event.xmotion.time;
-      if (MouseInStartButton(Event.xmotion.x, Event.xbutton.y, &whichButton, &startButtonPressed)) {
-	CheckForTip(Event.xmotion.x, Event.xmotion.y);
-	break;
-      }
-      num = WhichButton(&buttons, Event.xmotion.x, Event.xmotion.y);
-      if (!HighlightFocus) {
-	if (SomeButtonDown(Event.xmotion.state) && num != ButPressed) {
-	  if (num != -1) {
-	    RadioButton(&buttons, num, BUTTON_DOWN);
-	    ButPressed = num;
-	  } else {
-	    RadioButton(&buttons, num, BUTTON_UP);
-	    ButPressed = -1;
-	  }
-	  redraw = 0;
-	}
-      } else if (num != -1 && num != ButPressed)
-	SendText(Fvwm_fd, "Focus 0", ItemID(&windows, num));
-
-      CheckForTip(Event.xmotion.x, Event.xmotion.y);
-      break;
-
-    case ConfigureNotify:
-      memcpy(&Event2, &Event, sizeof(Event));
-      /* eat up excess ConfigureNotify events. */
-      while (FCheckTypedWindowEvent(dpy, win, ConfigureNotify, &Event2))
-      {
-	memcpy(&Event, &Event2, sizeof(Event));
-      }
-      if (Event.xconfigure.height != win_height) {
-	AdjustWindow(Event.xconfigure.width, Event.xconfigure.height);
-	redraw = 1;
-      }
-      /* useful because of dynamic style change */
-      if (!Event.xconfigure.send_event)
-      {
-	break;
-      }
-      else if (Event.xconfigure.x != win_x || Event.xconfigure.y != win_y)
-      {
-	if (colorset > -1 && Colorset[colorset].pixmap == ParentRelative)
-	  redraw = 1;
-	if (AutoStick)
-	{
-	  SetAlarm(STICK_TASK_BAR);
-	  auto_stick_y = Event.xconfigure.y;
-	}
-	else
-	{
-	  win_x = Event.xconfigure.x;
-	  win_y = Event.xconfigure.y;
-	}
-      }
-      break;
-    } /* switch (Event.type) */
-
-    if (redraw >= 0)
-      RedrawWindow(redraw);
-    DoAlarmAction();
-    if (NewTimestamp - lasttime > UpdateInterval*1000L)
-    {
-      DrawGoodies();
-      lasttime = NewTimestamp;
-    }
-  }
-
-  return;
+	return;
 }
 
 /***********************************
@@ -1751,13 +1925,13 @@ static void CreateOrUpdateGCs(void)
    if (iconbackgraph)
      XChangeGC(dpy,icongraph,gcmask,&gcval);
    else
-     icongraph = fvwmlib_XCreateGC(dpy,Root,gcmask,&gcval);
+     icongraph = fvwmlib_XCreateGC(dpy,win,gcmask,&gcval);
 
    gcval.foreground = piconback;
    if (iconbackgraph)
      XChangeGC(dpy,iconbackgraph,gcmask,&gcval);
    else
-     iconbackgraph = fvwmlib_XCreateGC(dpy,Root,gcmask,&gcval);
+     iconbackgraph = fvwmlib_XCreateGC(dpy,win,gcmask,&gcval);
 
    gcval.foreground = piconshadow;
    if (iconshadow)
@@ -1776,13 +1950,13 @@ static void CreateOrUpdateGCs(void)
    if (focusbackgraph)
      XChangeGC(dpy,focusgraph,gcmask,&gcval);
    else
-     focusgraph = fvwmlib_XCreateGC(dpy,Root,gcmask,&gcval);
+     focusgraph = fvwmlib_XCreateGC(dpy,win,gcmask,&gcval);
 
    gcval.foreground = pfocusback;
       if (focusbackgraph)
      XChangeGC(dpy,focusbackgraph,gcmask,&gcval);
    else
-     focusbackgraph = fvwmlib_XCreateGC(dpy,Root,gcmask,&gcval);
+     focusbackgraph = fvwmlib_XCreateGC(dpy,win,gcmask,&gcval);
 
    gcval.foreground = pfocusshadow;
    if (focusshadow)
@@ -1874,6 +2048,8 @@ void StartMeUp(void)
    int ret;
    int i;
    XSetWindowAttributes attr;
+   int wx;
+   int wy;
 
    if (!(dpy = XOpenDisplay(""))) {
      fprintf(stderr,"%s: can't open display %s", Module,
@@ -1899,7 +2075,7 @@ void StartMeUp(void)
      UpdateString(&geometry, "+0-0");
    /* evaluate further down */
    ret = FScreenParseGeometryWithScreen(
-     geometry, &hints.x, &hints.y, (unsigned int *)&hints.width,
+     geometry, &wx, &wy, (unsigned int *)&hints.width,
      (unsigned int *)&hints.height, &fscreen);
    FScreenGetScrRect(
      NULL, fscreen,
@@ -1942,24 +2118,24 @@ void StartMeUp(void)
    {
      if (AutoStick)
      {
-       if (-hints.y < Midline)
-	 hints.y = screen_g.height - (AutoHide ? VISIBLE_PIXELS() : win_height);
+       if (-wy < Midline)
+	 wy = screen_g.height - (AutoHide ? VISIBLE_PIXELS() : win_height);
        else
-	 hints.y = AutoHide ? VISIBLE_PIXELS() - win_height : 0;
-       hints.y += screen_g.y;
+	 wy = AutoHide ? VISIBLE_PIXELS() - win_height : 0;
+       wy += screen_g.y;
      }
      else
      {
-       hints.y += screen_g.height - win_height;
+       wy += screen_g.height - win_height;
      }
    }
    else if (AutoStick)
    {
-     if (hints.y < Midline)
-       hints.y = AutoHide ? VISIBLE_PIXELS() - win_height : 0;
+     if (wy < Midline)
+       wy = AutoHide ? VISIBLE_PIXELS() - win_height : 0;
      else
-       hints.y = screen_g.height - (AutoHide ? VISIBLE_PIXELS() : win_height);
-     hints.y += screen_g.y;
+       wy = screen_g.height - (AutoHide ? VISIBLE_PIXELS() : win_height);
+     wy += screen_g.y;
    }
 
    if (ret & XNegative)
@@ -1979,7 +2155,7 @@ void StartMeUp(void)
 
    hints.flags=USPosition|PPosition|USSize|PSize|PResizeInc|
      PWinGravity|PMinSize|PMaxSize|PBaseSize;
-   hints.x           = screen_g.x;
+   wx           = screen_g.x;
    hints.width       = win_width;
    hints.height      = win_height;
    hints.width_inc   = 1;
@@ -1991,8 +2167,8 @@ void StartMeUp(void)
    hints.base_width  = win_width;
    hints.base_height = RowHeight;
 
-   win_x = hints.x + win_border;
-   win_y = hints.y;
+   win_x = wx + win_border;
+   win_y = wy;
 
    if(Pdepth < 2) {
      back = PictureWhitePixel();
@@ -2020,7 +2196,7 @@ void StartMeUp(void)
      (colorset >= 0) ? Colorset[colorset].bg : back;
    attr.border_pixel = 0;
    attr.colormap = Pcmap;
-   win=XCreateWindow(dpy,Root,hints.x,hints.y,hints.width,hints.height,0,Pdepth,
+   win=XCreateWindow(dpy,Root,wx,wy,hints.width,hints.height,0,Pdepth,
 		     InputOutput,Pvisual,CWBackPixel|CWBorderPixel|CWColormap,
 		     &attr);
 
@@ -2032,14 +2208,16 @@ void StartMeUp(void)
     char *list[]={NULL,NULL};
     list[0] = Module+1;
 
-    classhints.res_name=safestrdup(Module+1);
-    classhints.res_class=safestrdup("FvwmTaskBar");
+    classhints.res_name= Module+1;
+    classhints.res_class= "FvwmTaskBar";
 
     if(!XStringListToTextProperty(list,1,&nametext))
     {
       fprintf(stderr,"%s: Failed to convert name to XText\n",Module);
       exit(1);
     }
+    /* hack to prevent mapping on wrong screen with StartsOnScreen */
+    FScreenMangleScreenIntoUSPosHints(fscreen, &hints);
     XSetWMProperties(dpy,win,&nametext,&nametext,
 		     NULL,0,&hints,NULL,&classhints);
     XFree(nametext.value);
@@ -2245,7 +2423,7 @@ void HideTaskBar()
   if (WindowState == -1 || win_is_shaded)
     return;
 
-  if (FocusInWin)
+  if (1||FocusInWin)
   {
     if (FQueryPointer(
 		dpy, win, &d_rt,&d_ch, &d_x, &d_y, &wx, &wy, &mask) == False)
