@@ -5,12 +5,12 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307	 USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "config.h"
@@ -18,11 +18,9 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
-#include <string.h>
 #include <fcntl.h>
 #include <pwd.h>
-#include <time.h>
-#include <sys/time.h>
+#include "libs/ftime.h"
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <X11/Xlib.h>
@@ -35,6 +33,8 @@
 #include "libs/FShape.h"
 #include "libs/Colorset.h"
 #include "libs/Module.h"
+#include "libs/Rectangles.h"
+#include "libs/FGettext.h"
 #include "Goodies.h"
 #include "FvwmTaskBar.h"
 #include "Mallocs.h"
@@ -65,6 +65,7 @@ int goodies_fontheight, clock_width;
 char *mailpath = NULL;
 char *clockfmt = NULL;
 char *datefmt = NULL;
+Bool do_display_clock = True;
 int BellVolume = DEFAULT_BELL_VOLUME;
 Pixmap mailpix = None;
 Pixmap wmailpix = None;
@@ -88,7 +89,7 @@ void cool_get_inboxstatus();
 #define gray_height 8
 extern unsigned char gray_bits[];
 
-/*		  x  y	w  h  tw th open type *text   win */
+/*                x  y  w  h  tw th open type *text   win */
 TipStruct Tip = { 0, 0, 0, 0,  0, 0,   0,   0, NULL, None };
 
 
@@ -134,11 +135,18 @@ static void CreateOrUpdateGoodyGC(void)
       XFreePixmap(dpy, wmailpix);
     wmailpix = XCreatePixmapFromBitmapData(
       dpy, win, (char *)minimail_bits, minimail_width, minimail_height,
-      BlackPixel(dpy, screen), WhitePixel(dpy, screen), Pdepth);
+      PictureBlackPixel(), PictureWhitePixel(), Pdepth);
     goodies_width += minimail_width + 7;
   }
-  else
+  else if (do_display_clock)
+  {
     goodies_width += 3;
+  }
+  else
+  {
+	  goodies_width += 0;	  
+  }
+
 }
 
 Bool change_goody_colorset(int cset, Bool force)
@@ -201,12 +209,17 @@ Bool GoodiesParseConfig(char *tline)
     do_check_mail = (has_mailpath && (mailcheck_interval > 0));
     break;
   case 2: /* Mailcheck */
-    do_check_mail = MAILCHECK_DEFAULT;
-    sscanf(rest, "%d", &do_check_mail);
+    mailcheck_interval = MAILCHECK_DEFAULT;
+    sscanf(rest, "%d", &mailcheck_interval);
     do_check_mail = (has_mailpath && (mailcheck_interval > 0));
     break;
   case 3: /* ClockFormat */
     UpdateString(&clockfmt, rest);
+    do_display_clock = True;
+    if (clockfmt && clockfmt[0] == '\0' && datefmt && datefmt[0] == '\0')
+    {
+	    do_display_clock = False;
+    } 
     break;
   case 4: /* StatusFont */
     CopyStringWithQuotes(&statusfont_string, rest);
@@ -235,6 +248,11 @@ Bool GoodiesParseConfig(char *tline)
     break;
   case 11: /* DateFormat */
     UpdateString(&datefmt, rest);
+    do_display_clock = True;
+    if (clockfmt && clockfmt[0] == '\0' && datefmt && datefmt[0] == '\0')
+    {
+	    do_display_clock = False;
+    }
     break;
   default:
     /* unknow option */
@@ -257,105 +275,183 @@ void LoadGoodiesFont(void)
 
 void InitGoodies(void)
 {
-  struct passwd *pwent;
-  char tmp[1024];
+	struct passwd *pwent;
+	char tmp[1024];
 
-  if (mailpath == NULL) {
-    strcpy(tmp, DEFAULT_MAIL_PATH);
-    pwent = getpwuid(getuid());
-    strcat(tmp, (char *) (pwent->pw_name));
-    UpdateString(&mailpath, tmp);
-  }
+	if (mailpath == NULL)
+	{
+		strcpy(tmp, DEFAULT_MAIL_PATH);
+		pwent = getpwuid(getuid());
+		strcat(tmp, (char *) (pwent->pw_name));
+		UpdateString(&mailpath, tmp);
+	}
 
-  CreateOrUpdateGoodyGC();
-  if (clockfmt)
-  {
-    struct tm *tms;
-    static time_t timer;
-    static char str[24];
-    time(&timer);
-    tms = localtime(&timer);
-    strftime(str, 24, clockfmt, tms);
-    clock_width = FlocaleTextWidth(FStatusFont, str, strlen(str)) + 4;
-  }
-  else
-    clock_width = FlocaleTextWidth(FStatusFont, "XX:XX", 5) + 4;
-  goodies_width += clock_width;
-  stwin_width = goodies_width;
+	CreateOrUpdateGoodyGC();
+	if (clockfmt)
+	{
+		if (!do_display_clock)
+		{
+			clock_width = 0;
+		}
+		else
+		{
+			struct tm *tms;
+			static time_t timer;
+			static char str[24];
+			time(&timer);
+			tms = localtime(&timer);
+			strftime(str, 24, clockfmt, tms);
+			clock_width = FlocaleTextWidth(
+				FStatusFont, str, strlen(str)) + 4;
+		}
+	}
+	else
+	{
+		clock_width = FlocaleTextWidth(FStatusFont, "XX:XX", 5) + 4;
+	}
+	goodies_width += clock_width;
+	stwin_width = goodies_width;
 }
 
-void Draw3dBox(Window wn, int x, int y, int w, int h)
+void Draw3dBox(Window wn, int x, int y, int w, int h, XRectangle *bounding)
 {
-  XClearArea(dpy, wn, x, y, w, h, False);
+	XRectangle r;
 
-  XDrawLine(dpy, win, shadow, x, y, x+w-2, y);
-  XDrawLine(dpy, win, shadow, x, y, x, y+h-2);
+	if (bounding)
+	{
+		r.x = bounding->x;
+		r.y = bounding->y;
+		r.width = bounding->width;
+		r.height = bounding->height;
+	}
+	else
+	{
+		r.x = x;
+		r.y = y;
+		r.width = w;
+		r.height = h;
+	}
+	XClearArea(dpy, wn, r.x, r.y, r.width, r.height, False);
 
-  XDrawLine(dpy, win, hilite, x, y+h-1, x+w-1, y+h-1);
-  XDrawLine(dpy, win, hilite, x+w-1, y+h-1, x+w-1, y);
+	XDrawLine(dpy, win, shadow, x, y, x+w-2, y);
+	XDrawLine(dpy, win, shadow, x, y, x, y+h-2);
+
+	XDrawLine(dpy, win, hilite, x, y+h-1, x+w-1, y+h-1);
+	XDrawLine(dpy, win, hilite, x+w-1, y+h-1, x+w-1, y);
 }
 
-void DrawGoodies(void)
+void DrawGoodies(XEvent *evp)
 {
-  struct tm *tms;
-  static char str[40];
-  static time_t timer;
-  static int last_mail_check = -1;
+	XRectangle rect;
+	struct tm *tms;
+	static char str[40];
+	static time_t timer;
+	static int last_mail_check = -1;
+	int x = win_width - stwin_width;
+	int y = 0;
+	int w = stwin_width;
+	int h = RowHeight;
+	Region t_region;
 
-  time(&timer);
-  tms = localtime(&timer);
-  if (clockfmt) {
-    strftime(str, 24, clockfmt, tms);
-    if (str[0] == '0') str[0]=' ';
-  } else {
-    strftime(str, 15, "%R", tms);
-  }
+	if (goodies_width == 0)
+	{
+		return;
+	}
+	if (evp)
+	{
+		if (!frect_get_intersection(
+			x, y, w, h,
+			evp->xexpose.x, evp->xexpose.y,
+			evp->xexpose.width, evp->xexpose.height,
+			&rect))
+		{
+			return;
+		}
+	}
+	else
+	{
+		rect.x = x;
+		rect.y = y;
+		rect.width = w;
+		rect.height = h;
+	}
+	time(&timer);
+	tms = localtime(&timer);
+	if (clockfmt)
+	{
+		strftime(str, 24, clockfmt, tms);
+		if (str[0] == '0') str[0]=' ';
+	}
+	else
+	{
+		strftime(str, 15, "%R", tms);
+	}
 
-  Draw3dBox(win, win_width - stwin_width, 0, stwin_width, RowHeight);
-  FwinString->win = win;
-  FwinString->gc = statusgc;
-  FwinString->str = str;
-  FwinString->x = win_width - stwin_width + 4;
-  FwinString->y = ((RowHeight - goodies_fontheight) >> 1) + FStatusFont->ascent;
-  if (colorset >= 0)
-  {
-    FwinString->colorset = &Colorset[colorset];
-    FwinString->flags.has_colorset = True;
-  }
-  else
-  {
-    FwinString->flags.has_colorset = False;
-  }
-  FlocaleDrawString(dpy, FStatusFont, FwinString, 0);
+	Draw3dBox(win, x, y, w, h, &rect);
+	t_region = XCreateRegion();
+	XUnionRectWithRegion (&rect, t_region, t_region);
+	FwinString->win = win;
+	FwinString->gc = statusgc;
+	FwinString->str = str;
+	FwinString->x = x + 4;
+	FwinString->y = ((RowHeight - goodies_fontheight) >> 1) +
+		FStatusFont->ascent;
+	FwinString->flags.has_clip_region = True;
+	FwinString->clip_region = t_region;
+	if (colorset >= 0)
+	{
+		FwinString->colorset = &Colorset[colorset];
+		FwinString->flags.has_colorset = True;
+	}
+	else
+	{
+		FwinString->flags.has_colorset = False;
+	}
+	FlocaleDrawString(dpy, FStatusFont, FwinString, 0);
+	FwinString->flags.has_clip_region = False;
+	XDestroyRegion(t_region);
 
-  if (!do_check_mail)
-    return;
-  if (timer - last_mail_check >= 10) {
-    cool_get_inboxstatus();
-    last_mail_check = timer;
-    if (newmail)
-      XBell(dpy, BellVolume);
-  }
+	if (!do_check_mail)
+	{
+		return;
+	}
+	if (timer - last_mail_check >= mailcheck_interval)
+	{
+		cool_get_inboxstatus();
+		last_mail_check = timer;
+		if (newmail)
+			XBell(dpy, BellVolume);
+	}
 
-  if (!mailcleared && (unreadmail || newmail))
-    XCopyArea(dpy, wmailpix, win, statusgc, 0, 0,
-	      minimail_width, minimail_height,
-	      win_width - stwin_width + clock_width + 3,
-	      ((RowHeight - minimail_height) >> 1));
-  else if (!IgnoreOldMail /*&& !mailcleared*/ && anymail)
-    XCopyArea(dpy, mailpix, win, statusgc, 0, 0,
-	      minimail_width, minimail_height,
-	      win_width - stwin_width + clock_width + 3,
-	      ((RowHeight - minimail_height) >> 1));
-
-  if (Tip.open) {
-    if (Tip.type == DATE_TIP)
-      if (tms->tm_mday != last_date) /* reflect date change */
-	CreateDateWindow(); /* This automatically deletes any old window */
-    last_date = tms->tm_mday;
-    RedrawTipWindow();
-  }
+	if (!mailcleared && (unreadmail || newmail))
+	{
+		XCopyArea(dpy, wmailpix, win, statusgc, 0, 0,
+			  minimail_width, minimail_height,
+			  win_width - stwin_width + clock_width + 3,
+			  ((RowHeight - minimail_height) >> 1));
+	}
+	else if (!IgnoreOldMail /*&& !mailcleared*/ && anymail)
+	{
+		XCopyArea(dpy, mailpix, win, statusgc, 0, 0,
+			  minimail_width, minimail_height,
+			  win_width - stwin_width + clock_width + 3,
+			  ((RowHeight - minimail_height) >> 1));
+	}
 
+	if (Tip.open)
+	{
+		if (Tip.type == DATE_TIP)
+		{
+			if (tms->tm_mday != last_date)
+			{
+				/* reflect date change */
+				CreateDateWindow(); /* This automatically
+						     * deletes any old window */
+			}
+		}
+		last_date = tms->tm_mday;
+		RedrawTipWindow();
+	}
 }
 
 int MouseInClock(int x, int y)
@@ -392,13 +488,22 @@ void CreateDateWindow(void)
 
 void CreateMailTipWindow()
 {
-  char str[20];
+	const char *str;
 
-  if (!anymail)
-    sprintf(str, "No new mail");
-  else
-    sprintf(str, "You have %smail", (newmail || unreadmail) ? "new " : "");
-  PopupTipWindow(win_width, 0, str);
+	if (!anymail)
+	{
+		str = _("No new mail");
+	}
+	else if (newmail || unreadmail)
+	{
+		str = _("You have new mail");
+	}
+	else
+	{
+		str = _("You have mail");
+	}
+
+	PopupTipWindow(win_width, 0, str);
 }
 
 void RedrawTipWindow(void)
@@ -494,7 +599,7 @@ void CreateTipWindow(int x, int y, int w, int h)
   Pixmap pchk = None;
   Pixel tip_fore;
   Pixel tip_back;
-  colorset_struct *cset = NULL;
+  colorset_t *cset = NULL;
 
   if (tipscolorset >= 0)
   {
@@ -509,7 +614,7 @@ void CreateTipWindow(int x, int y, int w, int h)
   }
 
   winattr.background_pixel = tip_back;
-  winattr.border_pixel = BlackPixel(dpy, screen);
+  winattr.border_pixel = PictureBlackPixel();
   winattr.colormap = Pcmap;
   winattr.override_redirect = True;
   winattr.save_under = True;
@@ -573,7 +678,7 @@ void CreateTipWindow(int x, int y, int w, int h)
   if (FShapesSupported)
   {
     FShapeCombineMask(dpy, Tip.win, FShapeBounding, 0, 0, pmask, FShapeSet);
-    FShapeCombineMask(dpy, Tip.win, FShapeClip,	    0, 0, pclip, FShapeSet);
+    FShapeCombineMask(dpy, Tip.win, FShapeClip,     0, 0, pclip, FShapeSet);
   }
   if (tipscolorset >= 0 && (cset->pixmap || cset->shape_mask))
   {
@@ -600,7 +705,7 @@ void DestroyTipWindow()
 }
 
 /*-----------------------------------------------------*/
-/* Get file modification time			       */
+/* Get file modification time                          */
 /* (based on the code of 'coolmail' By Byron C. Darrah */
 /*-----------------------------------------------------*/
 
@@ -614,8 +719,8 @@ void cool_get_inboxstatus()
    fd = open (mailpath, O_RDONLY, 0);
    if (fd < 0)
    {
-      anymail	 = 0;
-      newmail	 = 0;
+      anymail    = 0;
+      newmail    = 0;
       unreadmail = 0;
       newsize = 0;
    }
